@@ -6,7 +6,7 @@
 #              Vadim Buzek
 #              Petr Ocasek
 # --
-# $Id: cz.pm,v 1.47.2.2 2008/05/28 08:03:42 tr Exp $
+# $Id: cz.pm,v 1.64 2008/08/06 11:48:12 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -16,25 +16,24 @@
 package Kernel::Language::cz;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.47.2.2 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.64 $) [1];
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Tue May 29 15:08:03 2007
+    # Last translation file sync: Fri May 16 14:07:47 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-2', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%D/%M/%Y %T';
-    $Self->{DateFormatLong} = '%A %D %B %Y %T';
-    $Self->{DateFormatShort} = '%D/%M/%Y';
-    $Self->{DateInputFormat} = '%D/%M/%Y';
+    $Self->{DateFormat}          = '%D/%M/%Y %T';
+    $Self->{DateFormatLong}      = '%A %D %B %Y %T';
+    $Self->{DateFormatShort}     = '%D/%M/%Y';
+    $Self->{DateInputFormat}     = '%D/%M/%Y';
     $Self->{DateInputFormatLong} = '%D/%M/%Y - %T';
 
     $Self->{Translation} = {
@@ -108,6 +107,7 @@ sub Data {
         'please do not edit!' => 'prosme neupravujte!',
         'AddLink' => 'Pidat Odkaz',
         'Link' => 'Odkaz',
+        'Unlink' => '',
         'Linked' => '',
         'Link (Normal)' => '',
         'Link (Parent)' => '',
@@ -249,6 +249,8 @@ sub Data {
         'Mobile' => '',
         'Zip' => '',
         'City' => '',
+        'Location' => '',
+        'Street' => '',
         'Country' => '',
         'installed' => '',
         'uninstalled' => '',
@@ -257,6 +259,16 @@ sub Data {
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => '',
         'No Packages or no new Packages in selected Online Repository!' => '',
         'printed at' => '',
+        'Dear Mr. %s,' => '',
+        'Dear Mrs. %s,' => '',
+        'Dear %s,' => '',
+        'Hello %s,' => '',
+        'This account exists.' => '',
+        'New account created. Sent Login-Account to %s.' => '',
+        'Please press Back and try again.' => '',
+        'Sent password token to: %s' => '',
+        'Sent new password to: %s' => '',
+        'Invalid Token!' => '',
 
         # Template: AAAMonth
         'Jan' => 'Led',
@@ -387,6 +399,7 @@ sub Data {
         'Move' => 'Pesunout',
         'Queue' => 'Fronta',
         'Priority' => 'Priorita',
+        'Priority Update' => '',
         'State' => 'Stav',
         'Compose' => 'Sestavit',
         'Pending' => 'ek na vyzen',
@@ -455,6 +468,7 @@ sub Data {
         'Phone-Ticket' => '',
         'Search Tickets' => '',
         'Edit Customer Users' => '',
+        'Edit Customer Company' => '',
         'Bulk-Action' => '',
         'Bulk Actions on Tickets' => '',
         'Send Email and create a new Ticket' => '',
@@ -553,6 +567,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Customer request via web.',
         'History::TicketLinkAdd' => 'Added link to ticket "%s".',
         'History::TicketLinkDelete' => 'Deleted link to ticket "%s".',
+        'History::Subscribe' => 'Added subscription for user "%s".',
+        'History::Unsubscribe' => 'Removed subscription for user "%s".',
 
         # Template: AAAWeekDay
         'Sun' => 'Ne',
@@ -585,6 +601,7 @@ sub Data {
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => '',
+        'Search for' => '',
         'Add Customer Company' => '',
         'Add a new Customer Company.' => '',
         'List' => '',
@@ -593,7 +610,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'Sprva Klient',
-        'Search for' => '',
         'Add Customer User' => '',
         'Source' => '',
         'Create' => '',
@@ -612,14 +628,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
-        # Template: AdminCustomerUserServiceChangeForm
+        # Template: AdminCustomerUserService
         'Customer Users <-> Services Management' => '',
-        'Select the customeruser:service relations.' => '',
-        'Allocate services to CustomerUser' => '',
-        'Allocate CustomerUser to service' => '',
-
-        # Template: AdminCustomerUserServiceForm
+        'CustomerUser' => 'Klient',
+        'Service' => '',
         'Edit default services.' => '',
+        'Search Result' => 'Vsledky vyhledvn',
+        'Allocate services to CustomerUser' => '',
+        'Active' => '',
+        'Allocate CustomerUser to service' => '',
 
         # Template: AdminEmail
         'Message sent to' => 'Zprva odeslna',
@@ -642,6 +659,7 @@ sub Data {
         '(e. g. 234321)' => '(nap. 234321)',
         'Customer User Login' => 'Pihlen klienta',
         '(e. g. U5150)' => '(nap. U5150)',
+        'SLA' => '',
         'Agent' => '',
         'Ticket Lock' => '',
         'TicketFreeFields' => '',
@@ -649,10 +667,16 @@ sub Data {
         'No create time settings.' => '',
         'Ticket created' => 'Tiket vytvoen',
         'Ticket created between' => 'Tiket vytvoen mezi',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Pending Times' => '',
         'No pending time settings.' => '',
         'Ticket pending time reached' => '',
         'Ticket pending time reached between' => '',
+        'New Service' => '',
+        'New SLA' => '',
         'New Priority' => '',
         'New Queue' => 'Nov fronta',
         'New State' => '',
@@ -660,7 +684,9 @@ sub Data {
         'New Owner' => 'Nov vlastnk',
         'New Customer' => '',
         'New Ticket Lock' => '',
-        'CustomerUser' => 'Klient',
+        'New Type' => '',
+        'New Title' => '',
+        'New Type' => '',
         'New TicketFreeFields' => '',
         'Add Note' => 'Pidat poznmku',
         'CMD' => '',
@@ -693,6 +719,14 @@ sub Data {
         'System Log' => 'Log systmu',
         'Time' => '',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => '',
+        'Host' => 'Hostitel',
+        'Trusted' => 'Oveno',
+        'Dispatching' => 'Zaazen',
+        'All incoming emails with one account will be dispatched in the selected queue!' => 'Vechny pchoz emaily z danho tu budou zaazeny do vybran fronty!',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
+
         # Template: AdminNavigationBar
         'Users' => '',
         'Groups' => 'Skupiny',
@@ -747,6 +781,10 @@ sub Data {
         'Min Response' => '',
         'Max Response' => '',
         'Average Response' => '',
+        'Period' => '',
+        'Min' => '',
+        'Max' => '',
+        'Average' => '',
 
         # Template: AdminPGPForm
         'PGP Management' => '',
@@ -758,14 +796,6 @@ sub Data {
         'Expires' => '',
         'In this way you can directly edit the keyring configured in SysConfig.' => '',
 
-        # Template: AdminPOP3
-        'POP3 Account Management' => 'Sprva POP3 t',
-        'Host' => 'Hostitel',
-        'Trusted' => 'Oveno',
-        'Dispatching' => 'Zaazen',
-        'All incoming emails with one account will be dispatched in the selected queue!' => 'Vechny pchoz emaily z danho tu budou zaazeny do vybran fronty!',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
-
         # Template: AdminPostMasterFilter
         'PostMaster Filter Management' => '',
         'Filtername' => '',
@@ -785,9 +815,13 @@ sub Data {
         'Sub-Queue of' => 'Podfronta ',
         'Unlock timeout' => 'as do odemknut',
         '0 = no unlock' => '0 = dn odemknut',
+        'Only business hours are counted.' => '',
         'Escalation - First Response Time' => '',
         '0 = no escalation' => '0 = dn stupovn',
+        'Only business hours are counted.' => '',
+        'Notify by' => '',
         'Escalation - Update Time' => '',
+        'Notify by' => '',
         'Escalation - Solution Time' => '',
         'Follow up Option' => 'Nsledujc volba',
         'Ticket lock after a follow up' => 'Zamknout tiket po nsledujcm',
@@ -847,7 +881,6 @@ sub Data {
 
         # Template: AdminRoleUserChangeForm
         'Roles <-> Users Management' => '',
-        'Active' => '',
         'Select the role:user relations.' => '',
 
         # Template: AdminRoleUserForm
@@ -858,7 +891,7 @@ sub Data {
         'Add a new Salutation.' => '',
 
         # Template: AdminSelectBoxForm
-        'Select Box' => 'Poadavek na SQL databzi',
+        'SQL Box' => '',
         'Limit' => '',
         'Go' => '',
         'Select Box Result' => 'Vsledek SQL dotazu',
@@ -867,7 +900,6 @@ sub Data {
         'Service Management' => '',
         'Add Service' => '',
         'Add a new Service.' => '',
-        'Service' => '',
         'Sub-Service of' => '',
 
         # Template: AdminSession
@@ -888,10 +920,6 @@ sub Data {
         'SLA Management' => '',
         'Add SLA' => '',
         'Add a new SLA.' => '',
-        'SLA' => '',
-        'First Response Time' => '',
-        'Update Time' => '',
-        'Solution Time' => '',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => '',
@@ -1046,7 +1074,7 @@ sub Data {
         'Scale' => '',
         'minimal' => '',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => '',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => '',
@@ -1126,6 +1154,17 @@ sub Data {
         'Refresh' => '',
         'Clear To' => '',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => '',
+        'Escalation' => '',
+        'Today' => '',
+        'Tomorrow' => '',
+        'Next Week' => '',
+        'up' => 'nahoru',
+        'down' => 'dol',
+        'Escalation' => '',
+        'Locked' => '',
+
         # Template: AgentTicketForward
         'Article type' => 'Typ poloky',
 
@@ -1146,8 +1185,6 @@ sub Data {
         'Reminder' => 'Upomnka',
         'Sort by' => 'Setdit dle',
         'Order' => 'Seadit',
-        'up' => 'nahoru',
-        'down' => 'dol',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => '',
@@ -1177,7 +1214,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => '',
         'Accounted time' => 'tovan doba',
-        'Escalation in' => 'Stupovn v',
+        'First Response Time' => '',
+        'Update Time' => '',
+        'Solution Time' => '',
         'Linked-Object' => '',
         'Parent-Object' => '',
         'Child-Object' => '',
@@ -1212,29 +1251,35 @@ sub Data {
         'Search-Template' => 'Forma vyhledvn',
         'TicketFreeText' => 'Voln text tiketu',
         'Created in Queue' => '',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Result Form' => 'Forma vsledku',
         'Save Search-Profile as Template?' => 'Uloit profil vyhledvn jako ablonu?',
         'Yes, save it with name' => 'Ano, uloit pod nzvem',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
-        'Search Result' => 'Vsledky vyhledvn',
         'Change search options' => 'Zmnit monosti vyhledvn',
 
         # Template: AgentTicketSearchResultPrint
 
         # Template: AgentTicketSearchResultShort
-        'U' => 'Z-A',
-        'D' => 'A-Z',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => '',
         'Open Tickets' => '',
-        'Locked' => '',
 
         # Template: AgentTicketZoom
+        'Expand View' => '',
+        'Collapse View' => '',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1302,15 +1347,18 @@ sub Data {
 
         # Template: Installer
         'Web-Installer' => 'Web-instaltor',
+        'Welcome to %s' => 'Vtejte v %s',
         'Accept license' => '',
         'Don\'t accept license' => '',
         'Admin-User' => 'Administrtor',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => '',
         'Admin-Password' => '',
-        'your MySQL DB should have a root password! Default is empty!' => 'Vae MySQL databze by mla mt root heslo! Vchoz je przdn!',
         'Database-User' => '',
         'default \'hot\'' => 'vchoz \'hot\'',
         'DB connect host' => '',
         'Database' => '',
+        'Default Charset' => 'Vchoz znakov sada',
+        'utf8' => '',
         'false' => '',
         'SystemID' => 'Systmov ID',
         '(The identify of the system. Each ticket number and each http session id starts with this number)' => '(Identita systmu. Kad slo tiketu a ID kad HTTP relace zan tmto slem)',
@@ -1325,7 +1373,6 @@ sub Data {
         'Logfile' => 'Log soubor',
         '(Logfile just needed for File-LogModule!)' => '(Pro logovn do souboru je nutn zadat nzev souboru logu!)',
         'Webfrontend' => 'Webove rozhran',
-        'Default Charset' => 'Vchoz znakov sada',
         'Use utf-8 it your database supports it!' => 'Pouijte utf-8 pokud to Vae databze podporuje',
         'Default Language' => 'Vchoz jazyk',
         '(Used default language)' => '(Pouit vchoz jazyk)',
@@ -1335,11 +1382,9 @@ sub Data {
         'Restart your webserver' => 'Restartujte V webserver',
         'After doing so your OTRS is up and running.' => 'Po dokonen nsledujcch operac je V OTRS sputn a pob',
         'Start page' => 'vodn strnka',
-        'Have a lot of fun!' => 'Pejeme hodn spch s OTRS!',
         'Your OTRS Team' => 'V OTRS tm',
 
         # Template: Login
-        'Welcome to %s' => 'Vtejte v %s',
 
         # Template: Motd
 
@@ -1368,14 +1413,15 @@ sub Data {
         'Change roles <-> groups settings' => '',
         'Ticket Number Generator' => 'Genertor sel tiket',
         '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(Identifiktor tiket. Nekte lid chtj nastavit nap. \'Tiket#\',  \'Hovor#\' nebo \'MujTiket#\')',
-        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => '',
         'Create new Phone Ticket' => '',
+        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => '',
         'Symptom' => 'Pznak',
+        'U' => 'Z-A',
         'A message should have a To: recipient!' => 'Zprva by mla obsahovat Komu: pjemce!',
         'Site' => 'Umstn',
         'Customer history search (e. g. "ID342425").' => 'Vyhledvn historie klienta (nap. "ID342425")',
-        'Close!' => 'Zavt!',
         'for agent firstname' => 'pro kestn jmno agenta',
+        'Close!' => 'Zavt!',
         'The message being composed has been closed.  Exiting.' => 'Vytven zprva byla uzavena. Opoutm.',
         'A web calendar' => '',
         'to get the realname of the sender (if given)' => 'pro zskan skutenho jmna odeslatele (pokud je zadno)',
@@ -1405,7 +1451,6 @@ sub Data {
         'Stat#' => '',
         'A message must be spell checked!' => 'Zprva mus bt pravopisn zkontrolovan!',
         'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'V email s slem ticketu "<OTRS_TICKET>" je odesln zpt na "<OTRS_BOUNCE_TO>". Kontaktujte tuto adresu pro dal infromace.',
-        'Mail Account Management' => '',
         'ArticleID' => 'ID poloky',
         'A message should have a body!' => 'Zprva by mla mt tlo!',
         'All Agents' => 'Vichni agenti',
@@ -1418,9 +1463,10 @@ sub Data {
         'OTRS DB Password' => 'Heslo OTRS databze',
         'Last update' => 'Posledn aktualizace',
         'to get the first 20 character of the subject' => 'pro zskni prvnch 20 znak z pedmtu',
+        'Select the customeruser:service relations.' => '',
         'DB Admin Password' => 'Heslo administrtora databze',
-        'Drop Database' => 'Odstranit databazi',
         'Advisory' => '',
+        'Drop Database' => 'Odstranit databazi',
         'FileManager' => '',
         'Options of the current customer user data (e. g. <OTRS_CUSTOMER_DATA_UserFirstname>)' => '',
         'Pending type' => 'Typ ekn na vyzen',
@@ -1452,12 +1498,13 @@ sub Data {
         'Finished' => 'Dokoneno',
         'Account Type' => '',
         'Split' => 'Rozdlit',
-        'All messages' => 'Vechny zprvy',
+        'D' => 'A-Z',
         'System Status' => '',
+        'All messages' => 'Vechny zprvy',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => '',
         'A article should have a title!' => '',
-        'Event' => '',
         'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => '',
+        'Event' => '',
         'don\'t accept license' => 'nesouhlasm s licenc',
         'A web mail client' => '',
         'WebMail' => '',
@@ -1468,23 +1515,37 @@ sub Data {
         'to get the from line of the email' => 'pro zskan dku Od z emailu',
         'Solution' => 'een',
         'QueueView' => 'Nhled fronty',
+        'Select Box' => 'Poadavek na SQL databzi',
         'Welcome to OTRS' => '',
         'modified' => '',
+        'Escalation in' => 'Stupovn v',
         'Delete old database' => 'Smazat starou databzi',
         'sort downward' => 'setdit dol',
         'You need to use a ticket number!' => '',
         'A web file manager' => '',
+        'Have a lot of fun!' => 'Pejeme hodn spch s OTRS!',
         'send' => 'poslat',
         'Note Text' => 'Text poznmky',
+        'POP3 Account Management' => 'Sprva POP3 t',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => '',
         'System State Management' => 'Sprva stavu systmu',
         'OTRS DB User' => 'Uivatel OTRS databze',
         'PhoneView' => 'Nov tiket / hovor',
         'maximal period form' => '',
-        'Verion' => '',
         'TicketID' => 'ID tiketu',
         'Modified' => 'Zmnno',
         'Ticket selected for bulk action!' => '',
+
+        'Link Object: %s' => '',
+        'Unlink Object: %s' => '',
+        'Linked as' => '',
+        'Can not create link with %s!' => '',
+        'Can not delete link with %s!' => '',
+        'Object already linked as %s.' => '',
+        'Priority Management' => 'Řízení priorit',
+        'Add a new Priority.' => 'Dodat novou prioritou',
+        'Add Priority' => 'Dodat prioritou',
+        'Ticket Type is required!' => '',
     };
     # $$STOP$$
     return;
