@@ -2,7 +2,7 @@
 # Kernel/Language/de.pm - provides de language translation
 # Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: de.pm,v 1.147.2.6 2008/05/28 08:03:42 tr Exp $
+# $Id: de.pm,v 1.170 2008/08/06 12:28:37 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -11,25 +11,24 @@
 package Kernel::Language::de;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.147.2.6 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.170 $) [1];
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Tue May 29 15:05:19 2007
+    # Last translation file sync: Fri May 16 14:07:16 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%D.%M.%Y %T';
-    $Self->{DateFormatLong} = '%T - %D.%M.%Y';
-    $Self->{DateFormatShort} = '%D.%M.%Y';
-    $Self->{DateInputFormat} = '%D.%M.%Y';
+    $Self->{DateFormat}          = '%D.%M.%Y %T';
+    $Self->{DateFormatLong}      = '%T - %D.%M.%Y';
+    $Self->{DateFormatShort}     = '%D.%M.%Y';
+    $Self->{DateInputFormat}     = '%D.%M.%Y';
     $Self->{DateInputFormatLong} = '%D.%M.%Y - %T';
 
     $Self->{Translation} = {
@@ -103,6 +102,7 @@ sub Data {
         'please do not edit!' => 'Bitte nicht ndern!',
         'AddLink' => 'Link hinzufgen',
         'Link' => 'Verknpfen',
+        'Unlink' => 'Verknpft aufheben',
         'Linked' => 'Verknpft',
         'Link (Normal)' => 'Verknpft (Normal)',
         'Link (Parent)' => 'Verknpft (Eltern)',
@@ -244,6 +244,8 @@ sub Data {
         'Mobile' => 'Mobile',
         'Zip' => 'PLZ',
         'City' => 'Stadt',
+        'Location' => 'Standort',
+        'Street' => 'Strae',
         'Country' => 'Land',
         'installed' => 'installiert',
         'uninstalled' => 'nicht installiert',
@@ -252,6 +254,16 @@ sub Data {
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => 'Kein Paket fr den bentigten Framework vorhanden, aber fr andere Frameworks.',
         'No Packages or no new Packages in selected Online Repository!' => 'Kein Paket oder keine neuen Pakete im ausgewhlten Online Repository vorhanden!',
         'printed at' => 'gedruckt am',
+        'Dear Mr. %s,' => 'Sehr geehrter Herr %s,',
+        'Dear Mrs. %s,' => 'Sehr geehrte Frau %s,',
+        'Dear %s,' => 'Lieber %s,',
+        'Hello %s,' => 'Hallo %s,',
+        'This account exists.' => 'Dieser Benutzer ist bereits vorhanden.',
+        'New account created. Sent Login-Account to %s.' => 'Neuen Account erstellt. Login-Daten an %s gesendet.',
+        'Please press Back and try again.' => 'Bitte auf Zurck klicken und erneut versuchen.',
+        'Sent password token to: %s' => 'Passwort-Token an %s gesendet.',
+        'Sent new password to: %s' => 'Neues Passwort an %s gesendet.',
+        'Invalid Token!' => 'Ungltiger Token!',
 
         # Template: AAAMonth
         'Jan' => 'Jan',
@@ -291,7 +303,6 @@ sub Data {
         'Admin' => 'Admin',
         'Customer Users' => 'Kunden Benutzer',
         'Customer Users <-> Groups' => 'Kunden Benutzer <-> Gruppen',
-        'Customer Users <-> Services' => 'Kunden Benutzer <-> Services',
         'Users <-> Groups' => 'Benutzer <-> Gruppen',
         'Roles' => 'Rollen',
         'Roles <-> Users' => 'Rollen <-> Benutzer',
@@ -349,24 +360,23 @@ sub Data {
         'The selected time period is larger than the allowed time period!' => 'Der gewhlte Zeitraum ist grer als der erlaubte Zeitraum!',
         'Common Specification' => 'Allgemeine Angaben',
         'Xaxis' => 'X-Achse',
-        'Value Series'           => 'Wertereihen',
-        'Restrictions'           => 'Einschrnkungen',
-        'graph-lines'            => 'Liniendiagramm',
-        'graph-bars'             => 'Balkendiagramm',
-        'graph-hbars'            => 'Balkendiagramm (horizontal)',
-        'graph-points'           => 'Punktdiagramm',
-        'graph-lines-points'     => 'Linienpunktdiagramm',
-        'graph-area'             => 'Flchendiagramm',
-        'graph-pie'              => 'Tortendiagramm',
-        'extended'               => 'erweitert',
-        'Agent/Owner'            => 'Agent/Besitzer',
+        'Value Series' => 'Wertereihen',
+        'Restrictions' => 'Einschrnkungen',
+        'graph-lines' => 'Liniendiagramm',
+        'graph-bars' => 'Balkendiagramm',
+        'graph-hbars' => 'Balkendiagramm (horizontal)',
+        'graph-points' => 'Punktdiagramm',
+        'graph-lines-points' => 'Linienpunktdiagramm',
+        'graph-area' => 'Flchendiagramm',
+        'graph-pie' => 'Tortendiagramm',
+        'extended' => 'erweitert',
+        'Agent/Owner' => 'Agent/Besitzer',
         'Created by Agent/Owner' => 'Erstellt von Agent/Besitzer',
-        'Created Priority'       => 'Erstellt mit der Prioritt',
-        'Created State'          => 'Erstellt mit dem Status',
-        'Create Time'            => 'Erstellt',
-        'CustomerUserLogin'      => 'Kundenlogin',
-        'Close Time'             => 'Ticket geschlossen',
-        'CSV'                    => 'CSV',
+        'Created Priority' => 'Erstellt mit der Prioritt',
+        'Created State' => 'Erstellt mit dem Status',
+        'Create Time' => 'Erstellt',
+        'CustomerUserLogin' => 'Kundenlogin',
+        'Close Time' => 'Ticket geschlossen',
 
         # Template: AAATicket
         'Lock' => 'Sperren',
@@ -384,6 +394,7 @@ sub Data {
         'Move' => 'Verschieben',
         'Queue' => 'Queue',
         'Priority' => 'Prioritt',
+        'Priority Update' => 'Prioritt aktualisieren',
         'State' => 'Status',
         'Compose' => 'Verfassen',
         'Pending' => 'Warten',
@@ -452,6 +463,7 @@ sub Data {
         'Phone-Ticket' => 'Telefon-Ticket',
         'Search Tickets' => 'Ticket-Suche',
         'Edit Customer Users' => 'Kunden-Benutzer bearbeiten',
+        'Edit Customer Company' => 'Kunden-Firma bearbeiten',
         'Bulk-Action' => 'Sammel-Aktion',
         'Bulk Actions on Tickets' => 'Sammel-Action an Tickets',
         'Send Email and create a new Ticket' => 'E-Mail senden und neues Ticket erstellen',
@@ -550,6 +562,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Kunde stellte Anfrage ber Web.',
         'History::TicketLinkAdd' => 'Verknpfung zu "%s" hergestellt.',
         'History::TicketLinkDelete' => 'Verknpfung zu "%s" gelscht.',
+        'History::Subscribe' => 'Abo fr Benutzer "%s" eingetragen.',
+        'History::Unsubscribe' => 'Abo fr Benutzer "%s" ausgetragen.',
 
         # Template: AAAWeekDay
         'Sun' => 'Son',
@@ -582,6 +596,7 @@ sub Data {
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => 'Kunden-Firma Verwaltung',
+        'Search for' => 'Suche nach',
         'Add Customer Company' => 'Kunden-Firma hinzufgen',
         'Add a new Customer Company.' => 'Eine neue Kunden-Firma hinzufgen.',
         'List' => 'Liste',
@@ -590,7 +605,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'Kunden-Benutzer Verwaltung',
-        'Search for' => 'Suche nach',
         'Add Customer User' => 'Kunden-Benutzer hinzufgen',
         'Source' => 'Quelle',
         'Create' => 'Erstellen',
@@ -609,14 +623,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
-        # Template: AdminCustomerUserServiceChangeForm
+        # Template: AdminCustomerUserService
         'Customer Users <-> Services Management' => 'Kundenbenutzer <-> Services Verwaltung',
-        'Select the customeruser:service relations.' => 'Auswahl der Kundenbenutzer:Service Beziehungen.',
-        'Allocate services to CustomerUser' => 'Services zuordnen zum Kundenbenutzer',
-        'Allocate CustomerUser to service' => 'Kundenbenutzer zuordnen zum Service',
-
-        # Template: AdminCustomerUserServiceForm
+        'CustomerUser' => 'Kundenbenutzer',
+        'Service' => 'Service',
         'Edit default services.' => 'Standard-Services bearbeiten.',
+        'Search Result' => 'Such-Ergebnis',
+        'Allocate services to CustomerUser' => 'Services zuordnen zum Kundenbenutzer',
+        'Active' => 'Aktiv',
+        'Allocate CustomerUser to service' => 'Kundenbenutzer zuordnen zum Service',
 
         # Template: AdminEmail
         'Message sent to' => 'Nachricht gesendet an',
@@ -639,6 +654,7 @@ sub Data {
         '(e. g. 234321)' => 'z. B. 234321',
         'Customer User Login' => 'Kunden-Benutzer-Login',
         '(e. g. U5150)' => 'z. B. U5150',
+        'SLA' => 'SLA',
         'Agent' => 'Agent',
         'Ticket Lock' => 'Ticket sperren',
         'TicketFreeFields' => 'TicketFreiFelder',
@@ -646,10 +662,16 @@ sub Data {
         'No create time settings.' => 'Keine Erstell-Zeiten',
         'Ticket created' => 'Ticket erstellt',
         'Ticket created between' => 'Ticket erstellt zwischen',
+        'Close Times' => 'Schlie-Zeiten',
+        'No close time settings.' => 'keine Schlie-Zeiten',
+        'Ticket closed' => 'Ticket geschlossen',
+        'Ticket closed between' => 'Ticket geschlossen zwischen',
         'Pending Times' => 'Warten-Zeiten',
         'No pending time settings.' => 'Keine Warten-Zeiten',
         'Ticket pending time reached' => 'Ticket Warten-Zeit erreicht',
         'Ticket pending time reached between' => 'Ticket Warten-Zeit erreicht zwischen',
+        'New Service' => 'Neuer Service',
+        'New SLA' => 'Neuer SLA',
         'New Priority' => 'Neue Prioritt',
         'New Queue' => 'Neue Queue',
         'New State' => 'Neuer Status',
@@ -657,7 +679,8 @@ sub Data {
         'New Owner' => 'Neuer Besitzer',
         'New Customer' => 'Neuer Kunde',
         'New Ticket Lock' => 'Neues Ticket Lock',
-        'CustomerUser' => 'Kundenbenutzer',
+        'New Type' => 'Neuer Typ',
+        'New Title' => 'Neuer Titel',
         'New TicketFreeFields' => 'Neue TicketFreiFelder',
         'Add Note' => 'Notiz hinzufgen',
         'CMD' => 'CMD',
@@ -689,6 +712,14 @@ sub Data {
         'System Log' => 'System Log',
         'Time' => 'Zeit',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => 'Mail Account Management',
+        'Host' => 'Host',
+        'Trusted' => 'Vertraut',
+        'Dispatching' => 'Verteilung',
+        'All incoming emails with one account will be dispatched in the selected queue!' => 'Einkommende E-Mails von POP3-Konten werden in die ausgewhlte Queue einsortiert!',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => 'Wird dem Konto vertraut, werden die X-OTRS Header benutzt! PostMaster Filter werden trotzdem benutzt.',
+
         # Template: AdminNavigationBar
         'Users' => 'Benutzer',
         'Groups' => 'Gruppen',
@@ -743,6 +774,10 @@ sub Data {
         'Min Response' => 'Min. Antwortzeit',
         'Max Response' => 'Max. Antwortzeit',
         'Average Response' => 'Durchschnittliche Antwortzeit',
+        'Period' => 'Periode',
+        'Min' => 'Min',
+        'Max' => 'Max',
+        'Average' => 'Durchschnitt',
 
         # Template: AdminPGPForm
         'PGP Management' => 'PGP Verwaltung',
@@ -754,14 +789,6 @@ sub Data {
         'Expires' => 'Erlischt',
         'In this way you can directly edit the keyring configured in SysConfig.' => 'ber diesen Weg kann man den Schlsselring (konfiguriert in SysConfig) direkt bearbeiten.',
 
-        # Template: AdminPOP3
-        'POP3 Account Management' => 'POP3-Konten Verwaltung',
-        'Host' => 'Host',
-        'Trusted' => 'Vertraut',
-        'Dispatching' => 'Verteilung',
-        'All incoming emails with one account will be dispatched in the selected queue!' => 'Einkommende E-Mails von POP3-Konten werden in die ausgewhlte Queue einsortiert!',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => 'Wird dem Konto vertraut, werden die X-OTRS Header benutzt! PostMaster Filter werden trotzdem benutzt.',
-
         # Template: AdminPostMasterFilter
         'PostMaster Filter Management' => 'PostMaster Filter Verwaltung',
         'Filtername' => 'Filtername',
@@ -781,8 +808,10 @@ sub Data {
         'Sub-Queue of' => 'Unterqueue von',
         'Unlock timeout' => 'Freigabe-Zeitintervall',
         '0 = no unlock' => '0 = keine Freigabe',
+        'Only business hours are counted.' => 'Nur geschftszeiten werden bercksichtigt.',
         'Escalation - First Response Time' => 'Eskalation - Reaktionszeit',
         '0 = no escalation' => '0 = keine Eskalation',
+        'Notify by' => 'Benachrichtigt von',
         'Escalation - Update Time' => 'Eskalation - Aktualisierungszeit',
         'Escalation - Solution Time' => 'Eskalation - Lsungszeit',
         'Follow up Option' => 'Nachfrage Option',
@@ -843,7 +872,6 @@ sub Data {
 
         # Template: AdminRoleUserChangeForm
         'Roles <-> Users Management' => 'Rollen <-> Benutzer Verwaltung',
-        'Active' => 'Aktiv',
         'Select the role:user relations.' => 'Auswahl der Rollen:Benutzer Beziehungen.',
 
         # Template: AdminRoleUserForm
@@ -854,7 +882,7 @@ sub Data {
         'Add a new Salutation.' => 'Eine neue Anrede hinzufgen.',
 
         # Template: AdminSelectBoxForm
-        'Select Box' => 'Select Box',
+        'SQL Box' => 'SQL Box',
         'Limit' => 'Limit',
         'Go' => 'Go',
         'Select Box Result' => 'Select Box Ergebnis',
@@ -863,7 +891,6 @@ sub Data {
         'Service Management' => 'Service Verwaltung',
         'Add Service' => 'Service hinzufgen',
         'Add a new Service.' => 'Einen neuen Service hinzufgen.',
-        'Service' => 'Service',
         'Sub-Service of' => 'Unterservice von',
 
         # Template: AdminSession
@@ -884,10 +911,6 @@ sub Data {
         'SLA Management' => 'SLA Verwaltung',
         'Add SLA' => 'SLA hinzufgen',
         'Add a new SLA.' => 'Einen neuen SLA hinzufgen.',
-        'SLA' => 'SLA',
-        'First Response Time' => 'Reaktionszeit',
-        'Update Time' => 'Aktualisierungszeit',
-        'Solution Time' => 'Lsungszeit',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => 'S/MIME Verwaltung',
@@ -1042,7 +1065,7 @@ sub Data {
         'Scale' => 'Skalierung',
         'minimal' => 'minimal',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => 'Bitte bedenken Sie, dass die Zeitskalierung fr die Wertereihen grer sein muss als fr die X-Achse (z. B. X-Achse => Monat; Wertereihe => Jahr).',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => 'Auf dieser Seite werden die Wertereihen festgelegt. Jedes Attribut wird als einzelne Wertereihe dargestellt. Wenn Sie keine Attribute auswhlen werden alle Attribute bei der Generierung einer Statistik verwendet. Auch, wenn ein neues Attribut nach der Statistikkonfiguration hinzugefgt wird.',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => 'Auf dieser Seite werden die Wertereihen festgelegt. Jedes Attribut wird als einzelne Wertereihe dargestellt. Wenn Sie keine Attribute auswhlen werden alle Attribute bei der Generierung einer Statistik verwendet. Auch, wenn ein neues Attribut nach der Statistikkonfiguration hinzugefgt wird.',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => 'Auswahl des Elements, welches fr die X-Achse genutzt wird.',
@@ -1122,6 +1145,16 @@ sub Data {
         'Refresh' => 'Aktualisieren',
         'Clear To' => 'An: lschen',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => 'Ticket Eskalations Ansicht',
+        'Escalation' => 'Eskalation',
+        'Today' => 'Heute',
+        'Tomorrow' => 'Morgen',
+        'Next Week' => 'Nchste Woche',
+        'up' => 'aufwrts',
+        'down' => 'abwrts',
+        'Locked' => 'Sperre',
+
         # Template: AgentTicketForward
         'Article type' => 'Artikeltyp',
 
@@ -1142,8 +1175,6 @@ sub Data {
         'Reminder' => 'Erinnernd',
         'Sort by' => 'Sortieren nach',
         'Order' => 'Sortierung',
-        'up' => 'aufwrts',
-        'down' => 'abwrts',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => 'Ticket zusammenfassen',
@@ -1164,7 +1195,6 @@ sub Data {
         # Template: AgentTicketPhone
         'Phone call' => 'Anruf',
         'Clear From' => 'Von: lschen',
-        'A required field is:' => 'Bitte fllen Sie das Pflichtfeld aus:',
 
         # Template: AgentTicketPhoneOutbound
 
@@ -1174,7 +1204,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => 'Ticket-Info',
         'Accounted time' => 'Zugewiesene Zeit',
-        'Escalation in' => 'Eskalation in',
+        'First Response Time' => 'Reaktionszeit',
+        'Update Time' => 'Aktualisierungszeit',
+        'Solution Time' => 'Lsungszeit',
         'Linked-Object' => 'Verknpfte-Objekte',
         'Parent-Object' => 'Eltern-Objekte',
         'Child-Object' => 'Kinder-Objekte',
@@ -1213,23 +1245,27 @@ sub Data {
         'Save Search-Profile as Template?' => 'Speichere Such-Profil als Vorlage?',
         'Yes, save it with name' => 'Ja, speichere unter dem Namen',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
-        'Search Result' => 'Such-Ergebnis',
         'Change search options' => 'Such-Optionen ndern',
 
+        # Template: AgentTicketSearchResultPrint
+
         # Template: AgentTicketSearchResultShort
-        'U' => 'U',
-        'D' => 'D',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => 'Ticket Status Ansicht',
         'Open Tickets' => 'Offene Tickets',
-        'Locked' => 'Sperre',
 
         # Template: AgentTicketZoom
+        'Expand View' => 'Ausklappen Ansicht',
+        'Collapse View' => 'Zugeklappte Ansicht',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1282,7 +1318,6 @@ sub Data {
         # Template: CustomerTicketZoom
 
         # Template: CustomerWarning
-	'This account exists' => 'Dieser Benutzer ist bereits vorhanden',
 
         # Template: Error
         'Click here to report a bug!' => 'Klicken Sie hier, um einen Fehler zu berichten!',
@@ -1298,15 +1333,18 @@ sub Data {
 
         # Template: Installer
         'Web-Installer' => 'Web-Installer',
+        'Welcome to %s' => 'Willkommen zu %s',
         'Accept license' => 'Lizenz akzeptieren',
         'Don\'t accept license' => 'Lizenz _nicht_ akzeptieren',
         'Admin-User' => 'Admin-Benutzer',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => 'Falls ein Root-Passwort fr die Datenbank gesetzt ist, muss es hier eingegeben werden. Ist kein Passwort gesetzt, muss das Feld leer gelassen werden. Aus Sicherheitsgrnden empfehlen wir ein Root-Passwort zu setzt. Weitere Informationen hierzu finden Sie in der Dokumentation Ihrer Datenbank.',
         'Admin-Password' => 'Admin-Passwort',
-        'your MySQL DB should have a root password! Default is empty!' => 'Deine MySQL DB sollte ein Root Passwort haben! Voreingestellt ist keines!',
         'Database-User' => 'Datenbank-Benutzer',
         'default \'hot\'' => 'voreingestellt \'hot\'',
         'DB connect host' => 'DB Verbindungs-Host',
         'Database' => 'Datenbank',
+        'Default Charset' => 'Standard-Zeichensatz',
+        'utf8' => 'utf8',
         'false' => 'false',
         'SystemID' => 'SystemID',
         '(The identify of the system. Each ticket number and each http session id starts with this number)' => '(Das Kennzeichnen des Systems. Jede Ticketnummer und http-Sitzung beginnt mit dieser Kennung)',
@@ -1321,7 +1359,6 @@ sub Data {
         'Logfile' => 'Logdatei',
         '(Logfile just needed for File-LogModule!)' => '(Logfile nur bentigt fr File-LogModule!)',
         'Webfrontend' => 'Web-Oberflche',
-        'Default Charset' => 'Standard-Zeichensatz',
         'Use utf-8 it your database supports it!' => 'Benutzen Sie utf-8 nur, wenn Ihre Datenbank es untersttzt!',
         'Default Language' => 'Standard-Sprache',
         '(Used default language)' => '(Standardwert fr die Sprache)',
@@ -1331,11 +1368,9 @@ sub Data {
         'Restart your webserver' => 'Starte Deinen Webserver neu.',
         'After doing so your OTRS is up and running.' => 'Danach luft Dein OTRS.',
         'Start page' => 'Startseite',
-        'Have a lot of fun!' => 'Viel Spa!',
         'Your OTRS Team' => 'Dein OTRS-Team',
 
         # Template: Login
-        'Welcome to %s' => 'Willkommen zu %s',
 
         # Template: Motd
 
@@ -1366,6 +1401,7 @@ sub Data {
         '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(Ticket Kennzeichnen. Z.B. \'Ticket#\', \'Call#\' oder \'MyTicket#\')',
         'Create new Phone Ticket' => 'Neues Telefon-Ticket erstellen',
         'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'Auf diesem Wege knnen Sie den Keyring in Kernel/Config.pm direkt verndern',
+        'U' => 'U',
         'A message should have a To: recipient!' => 'Eine Nachricht sollte einen Empfnger im Feld An: haben!',
         'Site' => 'Seite',
         'Customer history search (e. g. "ID342425").' => 'Kunden-Historie-Suche (z. B. "ID342425").',
@@ -1377,6 +1413,7 @@ sub Data {
         'to get the realname of the sender (if given)' => 'Um den Realnamen des Senders zu erhalten (wenn mglich)',
         'FAQ Search Result' => 'FAQ Suchergebnis',
         'Notification (Customer)' => 'Benachrichtigung (Kunde)',
+        'CSV' => 'CSV',
         'Select Source (for add)' => 'Quelle auswhlen (zum Hinzufgen)',
         'Node-Name' => 'Node-Name',
         'Options of the ticket data (e. g. &lt;OTRS_TICKET_Number&gt;, &lt;OTRS_TICKET_ID&gt;, &lt;OTRS_TICKET_Queue&gt;, &lt;OTRS_TICKET_State&gt;)' => 'EInstellungen der Ticketdaten (z. B. &lt;OTRS_TICKET_Number&gt;, &lt;OTRS_TICKET_ID&gt;, &lt;OTRS_TICKET_Queue&gt;, &lt;OTRS_TICKET_State&gt;)',
@@ -1416,10 +1453,12 @@ sub Data {
         'Options of the current user who requested this action (e. g. &lt;OTRS_CURRENT_USERFIRSTNAME&gt;)' => 'Einstellungen fr den Benutzer, der diese Aktion ausgelst hat (z. B. &lt;OTRS_CURRENT_USERFIRSTNAME&gt;)',
         'Message for new Owner' => 'Nachricht an neuen Besitzer',
         'to get the first 5 lines of the email' => 'Um die ersten 5 Zeilen der E-Mail zu erhalten',
+        'Sent new password to: ' => 'Das neue Passwort wurde gesendet an: ',
         'OTRS DB Password' => 'OTRS DB Passwort',
         'Last update' => 'Letzte nderungen',
         'not rated' => 'nicht bewertet',
         'to get the first 20 character of the subject' => 'Um die ersten 20 Zeichen des Betreffs zu erhalten',
+        'Select the customeruser:service relations.' => 'Auswahl der Kundenbenutzer:Service Beziehungen.',
         'DB Admin Password' => 'DB Admin Passwort',
         'Drop Database' => 'Datenbank lschen',
         'Options of the current customer user data (e. g. <OTRS_CUSTOMER_DATA_UserFirstname>)' => 'Die Daten der Kundenbenutzer (z. B. <OTRS_CUSTOMER_DATA_UserFirstname>)',
@@ -1452,11 +1491,14 @@ sub Data {
         'Finished' => 'Fertig',
         'Imported' => 'Importiert',
         'unread' => 'ungelesen',
+        'D' => 'D',
         'Split' => 'Teilen',
         'All messages' => 'Alle Nachrichten',
         'System Status' => 'System Status',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => 'Optionen des Tickets (z. B. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)',
+        'A required field is:' => 'Bitte fllen Sie das Pflichtfeld aus:',
         'A article should have a title!' => 'Ein Artikel sollte einen Titel haben!',
+        'Customer Users <-> Services' => 'Kunden Benutzer <-> Services',
         'Event' => 'Ereignis',
         'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => 'Einstellungen (z. B.&lt;OTRS_CONFIG_HttpType&gt;)',
         'Imported by' => 'Importiert von',
@@ -1469,18 +1511,22 @@ sub Data {
         'Solution' => 'Lsung',
         'QueueView' => 'Queue-Ansicht',
         'My Queue' => 'Meine Queue',
+        'Select Box' => 'Select Box',
         'Instance' => 'Instanz',
         'Day' => 'Tag',
         'Service-Name' => 'Service-Name',
         'Welcome to OTRS' => 'Willkommen zu OTRS',
         'tmp_lock' => 'gesperrt (temporr)',
         'modified' => 'gendert',
+        'Escalation in' => 'Eskalation in',
         'Delete old database' => 'Alte Datenbank lschen',
         'sort downward' => 'abwrts sortieren',
         'You need to use a ticket number!' => 'Bitte Ticket-Nummer benutzen!',
         'Watcher' => 'Beobachter',
+        'Have a lot of fun!' => 'Viel Spa!',
         'send' => 'Senden',
         'Note Text' => 'Notiztext',
+        'POP3 Account Management' => 'POP3-Konten Verwaltung',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => 'Einstellungen der Benutzerdaten des aktuellen Benutzers ((z. B. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;).',
         'System State Management' => 'Status Verwaltung',
         'PhoneView' => 'Telefon-Ansicht',
@@ -1488,6 +1534,17 @@ sub Data {
         'File-Path' => 'Datei-Dateipfad',
         'Modified' => 'Verndert',
         'Ticket selected for bulk action!' => 'Ticket fr Bulk-Aktion Ausgewhlt',
+
+        'Link Object: %s' => 'Verknpfung erstellen: %s',
+        'Unlink Object: %s' => 'Verknpfung aufheben: %s',
+        'Linked as' => 'Verknpft als',
+        'Can not create link with %s!' => 'Link zu %s konnte nicht erstellt werden!',
+        'Can not delete link with %s!' => 'Link zu %s konnte nicht gelscht werden!',
+        'Object already linked as %s.' => 'Objekt bereits verlinkt als %s.',
+        'Priority Management' => 'Prioritt Verwaltung',
+        'Add a new Priority.' => 'Eine neue Prioritt hinzufgen.',
+        'Add Priority' => 'Prioritt hinzufgen',
+        'Ticket Type is required!' => 'Das Feld Ticket-Typ ist ein Pflichtfeld!',
     };
     # $$STOP$$
     return;
