@@ -1,42 +1,38 @@
 # --
-# Kernel/Language/hu.pm - provides de language translation
-# Copyright (C) 2004 RLAN Internet <MAGIC at rlan.hu>
+# Kernel/Language/hu.pm - provides hu language translation
+# Copyright (C) 2006 Gabor Gancs /gg@magicnet.hu/
+# Copyright (C) 2006 Krisztian Gancs /krisz@gancs.hu/
+# Copyright (C) 2006 Flora Szabo /szaboflora@magicnet.hu/
+# Copyright (C) 2007 Aron Ujvari <ujvari@hungary.com>
 # --
-# $Id: hu.pm,v 1.41 2007/07/16 09:30:10 martin Exp $
-# Translation: Gabor Gancs /gg@magicnet.hu/ & Krisztian Gancs /krisz@gancs.hu/
-# Verify: Flora Szabo /szaboflora@magicnet.hu/
-# Hungary Sopron Europe
-#
-# Reviewed and adapted to OTRS v2.2 by Aron Ujvari <ujvari@hungary.com>
-#
+# $Id: hu.pm,v 1.56 2008/08/06 11:48:12 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Language::hu;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.41 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.56 $) [1];
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Tue May 29 15:15:50 2007
+    # Last translation file sync: Fri May 16 14:08:31 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-2', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%Y.%M.%D %T';
-    $Self->{DateFormatLong} = '%Y %B %D %A %T';
-    $Self->{DateFormatShort} = '%Y.%M.%D';
-    $Self->{DateInputFormat} = '%Y.%M.%D';
+    $Self->{DateFormat}          = '%Y.%M.%D %T';
+    $Self->{DateFormatLong}      = '%Y %B %D %A %T';
+    $Self->{DateFormatShort}     = '%Y.%M.%D';
+    $Self->{DateInputFormat}     = '%Y.%M.%D';
     $Self->{DateInputFormatLong} = '%Y.%M.%D - %T';
 
     $Self->{Translation} = {
@@ -112,6 +108,9 @@ sub Data {
         'Link' => 'Kapcsolat',
         'Unlink' => 'Kapcsolat feloldsa',
         'Linked' => 'Kapcsolat',
+        'Link (Normal)' => '',
+        'Link (Parent)' => '',
+        'Link (Child)' => '',
         'Normal' => 'Norml',
         'Parent' => 'Szl',
         'Child' => 'Gyerek',
@@ -205,7 +204,6 @@ sub Data {
         'Please contact your admin' => 'Krjk vegye fel a kapcsolatot a rendszergazdjval',
         'Logout successful. Thank you for using OTRS!' => 'Kilps megtrtnt! Ksznjk, hogy az OTRS-t hasznlja!',
         'Invalid SessionID!' => 'Hibs folyamat azonost!',
-        'SessionID invalid! Need user data!' => 'Hibs folyamat azonost! Felhasznli adatok megadsa szksges!',
         'Feature not active!' => 'Kpessg nem aktv!',
         'Login is needed!' => '',
         'Password is needed!' => '',
@@ -250,8 +248,9 @@ sub Data {
         'Mobile' => 'Mobil szm',
         'Zip' => 'Irnytszm',
         'City' => 'Vros',
-        'Country' => 'Orszg',
+        'Location' => '',
         'Street' => 'Utca',
+        'Country' => 'Orszg',
         'installed' => 'teleptett',
         'uninstalled' => 'nem teleptett',
         'Security Note: You should activate %s because application is already running!' => 'Biztonsgi megjegyzs: Aktivlnia kellene a %s modult, mert az alakalmazs mr fut!',
@@ -259,13 +258,23 @@ sub Data {
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => 'Nincsenek csomagok a krt Keretrendszerhez ebben az on-line csomagtrolban, viszont vannak ms Keretrendszerekhez!',
         'No Packages or no new Packages in selected Online Repository!' => 'Nincsenek csomagok vagy nincsenek j csomagok a kivlasztott on-line csomagtrolban!',
         'printed at' => '',
+        'Dear Mr. %s,' => '',
+        'Dear Mrs. %s,' => '',
+        'Dear %s,' => '',
+        'Hello %s,' => '',
+        'This account exists.' => '',
+        'New account created. Sent Login-Account to %s.' => '',
+        'Please press Back and try again.' => '',
+        'Sent password token to: %s' => '',
+        'Sent new password to: %s' => '',
+        'Invalid Token!' => '',
 
         # Template: AAAMonth
         'Jan' => 'Jan',
         'Feb' => 'Feb',
         'Mar' => 'Mr',
         'Apr' => 'pr',
-        'May' => 'Mj',
+        'May' => 'Mjus',
         'Jun' => 'Jn',
         'Jul' => 'Jl',
         'Aug' => 'Aug',
@@ -277,7 +286,6 @@ sub Data {
         'February' => 'Februr',
         'March' => 'Mrcius',
         'April' => 'prilis',
-        'May' => 'Mjus',
         'June' => 'Jnius',
         'July' => 'Jlius',
         'August' => 'Augusztus',
@@ -299,7 +307,6 @@ sub Data {
         'Admin' => 'Adminisztrci',
         'Customer Users' => 'gyfl felhasznlk',
         'Customer Users <-> Groups' => 'gyfl felhasznlk <-> Csoportok',
-        'Customer Users <-> Services' => 'gyfl felhasznlk <-> Szolgltatsok',
         'Users <-> Groups' => 'Felhasznlk <-> Csoportok',
         'Roles' => 'Szerepek',
         'Roles <-> Users' => 'Szerepek <-> Felhasznlk',
@@ -352,7 +359,6 @@ sub Data {
         'If you use a time scale element you can only select one element!' => 'Amennyiben egy idskla elemet is vlasztott, akkro csak egy elemet vlaszthat kzlk!',
         'You have an error in your time selection!' => 'Hibs a kivlasztott id!',
         'Your reporting time interval is too small, please use a larger time scale!' => 'A kivlasztott id intervallum tl kicsi, krem vlasszon nagyobb sklt.',
-        'Your reporting time interval is too small, please use a larger time scale!' => 'A kivlasztott id intervallum tl kicsi, krem vlasszon nagyobb sklt.',
         'The selected start time is before the allowed start time!' => 'A kivlasztott kezdsi id a megengedett kezdsi id eltt van!',
         'The selected end time is after the allowed end time!' => 'A kivlasztott befejezsi id a megengedett befejezsi id utn van!',
         'The selected time period is larger than the allowed time period!' => 'A kivlasztott ismtlds a megengedett ismtldsnl nagyobb!',
@@ -392,6 +398,7 @@ sub Data {
         'Move' => 'thelyezs',
         'Queue' => 'Vrlista',
         'Priority' => 'Priorits',
+        'Priority Update' => 'Priorits mdostsa',
         'State' => 'llapot',
         'Compose' => 'Kszt',
         'Pending' => 'Vrakozik',
@@ -559,6 +566,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Trtnet::gyflWebKrs',
         'History::TicketLinkAdd' => 'Trtnet::JegyCsatolsHozzads',
         'History::TicketLinkDelete' => 'Trtnet::JegyCsatolsTrls',
+        'History::Subscribe' => 'Added subscription for user "%s".',
+        'History::Unsubscribe' => 'Removed subscription for user "%s".',
 
         # Template: AAAWeekDay
         'Sun' => 'Vas',
@@ -588,14 +597,10 @@ sub Data {
         'Options of the current user who requested this action (e. g. <OTRS_CURRENT_UserFirstname>).' => 'A mveletet vgz felhasznlnak adatai (pl. <OTRS_CURRENT_UserFirstname>).',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_TicketID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>).' => 'A jegy adatai (pl. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_TicketID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>).',
         'Config options (e. g. <OTRS_CONFIG_HttpType>).' => 'Konfigurcis rtkek (pl.  <OTRS_CONFIG_HttpType>).',
-	'auto follow up' => 'automatikus vlasz',
-	'auto reject' => 'automatikus visszautasts',
-	'auto remove' => 'automatikus trls',
-	'auto reply' => 'automatikus vlasz',
-	'auto reply/new ticket' => 'automatikus vlasz/j jegy',
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => 'gyfl cgek kezelse',
+        'Search for' => 'Keresend',
         'Add Customer Company' => 'gyfl cg hozzadsa',
         'Add a new Customer Company.' => 'j gyfl cg hozzadsa',
         'List' => 'Lista',
@@ -604,7 +609,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'gyfl felhasznlk kezelse',
-        'Search for' => 'Keresend',
         'Add Customer User' => 'gyfl felhasznl hozzadsa',
         'Source' => 'Forrs',
         'Create' => 'Ltrehozs',
@@ -623,11 +627,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
-        # Template: AdminCustomerUserServiceChangeForm
+        # Template: AdminCustomerUserService
         'Customer Users <-> Services Management' => 'gyfl felhasznlk <-> Szolgltatsok kezelse',
-        'Select the customeruser:service relations.' => 'Vlassza ki az gyfl felhasznl:szolgltats relcit.',
-
-        # Template: AdminCustomerUserServiceForm
+        'CustomerUser' => 'gyfl felhasznl',
+        'Service' => 'Szolgltats',
+        'Edit default services.' => '',
+        'Search Result' => 'Keressi eredmny',
+        'Allocate services to CustomerUser' => '',
+        'Active' => 'Aktv',
+        'Allocate CustomerUser to service' => '',
 
         # Template: AdminEmail
         'Message sent to' => 'zenet elkldve',
@@ -650,6 +658,7 @@ sub Data {
         '(e. g. 234321)' => 'pl. 234321',
         'Customer User Login' => 'gyfl felhasznl belps',
         '(e. g. U5150)' => 'pl. U5150',
+        'SLA' => 'SLA',
         'Agent' => 'gyintz',
         'Ticket Lock' => 'Jegy zrols',
         'TicketFreeFields' => 'Jegy szabad mezi',
@@ -657,10 +666,16 @@ sub Data {
         'No create time settings.' => 'Nincsenek ltrehozsi id belltsok.',
         'Ticket created' => 'Jegy ltrehozva',
         'Ticket created between' => 'Jegy ltrehozva idpontok kztt:',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Pending Times' => 'Vrakozsi idk',
         'No pending time settings.' => 'Nincsenek vrakozsi id belltsok.',
         'Ticket pending time reached' => 'Vrakozsi id letelt',
         'Ticket pending time reached between' => 'Vrakozsi id letelt idpontok kztt:',
+        'New Service' => '',
+        'New SLA' => '',
         'New Priority' => 'j priorits',
         'New Queue' => 'j vrlista',
         'New State' => 'j llapot',
@@ -668,7 +683,9 @@ sub Data {
         'New Owner' => 'j tulajdonos',
         'New Customer' => 'j gyfl',
         'New Ticket Lock' => 'Jegy j zrolsi llapota',
-        'CustomerUser' => 'gyfl felhasznl',
+        'New Type' => '',
+        'New Title' => '',
+        'New Type' => '',
         'New TicketFreeFields' => 'j jegy szabad mezk',
         'Add Note' => 'Megjegyzs hozzadsa',
         'CMD' => 'PARANCS',
@@ -687,6 +704,7 @@ sub Data {
         'No means, send agent and customer notifications on changes.' => 'Nem esetn mind az gyintznek, mind az gyflnek kld rtestseket a vltozsokrl.',
         'Save' => 'Ments',
         '%s Tickets affected! Do you really want to use this job?' => '%s jegy rintett! Valban el akarja vgezni ezt a teendt a jegyeken?',
+        '"}' => '',
 
         # Template: AdminGroupForm
         'Group Management' => 'Csoportok kezelse',
@@ -700,6 +718,14 @@ sub Data {
         'System Log' => 'Rendszernapl',
         'Time' => 'Id',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => '',
+        'Host' => 'Kiszolgl',
+        'Trusted' => 'Megbzhat',
+        'Dispatching' => 'Sztvlogats',
+        'All incoming emails with one account will be dispatched in the selected queue!' => 'Az sszes fikkal rendelkez bejv e-mail egy kivlasztott vrlisthoz lesz rendelve!',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => 'Ha az n fikja megbzhat, a mr ltez X-OTRS fejlcet hasznljuk berkezskor (prioritshoz, ...)! Egyb esetben a levelezsi szrk lesznek alkalmazva.',
+
         # Template: AdminNavigationBar
         'Users' => 'Felhasznlk',
         'Groups' => 'Csoportok',
@@ -717,7 +743,6 @@ sub Data {
         'Do you really want to uninstall this package?' => 'Valban el akarja tvoltani ezt a csomagot?',
         'Reinstall' => 'jratelepts',
         'Do you really want to reinstall this package (all manual changes get lost)?' => 'Valban jra kvnja telepteni ezt a csomagot (minden megvltoztatott bellts elvsz)?',
-        'Cancel' => 'Mgsem',
         'Continue' => 'Folytats',
         'Install' => 'Telepts',
         'Package' => 'Csomag',
@@ -755,6 +780,10 @@ sub Data {
         'Min Response' => '',
         'Max Response' => '',
         'Average Response' => '',
+        'Period' => '',
+        'Min' => '',
+        'Max' => '',
+        'Average' => '',
 
         # Template: AdminPGPForm
         'PGP Management' => 'PGP kulcs kezelse',
@@ -766,17 +795,7 @@ sub Data {
         'Expires' => 'Lejrati id',
         'In this way you can directly edit the keyring configured in SysConfig.' => 'gy kzvetlenl szerkesztheti a kulcstartt amit a rendszer belltsainl belltott.',
 
-        # Template: AdminPOP3
-        'PostMaster POP3 Account' => 'Levelezsi fikok (POP3)',
-        'POP3 Account Management' => 'Levelezsi POP3 fikok kezelse',
-        'Host' => 'Kiszolgl',
-        'Trusted' => 'Megbzhat',
-        'Dispatching' => 'Sztvlogats',
-        'All incoming emails with one account will be dispatched in the selected queue!' => 'Az sszes fikkal rendelkez bejv e-mail egy kivlasztott vrlisthoz lesz rendelve!',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => 'Ha az n fikja megbzhat, a mr ltez X-OTRS fejlcet hasznljuk berkezskor (prioritshoz, ...)! Egyb esetben a levelezsi szrk lesznek alkalmazva.',
-
         # Template: AdminPostMasterFilter
-        'PostMaster Filter' => 'Levelezsi szrk',
         'PostMaster Filter Management' => 'Levelezsi szrk kezelse',
         'Filtername' => 'Szr neve',
         'Match' => 'Egyezs',
@@ -795,9 +814,13 @@ sub Data {
         'Sub-Queue of' => 'Vrlista al tartozik',
         'Unlock timeout' => 'Feloldsi idtllps',
         '0 = no unlock' => '0 = nincs felolds',
+        'Only business hours are counted.' => '',
         'Escalation - First Response Time' => 'Kiemels - Els vlasz ideje',
         '0 = no escalation' => '0 = nincs kiemels',
+        'Only business hours are counted.' => '',
+        'Notify by' => '',
         'Escalation - Update Time' => 'Kiemels - Frissts ideje',
+        'Notify by' => '',
         'Escalation - Solution Time' => 'Kiemels - Megolds ideje',
         'Follow up Option' => 'Vlasz kezelse',
         'Ticket lock after a follow up' => 'Jegy zrolsa vlasz rkezse utn.',
@@ -857,7 +880,6 @@ sub Data {
 
         # Template: AdminRoleUserChangeForm
         'Roles <-> Users Management' => 'Szerepek <-> Felhasznlk kezelse',
-        'Active' => 'Aktv',
         'Select the role:user relations.' => 'Vlassza ki a szerep:felhasznl kapcsolatokat.',
 
         # Template: AdminRoleUserForm
@@ -869,7 +891,6 @@ sub Data {
 
         # Template: AdminSelectBoxForm
         'SQL Box' => 'SQL parancsok',
-        'Select Box' => 'SQL lekrdezs',
         'Limit' => 'Sorok szma legfeljebb',
         'Go' => 'Indts',
         'Select Box Result' => 'SQL parancs eredmnye',
@@ -878,7 +899,6 @@ sub Data {
         'Service Management' => 'Szolgltatsok kezelse',
         'Add Service' => 'Szolgltats hozzadsa',
         'Add a new Service.' => 'j szolgltats hozzadsa',
-        'Service' => 'Szolgltats',
         'Sub-Service of' => 'Szolgtatsa al tartozik',
 
         # Template: AdminSession
@@ -899,10 +919,6 @@ sub Data {
         'SLA Management' => 'SLA kezelse',
         'Add SLA' => 'SLA hozzadsa',
         'Add a new SLA.' => 'j SLA hozzadsa',
-        'SLA' => 'SLA',
-        'First Response Time' => 'Els vlaszid',
-        'Update Time' => 'Frissts ideje',
-        'Solution Time' => 'Megolds ideje',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => 'S/MIME kezels',
@@ -910,7 +926,6 @@ sub Data {
         'Add Private Key' => 'Titkos Kulcs Hozadsa',
         'Secret' => 'Titok',
         'Hash' => 'Kivonat',
-        'S/MIME' => 'S/MIME',
         'In this way you can directly edit the certification and private keys in file system.' => 'ly mdon kzvetlenl szerkesztheti a fjlrendszeren trolt tanustvnyokat s titkos kulcsokat.',
 
         # Template: AdminStateForm
@@ -1058,7 +1073,7 @@ sub Data {
         'Scale' => 'Skla',
         'minimal' => '',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => '',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => 'Itt kivlaszthatja a grafikonon megjelen rtkeket. Egy vagy kt tulajdonsgot jellhet ki. Utn kivlaszthatja a tulajdonsg rtkeit. Minden rtk kln kerl brzolsra a grafikonon. Ha nem vlaszt ki egyetlen rtket sem a tulajdonsghoz, akkor az sszes rtk hasznlva lesz a statisztika ltrehozsakor. Szintn hozzadsra kerlnek a legutbbi bellts ta ltrejtt j rtkek is.',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => 'Itt kivlaszthatja a grafikonon megjelen rtkeket. Egy vagy kt tulajdonsgot jellhet ki. Utn kivlaszthatja a tulajdonsg rtkeit. Minden rtk kln kerl brzolsra a grafikonon. Ha nem vlaszt ki egyetlen rtket sem a tulajdonsghoz, akkor az sszes rtk hasznlva lesz a statisztika ltrehozsakor. Szintn hozzadsra kerlnek a legutbbi bellts ta ltrejtt j rtkek is.',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => 'Vlassza ki a tulajdonsgot, amely az X tengelyen fog megjelenni.',
@@ -1080,7 +1095,7 @@ sub Data {
 
         # Template: AgentStatsView
         'Export Config' => 'Belltsok exportlsa',
-        'Informations about the Stat' => 'Informci a statisztikrl',
+        'Information about the Stat' => 'Informci a statisztikrl',
         'Exchange Axis' => 'Tengelyek flcserlse',
         'Configurable params of static stat' => '',
         'No element selected.' => 'Nincsenek ertkek kivlasztva.',
@@ -1138,6 +1153,17 @@ sub Data {
         'Refresh' => 'Frissts',
         'Clear To' => 'Mez trlse',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => '',
+        'Escalation' => '',
+        'Today' => '',
+        'Tomorrow' => '',
+        'Next Week' => '',
+        'up' => 'fel',
+        'down' => 'le',
+        'Escalation' => '',
+        'Locked' => 'Zrols',
+
         # Template: AgentTicketForward
         'Article type' => 'Bejegyzs tpusa',
 
@@ -1158,8 +1184,6 @@ sub Data {
         'Reminder' => 'Emlkeztet',
         'Sort by' => 'Rendezs gy',
         'Order' => 'Sorrend',
-        'up' => 'fel',
-        'down' => 'le',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => 'Jegy egyestse',
@@ -1189,7 +1213,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => 'Jegy informci',
         'Accounted time' => 'Elszmolt id',
-        'Escalation in' => 'Kiemels ebben',
+        'First Response Time' => 'Els vlaszid',
+        'Update Time' => 'Frissts ideje',
+        'Solution Time' => 'Megolds ideje',
         'Linked-Object' => 'Kapcsold objektum',
         'Parent-Object' => 'Szl objektum',
         'Child-Object' => 'Gyerek objektum',
@@ -1224,27 +1250,36 @@ sub Data {
         'Search-Template' => 'Keres sablon',
         'TicketFreeText' => 'Jegy szabadszveg',
         'Created in Queue' => 'Ltrehozskori vrlista',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Result Form' => 'Eredmny rlap',
         'Save Search-Profile as Template?' => 'Elmenti a keres profilt sablonknt?',
         'Yes, save it with name' => 'Igen, elmentve ezen a nven',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
-        'Search Result' => 'Keressi eredmny',
         'Change search options' => 'Keressi belltsok mdostsa',
 
+        # Template: AgentTicketSearchResultPrint
+        '"}' => '',
+
         # Template: AgentTicketSearchResultShort
-        'U' => 'A',
-        'D' => 'Z',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => 'Jegy llapotnak megtekintse',
         'Open Tickets' => 'Jegyek megnyitsa',
-        'Locked' => 'Zrols',
 
         # Template: AgentTicketZoom
+        'Expand View' => '',
+        'Collapse View' => '',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1312,15 +1347,18 @@ sub Data {
 
         # Template: Installer
         'Web-Installer' => 'Web-telept',
+        'Welcome to %s' => 'dvzli az %s',
         'Accept license' => 'Lincensz elfogadsa',
         'Don\'t accept license' => 'Licensz elutastsa',
         'Admin-User' => 'Adminisztrtor felhasznl',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => '',
         'Admin-Password' => 'Adminisztrtor jelsz',
-        'your MySQL DB should have a root password! Default is empty!' => 'Az n MySQL adatbzisnak kell legyen root jelszava! Az alaprtelmezett res!',
         'Database-User' => 'Adatbzis felhasznl',
         'default \'hot\'' => 'alaprtelmezett',
         'DB connect host' => 'Adatbzis kiszolgl',
         'Database' => 'Adatbzis',
+        'Default Charset' => 'Alaprtelmezett karakterkszlet',
+        'utf8' => '',
         'false' => 'hamis',
         'SystemID' => 'Rendszer azonost',
         '(The identify of the system. Each ticket number and each http session id starts with this number)' => '(Azonosts a rendszerben. Minden jegyhez s minden http eljrs ezzel a sorszmmal indul)',
@@ -1335,7 +1373,6 @@ sub Data {
         'Logfile' => 'Log file',
         '(Logfile just needed for File-LogModule!)' => '(Logfile szksges a File-LogModul szmra!)',
         'Webfrontend' => 'Webes felhasznli fellet',
-        'Default Charset' => 'Alaprtelmezett karakterkszlet',
         'Use utf-8 it your database supports it!' => 'Hasznld utf-8-at az adatbzis tmogatsoknl!',
         'Default Language' => 'Alaprtelmezett nyelv',
         '(Used default language)' => '(A felhasznl alaprtelmezett nyelve)',
@@ -1345,11 +1382,9 @@ sub Data {
         'Restart your webserver' => 'Indtsa jra a web-kiszolglt',
         'After doing so your OTRS is up and running.' => 'Ha ez ksz, az OTRS ksz s fut.',
         'Start page' => 'Start oldal',
-        'Have a lot of fun!' => 'Sok sikert!',
         'Your OTRS Team' => 'Az n OTRS csapata',
 
         # Template: Login
-        'Welcome to %s' => 'dvzli az %s',
 
         # Template: Motd
 
@@ -1373,27 +1408,31 @@ sub Data {
 
         # Template: Warning
         # Misc
+        'auto follow up' => 'automatikus vlasz',
         'Create Database' => 'Adatbzis ltrehozsa',
         'verified' => 'ellenrztt',
         'File-Name' => '',
         'Ticket Number Generator' => 'Jegy sorszm genertor',
         '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(Jegy azonosts. pl. \'Jegy#\', \'Hv#\' vagy \'Jegyem#\')',
-        'Create new Phone Ticket' => 'j telefon jegy ltrehozsa',
         'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'ly mdon kzvetlenl szerkesztheti a Kernel/Config.pm-ben belltott kulcskarikt.',
+        'Create new Phone Ticket' => 'j telefon jegy ltrehozsa',
+        'U' => 'A',
         'A message should have a To: recipient!' => 'Egy zenethez kellene legyen cmzett!',
         'Site' => 'Gp',
+        'Reset of unlock time.' => 'Feloldsi id nullzsa.',
         'Customer history search (e. g. "ID342425").' => 'Keress az gyfl trtnetben (pl. "ID342425").',
-        'for agent firstname' => 'gyintz keresztnvhez',
         'Close!' => 'Lezr!',
+        'for agent firstname' => 'gyintz keresztnvhez',
         'Reporter' => '',
-        'Process-Path' => '',
         'The message being composed has been closed.  Exiting.' => 'Az ppen elkszlt levl lezrsra kerlt. Kilps.',
+        'Process-Path' => '',
         'to get the realname of the sender (if given)' => 'hogy megkapja a felad valdi nevt (ha lehetsges)',
         'FAQ Search Result' => '',
         'Notification (Customer)' => 'rtests (gyfl)',
         'Select Source (for add)' => 'Vlassza ki a forrst (hozzadshoz)',
         'Node-Name' => '',
         'Options of the ticket data (e. g. &lt;OTRS_TICKET_Number&gt;, &lt;OTRS_TICKET_ID&gt;, &lt;OTRS_TICKET_Queue&gt;, &lt;OTRS_TICKET_State&gt;)' => '',
+        'Agent updated!' => 'gyintz mdostva!',
         'Home' => 'Otthon',
         'Workflow Groups' => '',
         'Current Impact Rating' => '',
@@ -1401,6 +1440,7 @@ sub Data {
         'FAQ System History' => '',
         'customer realname' => 'gyfl valdi nv',
         'Pending messages' => 'Vrakoz zenetek',
+        'auto reply/new ticket' => 'automatikus vlasz/j jegy',
         'Modules' => 'Modul',
         'for agent login' => 'gyintz belpshez',
         'Keyword' => 'Kulcssz',
@@ -1417,23 +1457,28 @@ sub Data {
         'not verified' => 'nem ellenrztt',
         'Stat#' => 'Stat#',
         'Create new database' => 'j adatbzis ltrehozsa',
+        'auto reject' => 'automatikus visszautasts',
         'Year' => 'v',
         'A message must be spell checked!' => 'Az zenetnek helyesrsellenrzsen kell tmennie!',
         'X-axis' => 'X tengely',
-        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => 'Az n "<OTRS_TICKET>" szm jegyhez rendelt e-mailje visszakldsre kerlt a "<OTRS_BOUNCE_TO>" cmre. Vegye fel ezzel a cmmel a kapcsolatot tovbbi informcikrt.',
+        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'Az n "<OTRS_TICKET>" szm jegyhez rendelt e-mailje visszakldsre kerlt a "<OTRS_BOUNCE_TO>" cmre. Vegye fel ezzel a cmmel a kapcsolatot tovbbi informcikrt.',
         'A message should have a body!' => 'Egy zenetnek kell legyen trzse!',
         'All Agents' => 'Minden gyintz',
         'Keywords' => 'Kulcssz',
         'No * possible!' => 'A "*" nem lehetsges!',
         'Load' => 'Betlts',
         'Change Time' => 'Id megvltoztatsa',
+        'PostMaster Filter' => 'Levelezsi szrk',
         'Options of the current user who requested this action (e. g. &lt;OTRS_CURRENT_USERFIRSTNAME&gt;)' => '',
+        'PostMaster POP3 Account' => 'Levelezsi fikok (POP3)',
         'Message for new Owner' => 'zenet az j tulajdonosnak',
         'to get the first 5 lines of the email' => 'hogy megkapja az els 5 sort az e-mailbl',
+        'Default Sign Key' => 'Alaprtelmezett alr kulcs',
         'OTRS DB Password' => 'OTRS DB jelsz',
         'Last update' => 'Utols frissts',
         'not rated' => '',
         'to get the first 20 character of the subject' => 'hogy megkapja az els 20 karaktert a trgybl',
+        'Select the customeruser:service relations.' => 'Vlassza ki az gyfl felhasznl:szolgltats relcit.',
         'DB Admin Password' => 'DB Admin jelsz',
         'Drop Database' => 'Adatbzis trlse',
         'Options of the current customer user data (e. g. <OTRS_CUSTOMER_DATA_UserFirstname>)' => 'Opcik az aktulis gyfl felhasznli adatokhoz (pl. <OTRS_CUSTOMER_DATA_UserFirstname>)',
@@ -1443,10 +1488,13 @@ sub Data {
         'This window must be called from compose window' => 'Ezt az ablakot a szerkeszt ablakbl kell hvni',
         'User-Number' => '',
         'You need min. one selected Ticket!' => 'Legalbb egy jegyet ki kell vlasztani!',
+        'Reset of escalation time.' => 'Kiemelsi id nullzsa.',
+        'System Address updated!' => 'Rendszer cm mdostva!',
         'Options of the ticket data (e. g. <OTRS_TICKET_Number>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => '',
         '(Used ticket number format)' => '(Nyitott jegyek sorszmnak formtuma)',
         'Fulltext' => 'Teljes szveg',
         'Month' => 'Hnap',
+        'SessionID invalid! Need user data!' => 'Hibs folyamat azonost! Felhasznli adatok megadsa szksges!',
         'Node-Address' => '',
         'All Agent variables.' => '',
         ' (work units)' => ' (munkaegysg)',
@@ -1467,13 +1515,16 @@ sub Data {
         'Imported' => '',
         'unread' => 'olvasatlan',
         'Split' => 'Feloszts',
-        'All messages' => 'Minden zenet',
+        'D' => 'Z',
         'System Status' => 'Rendszer llapota',
+        'All messages' => 'Minden zenet',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => 'A jegy adatai (pl.  <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)',
         'A article should have a title!' => 'Egy bejegyzsnek kell legyen cme!',
-        'Event' => 'Esemny',
+        'Customer Users <-> Services' => 'gyfl felhasznlk <-> Szolgltatsok',
         'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => 'Konfigurcis rtkek (pl. &lt;OTRS_CONFIG_HttpType&gt;)',
+        'Event' => 'Esemny',
         'Imported by' => '',
+        'S/MIME' => 'S/MIME',
         'Ticket owner options (e. g. <OTRS_OWNER_UserFirstname>)' => 'Jegy tulajdonos opcik (pl. <OTRS_OWNER_UserFirstname>)',
         'read' => 'olvasott',
         'Product' => 'Termk',
@@ -1481,20 +1532,26 @@ sub Data {
         'kill all sessions' => 'Minden eljrs kilvse',
         'to get the from line of the email' => 'hogy megkapja a feladt az e-mailbl',
         'Solution' => 'Megolds',
+        'auto reply' => 'automatikus vlasz',
         'QueueView' => 'Vrlista nzet',
         'My Queue' => 'Sajt vrlistm',
+        'Select Box' => 'SQL lekrdezs',
         'Instance' => '',
         'Day' => 'Nap',
+        'auto remove' => 'automatikus trls',
         'Service-Name' => 'Szolgltats neve',
         'Welcome to OTRS' => 'dvzli az OTRS',
         'tmp_lock' => 'ideiglenesen zrolt',
         'modified' => 'mdostott',
+        'Escalation in' => 'Kiemels ebben',
         'Delete old database' => 'Rgi adatbzis trlse',
         'sort downward' => 'rendezs lefel',
         'You need to use a ticket number!' => 'Adja meg egy jegy szmt!',
         'Watcher' => '',
+        'Have a lot of fun!' => 'Sok sikert!',
         'send' => 'klds',
         'Note Text' => 'Jegyzet szveg',
+        'POP3 Account Management' => 'Levelezsi POP3 fikok kezelse',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => 'Az aktulis gyfl felhasznl adatai (pl. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)',
         'System State Management' => 'Rendszerllapot kezels',
         'PhoneView' => 'TelefonNzet',
@@ -1503,15 +1560,17 @@ sub Data {
         'Modified' => 'Mdostva',
         'Ticket selected for bulk action!' => 'Jegy kivlasztva csoportos mvelethez!',
 
-         # Extra
-         'Priority Update' => 'Priorits mdostsa',
-	 'Agent updated!' => 'gyintz mdostva!',
-	 'System Address updated!' => 'Rendszer cm mdostva!',
-	 'Reset of escalation time.' => 'Kiemelsi id nullzsa.',
-	 'Reset of unlock time.' => 'Feloldsi id nullzsa.',
-	 'Default Sign Key' => 'Alaprtelmezett alr kulcs'
+        'Link Object: %s' => '',
+        'Unlink Object: %s' => '',
+        'Linked as' => '',
+        'Can not create link with %s!' => '',
+        'Can not delete link with %s!' => '',
+        'Object already linked as %s.' => '',
+        'Priority Management' => '',
+        'Add a new Priority.' => '',
+        'Add Priority' => '',
+        'Ticket Type is required!' => '',
     };
-
     # $$STOP$$
     return;
 }
