@@ -1,11 +1,11 @@
 # --
 # Kernel/Language/nb_NO.pm - Norwegian language translation (bokml)
 # Copyright (C) 2004 Arne Georg Gleditsch <argggh at linpro.no>
-#               2005 Stefansen Espen <espen.stefansen at imr.no>
-#               2006 Knut Haugen <knuthaug at linpro.no>
-#               2007 Fredrik Andersen <fredrik.andersen at husbanken.no>
+# Copyright (C) 2005 Stefansen Espen <espen.stefansen at imr.no>
+# Copyright (C) 2006 Knut Haugen <knuthaug at linpro.no>
+# Copyright (C) 2007-2008 Fredrik Andersen <fredrik.andersen at husbanken.no>
 # --
-# $Id: nb_NO.pm,v 1.46.2.2 2008/05/28 08:03:42 tr Exp $
+# $Id: nb_NO.pm,v 1.65 2008/08/06 11:48:12 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,25 +15,24 @@
 package Kernel::Language::nb_NO;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = q$Revision: 1.46.2.2 $;
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = q$Revision: 1.65 $;
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Mon Jul 16 12:05:41 2007
+    # Last translation file sync: Fri May 16 14:08:39 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%D/%M %Y %T';
-    $Self->{DateFormatLong} = '%A %D. %B %Y %T';
-    $Self->{DateFormatShort} = '%D.%M.%Y';
-    $Self->{DateInputFormat} = '%D.%M.%Y';
+    $Self->{DateFormat}          = '%D/%M %Y %T';
+    $Self->{DateFormatLong}      = '%A %D. %B %Y %T';
+    $Self->{DateFormatShort}     = '%D.%M.%Y';
+    $Self->{DateInputFormat}     = '%D.%M.%Y';
     $Self->{DateInputFormatLong} = '%D.%M.%Y - %T';
 
     $Self->{Translation} = {
@@ -100,7 +99,7 @@ sub Data {
         'Back' => 'Tilbake',
         'Next...' => 'Neste...',
         '...Back' => '...Tilbake',
-        '-none-' => '-ingen',
+        '-none-' => '-ingen-',
         'none' => 'ingen',
         'none!' => 'ingen!',
         'none - answered' => 'ingen - besvart',
@@ -227,7 +226,7 @@ sub Data {
         'Cc: (%s) added database email!' => 'Cc: (%s) la til database-epost!',
         '(Click here to add)' => '(Klikk her for  legge til)',
         'Preview' => 'Forhndsvisning',
-        'Package not correctly deployed! You should reinstall the Package again!' => 'Pakken er ikke installert korrekt! Du burde reinstallere pakken igjen!',
+        'Package not correctly deployed! You should reinstall the Package again!' => 'Pakken er ikke installert korrekt! Du br reinstallere pakken igjen!',
         'Added User "%s"' => 'Lagt til bruker "%s"',
         'Contract' => 'Kontrakt',
         'Online Customer: %s' => 'Plogget kunde: %s',
@@ -249,6 +248,7 @@ sub Data {
         'Mobile' => 'Mobil',
         'Zip' => 'Postnummer',
         'City' => 'By',
+        'Location' => 'Kart',
         'Street' => 'Gate',
         'Country' => 'Land',
         'installed' => 'installert',
@@ -258,6 +258,16 @@ sub Data {
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => 'Ingen pakker ble funnet for det nskede rammeverket i online bibliotek, men pakker for andre rammeverk ble funnet!',
         'No Packages or no new Packages in selected Online Repository!' => 'Ingen pakker, eller ingen nye pakker i valgte online bibliotek!',
         'printed at' => 'skrevet ut p',
+        'Dear Mr. %s,' => 'Kjre %s',
+        'Dear Mrs. %s,' => 'Kjre %s',
+        'Dear %s,' => 'Kjre %s',
+        'Hello %s,' => 'Kjre %s',
+        'This account exists.' => 'Kontoen finnes allerede',
+        'New account created. Sent Login-Account to %s.' => 'Ny konto opprettet. Login-konto sendt til %s',
+        'Please press Back and try again.' => 'Vennligst g tilbake og prv p nytt',
+        'Sent password token to: %s' => 'Passord-bevis sendt til: %s',
+        'Sent new password to: %s' => 'Sendt nytt passord til: %s',
+        'Invalid Token!' => 'Ugyldig bevis!',
 
         # Template: AAAMonth
         'Jan' => 'jan',
@@ -556,6 +566,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Kundeforesprsel via web.',
         'History::TicketLinkAdd' => 'La til link til sak "%s".',
         'History::TicketLinkDelete' => 'Slettet link til sak "%s".',
+        'History::Subscribe' => 'Added subscription for user "%s".',
+        'History::Unsubscribe' => 'Removed subscription for user "%s".',
 
         # Template: AAAWeekDay
         'Sun' => 'sn',
@@ -588,6 +600,7 @@ sub Data {
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => 'Administrasjon av kundebedrifter',
+        'Search for' => 'Sk etter',
         'Add Customer Company' => 'Legg til kundebedrift',
         'Add a new Customer Company.' => 'Legg til en ny kundebedrift',
         'List' => 'Liste',
@@ -596,7 +609,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'Administrasjon av kunde-brukere',
-        'Search for' => 'Sk etter',
         'Add Customer User' => 'Legg til kundebruker',
         'Source' => 'Kilde',
         'Create' => 'Opprett',
@@ -617,26 +629,17 @@ sub Data {
 
         # Template: AdminCustomerUserService
         'Customer Users <-> Services Management' => 'Kunde <-> Tjenesteadministrasjon',
-        'CustomerUser' => 'Kunde-bruker',
+        'CustomerUser' => 'Kundebruker',
         'Service' => 'Tjeneste',
+        'Edit default services.' => 'Endre standardtjenester',
         'Search Result' => 'Skeresultat',
-        'Allocate services to CustomerUser' => 'Tilordne tjenester til kunde-bruker',
-        'Active' => 'Aktiv',
-        'Allocate CustomerUser to service' => 'Tilordne kunde-bruker til tjeneste',
-
-        # Template: AdminCustomerUserServiceChangeForm
-        'Customer Users <-> Services Management' => 'Kunde <-> Tjenesteadministrasjon',
-        'Select the customeruser:service relations.' => '',
-        'Allocate services to CustomerUser' => 'Tilordne tjenester til kunde-bruker',
-        'Allocate CustomerUser to service' => 'Tilordne kunde-bruker til tjeneste',
-        'CustomerUser' => 'Kunde-bruker',
+        'CustomerUser' => 'Kundebruker',
         'Service' => 'Tjeneste',
-        'Search Result' => 'Skeresultat',
+        'Allocate services to CustomerUser' => 'Tilordne tjenester til kundebruker',
+        'Active' => 'Aktivere',
+        'Allocate CustomerUser to service' => 'Tilordne kundebruker til tjeneste',
         'Active' => 'Aktiv',
 
-        # Template: AdminCustomerUserServiceForm
-        'Edit default services.' => '',
-
         # Template: AdminEmail
         'Message sent to' => 'Melding sendt til',
         'Recipents' => 'Mottager(e)',
@@ -658,6 +661,7 @@ sub Data {
         '(e. g. 234321)' => 'f.eks. 234321',
         'Customer User Login' => 'Kunde-bruker login-navn',
         '(e. g. U5150)' => 'f.eks. U5150',
+        'SLA' => 'SLA',
         'Agent' => 'Agent',
         'Ticket Lock' => 'Saks-ls',
         'TicketFreeFields' => 'SakTilgjengeligeFelter',
@@ -665,10 +669,16 @@ sub Data {
         'No create time settings.' => 'Ingen opprettelsestidspunkt innstillinger.',
         'Ticket created' => 'Sak opprettet',
         'Ticket created between' => 'Sak opprettet mellom',
+        'Close Times' => 'Stengetider',
+        'No close time settings.' => 'Ingen stengetid innstillinger',
+        'Ticket closed' => 'Sak lst',
+        'Ticket closed between' => 'Sak lst mellom',
         'Pending Times' => 'Ventetid',
         'No pending time settings.' => 'Ingen innstillinger for ventetid.',
         'Ticket pending time reached' => 'Ventetiden er ndd',
         'Ticket pending time reached between' => 'Ventetiden er ndd mellom',
+        'New Service' => 'Ny Tjeneste',
+        'New SLA' => 'Ny SLA',
         'New Priority' => 'Ny prioritet',
         'New Queue' => 'Ny mappe',
         'New State' => 'Ny status',
@@ -676,6 +686,9 @@ sub Data {
         'New Owner' => 'Ny saksbehandler',
         'New Customer' => 'Ny kunde',
         'New Ticket Lock' => 'Ny saks-ls',
+        'New Type' => 'Ny type',
+        'New Title' => 'Ny tittel',
+        'New Type' => 'Ny type',
         'New TicketFreeFields' => 'Ny SakTilgjengeligFelter',
         'Add Note' => 'Legg til notis',
         'CMD' => 'Kommando',
@@ -708,6 +721,14 @@ sub Data {
         'System Log' => 'Systemlogg',
         'Time' => 'Tid',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => 'Epost konto administrasjon',
+        'Host' => 'Maskin',
+        'Trusted' => 'Betrodd',
+        'Dispatching' => 'Fordeling',
+        'All incoming emails with one account will be dispatched in the selected queue!' => 'Innkommende e-poster fra POP3-kontoer blir sortert til valgt mappe!',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => 'Dersom kontoen er betrodd vil de eksisterende X-OTRS headere ved ankomst (for proritet...) bli brukt. PostMaster filtre vil bli brukt uansett.',
+
         # Template: AdminNavigationBar
         'Users' => 'Saksbehandlere',
         'Groups' => 'Grupper',
@@ -762,6 +783,10 @@ sub Data {
         'Min Response' => 'Min Respons',
         'Max Response' => 'Max Respons',
         'Average Response' => 'Gjennomsnittlig Respons',
+        'Period' => 'Periode',
+        'Min' => 'Min',
+        'Max' => 'Max',
+        'Average' => 'Gjennomsnitt',
 
         # Template: AdminPGPForm
         'PGP Management' => 'PGP-innstillinger',
@@ -773,14 +798,6 @@ sub Data {
         'Expires' => 'Utgr',
         'In this way you can directly edit the keyring configured in SysConfig.' => 'P denne mten kan du direkte redigere keyringen som er konfigurert i SysConfig',
 
-        # Template: AdminPOP3
-        'POP3 Account Management' => 'Administrasjon: POP3-Konto',
-        'Host' => 'Maskin',
-        'Trusted' => 'Betrodd',
-        'Dispatching' => 'Fordeling',
-        'All incoming emails with one account will be dispatched in the selected queue!' => 'Innkommende e-poster fra POP3-kontoer blir sortert til valgt mappe!',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => 'Dersom kontoen er betrodd vil de eksisterende X-OTRS headere ved ankomst (for proritet...) bli brukt. PostMaster filtre vil bli brukt uansett.',
-
         # Template: AdminPostMasterFilter
         'PostMaster Filter Management' => 'Administrasjon: E-postfilter',
         'Filtername' => 'Filternavn',
@@ -800,9 +817,13 @@ sub Data {
         'Sub-Queue of' => 'Undermappe av',
         'Unlock timeout' => 'Tidsintervall for  sette sak tilgjengelig for andre',
         '0 = no unlock' => '0 = ikke gjr saker tilgjengelig',
+        'Only business hours are counted.' => 'Kun timene i pningstiden telles',
         'Escalation - First Response Time' => 'Eskalering - frste responstid',
         '0 = no escalation' => '0 = ingen eskalering',
+        'Only business hours are counted.' => 'Kun timene i pningstiden telles',
+        'Notify by' => 'Varsle med',
         'Escalation - Update Time' => 'Eskalering - oppdateringstid',
+        'Notify by' => 'Varsle med',
         'Escalation - Solution Time' => 'Eskalering - lsningstid',
         'Follow up Option' => 'Korrespondanse p avsluttet sak',
         'Ticket lock after a follow up' => 'Saken settes som privat etter oppflgnings e-post',
@@ -872,7 +893,7 @@ sub Data {
         'Add a new Salutation.' => 'Legg til en ny hilsning.',
 
         # Template: AdminSelectBoxForm
-        'Select Box' => 'SQL-tilgang',
+        'SQL Box' => 'SQL boks',
         'Limit' => 'Grense',
         'Go' => 'Kjr',
         'Select Box Result' => 'Select Box-resultat',
@@ -901,10 +922,6 @@ sub Data {
         'SLA Management' => 'SLA administrasjon',
         'Add SLA' => 'Legg til SLA',
         'Add a new SLA.' => 'Legg til en ny SLA',
-        'SLA' => 'SLA',
-        'First Response Time' => 'Frste responstid',
-        'Update Time' => 'Oppdateringstid',
-        'Solution Time' => 'Lsningstid',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => 'Administrasjon: S/MIME',
@@ -1009,11 +1026,9 @@ sub Data {
         'Apply these changes' => 'Iverksett endringer',
 
         # Template: AgentStatsDelete
-        'Stat#' => 'Stat#',
         'Do you really want to delete this Object?' => 'Vil du virkelig slette dette objektet?',
 
         # Template: AgentStatsEditRestrictions
-        'Stat#' => 'Stat#',
         'Select the restrictions to characterise the stat' => 'Velg restriksjonene for  karakterisere statistikken',
         'Fixed' => 'Fast',
         'Please select only one element or turn off the button \'Fixed\'.' => 'Vennligst velg kun ett element, eller deaktiver \'Fast\' knappen',
@@ -1061,7 +1076,7 @@ sub Data {
         'Scale' => 'Skala',
         'minimal' => 'minimal',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => 'Bemerk at skalaen for verdieserien m vre strre enn skalaen til X-aksen (f.eks. X-akse => mned, verdiserie => r).',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => 'Her kan du sette verdiserien. Du har muligheten til  velge en eller flere elementer, og deretter kan du velge attributtene til elementene. Hver attributt vil bli vist som en egen verdiserie. Dersom du ikke velge noen attributter, vil alle attributtene bli brukt nr statistikken genereres. I tillegg vil nye attributter som er lagt til etter konfigurasjonen av statistikken ogs vises.',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => 'Her kan du sette verdiserien. Du har muligheten til  velge en eller flere elementer, og deretter kan du velge attributtene til elementene. Hver attributt vil bli vist som en egen verdiserie. Dersom du ikke velge noen attributter, vil alle attributtene bli brukt nr statistikken genereres. I tillegg vil nye attributter som er lagt til etter konfigurasjonen av statistikken ogs vises.',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => 'Velg et element som skal brukes p X-aksen',
@@ -1092,12 +1107,6 @@ sub Data {
         'Start' => 'Start',
         'With the input and select fields you can configurate the stat at your needs. Which elements of a stat you can edit depends on your stats administrator who configurated the stat.' => 'Med input og valg feltene kan man konfigurere statistikken til  fylle dine behov. Hvilke elementer til en statistikk man kan endre avhenger av hvilke elementer den som opprettet statistikken har satt til  kunne endres.',
 
-        # Template: AgentTicketArticleUpdate
-        'A message should have a subject!' => 'En melding m ha en emnebeskrivelse!',
-        'A message should have a body!' => 'En melding m inneholde en meldingstekst!',
-        'You need to account time!' => 'Du har ikke frt tidsregnskap!',
-        'Edit Article' => 'Editer artikkel',
-
         # Template: AgentTicketBounce
         'Bounce ticket' => 'Oversend sak',
         'Ticket locked!' => 'Ticket lst',
@@ -1105,7 +1114,6 @@ sub Data {
         'Bounce to' => 'Oversend til',
         'Next ticket state' => 'Neste status p sak',
         'Inform sender' => 'Informer avsender',
-        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'E-posten med saksnummer "<OTRS_TICKET>" er oversendt "<OTRS_BOUNCE_TO>". Vennligst ta kontakt p denne adressen for videre henvendelser.',
         'Send mail!' => 'Send e-posten!',
 
         # Template: AgentTicketBulk
@@ -1124,7 +1132,6 @@ sub Data {
         'Next state' => 'Neste status',
         'Pending date' => 'Sett p vent til',
         'Time units' => 'Tidsenheter',
-        ' (work units)' => ' (arbeidsenheter)',
 
         # Template: AgentTicketCompose
         'Compose answer for ticket' => 'Forfatt svar til sak',
@@ -1149,6 +1156,17 @@ sub Data {
         'Refresh' => 'Oppdater',
         'Clear To' => 'Visk ut "Til"',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => 'Eskaleringsvisning',
+        'Escalation' => 'Eskalering',
+        'Today' => 'Idag',
+        'Tomorrow' => 'I morgen',
+        'Next Week' => 'Neste Uke',
+        'up' => 'stigende',
+        'down' => 'synkende',
+        'Escalation' => 'Eskalering',
+        'Locked' => 'Tilgjenglighet',
+
         # Template: AgentTicketForward
         'Article type' => 'Artikkeltype',
 
@@ -1169,8 +1187,6 @@ sub Data {
         'Reminder' => 'Pminnelse',
         'Sort by' => 'Sorter etter',
         'Order' => 'Sortering',
-        'up' => 'stigende',
-        'down' => 'synkende',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => 'Flett saker',
@@ -1200,7 +1216,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => 'Saksinfo',
         'Accounted time' => 'Benyttet tid',
-        'Escalation in' => 'Eskalering om',
+        'First Response Time' => 'Frste responstid',
+        'Update Time' => 'Oppdateringstid',
+        'Solution Time' => 'Lsningstid',
         'Linked-Object' => 'Koblet objekt',
         'Parent-Object' => 'Foreldre-objekt',
         'Child-Object' => 'Barne-objekt',
@@ -1235,28 +1253,36 @@ sub Data {
         'Search-Template' => 'Skemal',
         'TicketFreeText' => 'Stikkordssk',
         'Created in Queue' => 'Opprettet i mappe',
+        'Close Times' => 'Stengetider',
+        'No close time settings.' => 'Ingen stengetid innstilling',
+        'Ticket closed' => 'Sak lst',
+        'Ticket closed between' => 'Sak lst mellom',
         'Result Form' => 'Resultatbilde',
         'Save Search-Profile as Template?' => 'Lagre skekriterier som mal?',
         'Yes, save it with name' => 'Ja, lagre med navn',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
+        'Search Result' => 'Skeresultat',
         'Change search options' => 'Endre ske-innstillinger',
 
         # Template: AgentTicketSearchResultPrint
 
         # Template: AgentTicketSearchResultShort
-        'U' => 'O',
-        'D' => 'N',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => 'Sakstatus-visning',
         'Open Tickets' => 'pne saker',
-        'Locked' => 'Tilgjenglighet',
 
         # Template: AgentTicketZoom
+        'Expand View' => 'Utvid',
+        'Collapse View' => 'Begrens',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1328,8 +1354,8 @@ sub Data {
         'Accept license' => 'Aksepter lisens',
         'Don\'t accept license' => 'Ikke aksepter lisens',
         'Admin-User' => 'Admin-bruker',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => 'Hvis du har satt et root passord for databasen, m det skrives inn her. Hvis ikke kan du la dette feltet vre pent. For sikkerhetsskyld anbefaler vi  sette et root passord. For mer informasjon, vennligst se i databasedokumentasjonen.',
         'Admin-Password' => 'Administrator-passord',
-        'your MySQL DB should have a root password! Default is empty!' => 'Din MySQL-database br ha et root-passord satt!  Default er intet passord!',
         'Database-User' => 'Database-bruker',
         'default \'hot\'' => 'Standard \'hot\'',
         'DB connect host' => 'Tilkoblingsmaskin for database',
@@ -1359,7 +1385,6 @@ sub Data {
         'Restart your webserver' => 'Restart webserveren din',
         'After doing so your OTRS is up and running.' => 'Etter dette vil OTRS vre oppe og kjre.',
         'Start page' => 'Startside',
-        'Have a lot of fun!' => 'Ha det gy!',
         'Your OTRS Team' => 'Ditt OTRS-Team',
 
         # Template: Login
@@ -1386,18 +1411,20 @@ sub Data {
 
         # Template: Warning
         # Misc
+        'Edit Article' => 'Editer artikkel',
         'Create Database' => 'Opprett database',
         'DB Host' => 'Databasemaskin',
         'Ticket Number Generator' => 'Saksnummer-generator',
         '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(Sakskjennetegn, f.eks. \'Ticket#\', \'Call#\' eller \'MyTicket#\')',
-        'Create new Phone Ticket' => 'Opprett ny henvendelse',
         'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'P denne mten kan du direkte redigere nkkelringen som er konfigurert i Kernel/Config.pm',
+        'Create new Phone Ticket' => 'Opprett ny henvendelse',
         'Symptom' => 'Symptom',
+        'U' => 'O',
         'A message should have a To: recipient!' => 'En melding m ha en mottager i Til:-feltet!',
         'Site' => 'side',
         'Customer history search (e. g. "ID342425").' => 'Sk etter kunde for historikk (f.eks. "ID342425").',
-        'for agent firstname' => 'gir agents fornavn',
         'Close!' => 'Lukk!',
+        'for agent firstname' => 'gir agents fornavn',
         'The message being composed has been closed.  Exiting.' => 'Det tilhrende redigeringsvinduet har blitt lukket.  Avslutter.',
         'A web calendar' => 'EN web-kalender',
         'to get the realname of the sender (if given)' => 'gir avsenders fulle navn (hvis mulig)',
@@ -1426,9 +1453,12 @@ sub Data {
         'next step' => 'neste steg',
         'Customer history search' => 'Historikk for kunde',
         'Admin-Email' => 'Admin e-post',
+        'Stat#' => 'Stat#',
         'Create new database' => 'Opprett ny database',
         'A message must be spell checked!' => 'Stavekontroll m utfres p alle meldinger!',
+        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'E-posten med saksnummer "<OTRS_TICKET>" er oversendt "<OTRS_BOUNCE_TO>". Vennligst ta kontakt p denne adressen for videre henvendelser.',
         'ArticleID' => 'Artikkel-ID',
+        'A message should have a body!' => 'En melding m inneholde en meldingstekst!',
         'All Agents' => 'Alle agenter',
         'Keywords' => 'Nkkelord',
         'No * possible!' => 'Jokertegn ikke tillatt!',
@@ -1438,9 +1468,10 @@ sub Data {
         'OTRS DB Password' => 'OTRS DB passord',
         'Last update' => 'Sist endret',
         'to get the first 20 character of the subject' => 'gir de frste 20 bokstavene av emnebeskrivelsen',
+        'Select the customeruser:service relations.' => 'Velg kundebruker:tjeneste relasjoner',
         'DB Admin Password' => 'DB administratorpassord',
-        'Advisory' => 'Rd',
         'Drop Database' => 'Slett database',
+        'Advisory' => 'Rd',
         'FileManager' => 'Filhndterer',
         'Options of the current customer user data (e. g. <OTRS_CUSTOMER_DATA_UserFirstname>)' => 'gir tilgang til data for gjeldende kunde (f.eks. <OTRS_CUSTOMER_DATA_UserFirstname>)',
         'Pending type' => 'Venter p',
@@ -1453,28 +1484,32 @@ sub Data {
         'Fulltext' => 'Fritekst',
         'Incident' => 'Hendelse',
         'All Agent variables.' => 'Alle agent variabler.',
+        ' (work units)' => ' (arbeidsenheter)',
         'All Customer variables like defined in config option CustomerUser.' => 'Alle "kunde-variabler" som er definert i konfigurasjonen CustomerUser',
         'accept license' => 'aksepter lisens',
         'for agent lastname' => 'gir agents etternavn',
         'Options of the current user who requested this action (e. g. <OTRS_CURRENT_UserFirstname>)' => 'gir tilgang til data for agenten som utfrer handlingen (f.eks. <OTRS_CURRENT_UserFirstname>)',
         'Reminder messages' => 'Pminnelses-meldinger',
+        'A message should have a subject!' => 'En melding m ha en emnebeskrivelse!',
         'Don\'t forget to add a new user to groups!' => 'Ikke glem  gi nye brukere en gruppe!',
         'You need a email address (e. g. customer@example.com) in To:!' => 'I Til-feltet m det oppgis en gyldig email-adresse (f.eks. kunde@eksempeldomene.no)!',
         'CreateTicket' => 'Opprettet sak',
+        'You need to account time!' => 'Du har ikke frt tidsregnskap!',
         'System Settings' => 'Systeminnstillinger',
         'WebWatcher' => 'Webovervker',
         'Finished' => 'Ferdig',
         'Explorer' => 'Utforsker',
         'Account Type' => 'Konto type',
         'Split' => 'Splitt',
-        'System Status' => 'System status',
+        'D' => 'N',
         'All messages' => 'Alle meldinger',
+        'System Status' => 'System status',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => 'Valg for saks-data (f.eks. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)',
         'Artefact' => 'Artefakt',
         'A article should have a title!' => 'En artikkel br ha en tittel',
         'Here you can define the x-axis. You can select one element via the radio button. Than you you have to select two or more attributes of the element. If you make no selection all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => 'Her kan man definere X-aksen. Man kan frst velge ett element, og deretter to eller fler attributter for elementet. Dersom du ikke velger noen attributter vil alle attributtene til elementet velges, i tillegg til eventuelle nye elementer som legges til senere.',
-        'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => 'Konfigurasjonsinnstillinger (f.eks. &lt;OTRS_CONFIG_HttpType&gt;)',
         'Event' => 'Hendelse',
+        'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => 'Konfigurasjonsinnstillinger (f.eks. &lt;OTRS_CONFIG_HttpType&gt;)',
         'don\'t accept license' => 'ikke aksepter lisens',
         'A web mail client' => 'En webmail-klient',
         'Please select only one Element or turn of the button \'Fixed\'.' => 'Vennligst velg kun ett element, eller deaktiver \'Fast\' knappen.',
@@ -1488,25 +1523,39 @@ sub Data {
         'to get the from line of the email' => 'gir avsenderlinjen i e-posten',
         'Solution' => 'Lsning',
         'QueueView' => 'Mapper',
+        'Select Box' => 'SQL-tilgang',
         'Please select only one element or turn of the button \'Fixed\' where the select field is marked!' => 'Vennligst velg kun ett element, eller skru av \'Fast\' knappen der valgt felt er markert!',
         'Welcome to OTRS' => 'Velkommen til OTRS',
         'modified' => 'endret',
+        'Escalation in' => 'Eskalering om',
         'Delete old database' => 'Slett gammel database',
         'sort downward' => 'Sorter synkende',
         'You need to use a ticket number!' => 'Du m bruke et saksnummer',
         'A web file manager' => 'En webbasert filhndterer',
+        'Have a lot of fun!' => 'Ha det gy!',
         'send' => 'Send',
         'Note Text' => 'Notistekst',
+        'POP3 Account Management' => 'Administrasjon: POP3-Konto',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => 'Valg for gjeldende kundes brukerdata (f.eks. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)',
         'System State Management' => 'Administrasjon: Status',
         'OTRS DB User' => 'OTRS DB bruker',
         'PhoneView' => 'Henvendelser',
         'maximal period form' => 'maksimal periode form',
-        'Verion' => 'Versjon',
         'TicketID' => 'Sak-ID',
         'SubCategoryOf' => 'Underkategori',
         'Modified' => 'Endret',
         'Ticket selected for bulk action!' => 'Sak valgt for masseredigering',
+
+        'Link Object: %s' => 'Koble Objekt: %s',
+        'Unlink Object: %s' => 'Koble fra Objekt: %s',
+        'Linked as' => 'Koblet som',
+        'Can not create link with %s!' => 'Kan ikke opprette kobling mot %s!',
+        'Can not delete link with %s!' => 'Kan ikke fjerne kobling mot %s',
+        'Object already linked as %s.' => 'Objekt er allerede koblet som %s.',
+        'Priority Management' => 'Prioriteringsadministrasjon',
+        'Add a new Priority.' => 'Legg til som ny Prioritering',
+        'Add Priority' => 'Legg til Prioritering',
+        'Ticket Type is required!' => '',
     };
     # $$STOP$$
     return;
