@@ -4,9 +4,9 @@
 # Copyright (C) 2003 A-NeT Internet Services bv Hans Bakker <h.bakker at a-net.nl>
 # Copyright (C) 2004 Martijn Lohmeijer <martijn.lohmeijer 'at' sogeti.nl>
 # Copyright (C) 2005-2007 Jurgen Rutgers <jurgen 'at' besite.nl>
-#                         Richard Hinkamp <richard 'at' besite.nl>
+# Copyright (C) 2005-2007 Richard Hinkamp <richard 'at' besite.nl>
 # --
-# $Id: nl.pm,v 1.64.2.2 2008/05/28 08:03:42 tr Exp $
+# $Id: nl.pm,v 1.82 2008/08/06 11:48:12 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -26,25 +26,24 @@
 package Kernel::Language::nl;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.64.2.2 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*\$/$1/;
+$VERSION = qw($Revision: 1.82 $) [1];
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Tue May 29 15:18:09 2007
+    # Last translation file sync: Fri May 16 14:08:45 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%D.%M.%Y %T';
-    $Self->{DateFormatLong} = '%A %D %B %T %Y';
-    $Self->{DateFormatShort} = '%D.%M.%Y';
-    $Self->{DateInputFormat} = '%D.%M.%Y';
+    $Self->{DateFormat}          = '%D.%M.%Y %T';
+    $Self->{DateFormatLong}      = '%A %D %B %T %Y';
+    $Self->{DateFormatShort}     = '%D.%M.%Y';
+    $Self->{DateInputFormat}     = '%D.%M.%Y';
     $Self->{DateInputFormatLong} = '%D.%M.%Y - %T';
 
     $Self->{Translation} = {
@@ -118,6 +117,7 @@ sub Data {
         'please do not edit!' => 'niet wijzigen s.v.p.!',
         'AddLink' => 'Link toevoegen',
         'Link' => 'Link',
+        'Unlink' => '',
         'Linked' => 'Gelinkt',
         'Link (Normal)' => 'Link (normaal)',
         'Link (Parent)' => 'Link (hoofd)',
@@ -259,14 +259,26 @@ sub Data {
         'Mobile' => 'Mobiel',
         'Zip' => 'Postcode',
         'City' => 'Plaats',
+        'Location' => 'Locatie',
+        'Street' => 'Straat',
         'Country' => 'Land',
-        'installed' => '',
-        'uninstalled' => '',
+        'installed' => 'genstalleerd',
+        'uninstalled' => 'verwijderd',
         'Security Note: You should activate %s because application is already running!' => '',
         'Unable to parse Online Repository index document!' => '',
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => '',
         'No Packages or no new Packages in selected Online Repository!' => '',
         'printed at' => '',
+        'Dear Mr. %s,' => '',
+        'Dear Mrs. %s,' => '',
+        'Dear %s,' => '',
+        'Hello %s,' => '',
+        'This account exists.' => '',
+        'New account created. Sent Login-Account to %s.' => '',
+        'Please press Back and try again.' => '',
+        'Sent password token to: %s' => '',
+        'Sent new password to: %s' => '',
+        'Invalid Token!' => '',
 
         # Template: AAAMonth
         'Jan' => 'jan',
@@ -397,6 +409,7 @@ sub Data {
         'Move' => 'Verplaatsen',
         'Queue' => 'Wachtrij',
         'Priority' => 'Prioriteit',
+        'Priority Update' => '',
         'State' => 'Status',
         'Compose' => 'Maken',
         'Pending' => 'Wachtend',
@@ -465,6 +478,7 @@ sub Data {
         'Phone-Ticket' => 'Telefoon Ticket',
         'Search Tickets' => 'Zoek Tickets',
         'Edit Customer Users' => 'Wijzig klant gebruikers',
+        'Edit Customer Company' => '',
         'Bulk-Action' => 'Bulk Actie',
         'Bulk Actions on Tickets' => 'Bulk Actie op Tickets',
         'Send Email and create a new Ticket' => 'Verstuur e-mail en maak een nieuw Ticket aan',
@@ -563,6 +577,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Klant stelt vraag via het web.',
         'History::TicketLinkAdd' => 'Link naar "%s" toegevoegd.',
         'History::TicketLinkDelete' => 'Link naar "%s" verwijderd.',
+        'History::Subscribe' => 'Added subscription for user "%s".',
+        'History::Unsubscribe' => 'Removed subscription for user "%s".',
 
         # Template: AAAWeekDay
         'Sun' => 'zondag',
@@ -595,6 +611,7 @@ sub Data {
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => 'Klant bedrijven beheer',
+        'Search for' => 'Zoek naar',
         'Add Customer Company' => 'Klant bedrijf toevoegen',
         'Add a new Customer Company.' => 'Voeg een nieuw klant bedrijf toe.',
         'List' => 'Lijst',
@@ -603,7 +620,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'Gebruikersbeheer klanten',
-        'Search for' => 'Zoek naar',
         'Add Customer User' => 'Klant gebruiker toevoegen',
         'Source' => 'Bron',
         'Create' => 'Aanmaken',
@@ -622,14 +638,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
-        # Template: AdminCustomerUserServiceChangeForm
+        # Template: AdminCustomerUserService
         'Customer Users <-> Services Management' => '',
-        'Select the customeruser:service relations.' => '',
-        'Allocate services to CustomerUser' => '',
-        'Allocate CustomerUser to service' => '',
-
-        # Template: AdminCustomerUserServiceForm
+        'CustomerUser' => 'Klant gebruiker',
+        'Service' => 'Service',
         'Edit default services.' => '',
+        'Search Result' => 'Zoekresultaat',
+        'Allocate services to CustomerUser' => '',
+        'Active' => 'Actief',
+        'Allocate CustomerUser to service' => '',
 
         # Template: AdminEmail
         'Message sent to' => 'Bericht verstuurd naar',
@@ -652,6 +669,7 @@ sub Data {
         '(e. g. 234321)' => '(b.v. 234321)',
         'Customer User Login' => 'Klant login',
         '(e. g. U5150)' => '(b.v. U5150)',
+        'SLA' => 'SLA',
         'Agent' => 'Agent/Eigenaar',
         'Ticket Lock' => 'Ticket vergrendeling',
         'TicketFreeFields' => 'Vrije invulvelden van het Ticket',
@@ -659,10 +677,16 @@ sub Data {
         'No create time settings.' => 'Geen tijd instellingen',
         'Ticket created' => 'Ticket aangemaakt',
         'Ticket created between' => 'Ticket aangemaakt tussen',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Pending Times' => 'Wachtend tijden',
         'No pending time settings.' => 'Geen wachtende tijd instellingen',
         'Ticket pending time reached' => 'Ticket wachtende tijd bereikt',
         'Ticket pending time reached between' => 'Ticket wachtende tijd tussen',
+        'New Service' => '',
+        'New SLA' => '',
         'New Priority' => 'Nieuwe prioriteit',
         'New Queue' => 'Nieuwe wachtrij',
         'New State' => 'Nieuwe status',
@@ -670,7 +694,9 @@ sub Data {
         'New Owner' => 'Nieuwe eigenaar',
         'New Customer' => 'Nieuwe klant',
         'New Ticket Lock' => 'Nieuwe Ticket vergrendeling',
-        'CustomerUser' => 'Klant gebruiker',
+        'New Type' => '',
+        'New Title' => '',
+        'New Type' => '',
         'New TicketFreeFields' => '',
         'Add Note' => 'Notitie toevoegen',
         'CMD' => 'Commando',
@@ -703,6 +729,14 @@ sub Data {
         'System Log' => 'Systeem logboek',
         'Time' => 'Tijd',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => '',
+        'Host' => 'Server',
+        'Trusted' => 'Vertrouwd',
+        'Dispatching' => 'Sortering',
+        'All incoming emails with one account will be dispatched in the selected queue!' => 'Alle binnenkomende e-mail\'s in een account zullen worden geplaatst in de geselecteerde wachtrij',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
+
         # Template: AdminNavigationBar
         'Users' => 'Gebruikers',
         'Groups' => 'Groepen',
@@ -718,24 +752,24 @@ sub Data {
         'Uninstall' => '',
         'Version' => '',
         'Do you really want to uninstall this package?' => '',
-        'Reinstall' => '',
+        'Reinstall' => 'Reinstall',
         'Do you really want to reinstall this package (all manual changes get lost)?' => '',
-        'Continue' => '',
-        'Install' => '',
-        'Package' => '',
+        'Continue' => 'Doorgaan',
+        'Install' => 'Installeer',
+        'Package' => 'Arrangement',
         'Online Repository' => '',
-        'Vendor' => '',
+        'Vendor' => 'Verkoper',
         'Upgrade' => '',
         'Local Repository' => '',
         'Status' => '',
-        'Overview' => '',
-        'Download' => '',
-        'Rebuild' => '',
+        'Overview' => 'Overzicht',
+        'Download' => 'Downloaden',
+        'Rebuild' => 'Herbouw',
         'ChangeLog' => '',
-        'Date' => '',
+        'Date' => 'Datum',
         'Filelist' => '',
         'Download file from package!' => '',
-        'Required' => '',
+        'Required' => 'verplicht',
         'PrimaryKey' => '',
         'AutoIncrement' => '',
         'SQL' => '',
@@ -753,10 +787,14 @@ sub Data {
         'Logfile too large, you need to reset it!' => '',
         'Range' => 'Bereik',
         'Interface' => '',
-        'Requests' => '',
+        'Requests' => 'Verzoeken',
         'Min Response' => '',
         'Max Response' => '',
-        'Average Response' => '',
+        'Average Response' => 'Gemiddelde Response',
+        'Period' => 'Looptijd',
+        'Min' => '',
+        'Max' => '',
+        'Average' => 'Gemiddeld',
 
         # Template: AdminPGPForm
         'PGP Management' => '',
@@ -765,17 +803,9 @@ sub Data {
         'Bit' => '',
         'Key' => '',
         'Fingerprint' => '',
-        'Expires' => '',
+        'Expires' => 'Verloopt',
         'In this way you can directly edit the keyring configured in SysConfig.' => '',
 
-        # Template: AdminPOP3
-        'POP3 Account Management' => 'POP3 Account beheer',
-        'Host' => 'Server',
-        'Trusted' => 'Vertrouwd',
-        'Dispatching' => 'Sortering',
-        'All incoming emails with one account will be dispatched in the selected queue!' => 'Alle binnenkomende e-mail\'s in een account zullen worden geplaatst in de geselecteerde wachtrij',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
-
         # Template: AdminPostMasterFilter
         'PostMaster Filter Management' => 'Postmaster filter beheer',
         'Filtername' => 'Filter naam',
@@ -795,9 +825,13 @@ sub Data {
         'Sub-Queue of' => 'Sub-wachtrij van',
         'Unlock timeout' => 'Ontgrendel tijdsoverschrijding',
         '0 = no unlock' => '0 = geen ontgrendeling',
+        'Only business hours are counted.' => '',
         'Escalation - First Response Time' => '',
         '0 = no escalation' => '0 = geen escalatie',
+        'Only business hours are counted.' => '',
+        'Notify by' => '',
         'Escalation - Update Time' => '',
+        'Notify by' => '',
         'Escalation - Solution Time' => '',
         'Follow up Option' => 'Follow up optie',
         'Ticket lock after a follow up' => 'Ticket-vergrendeling na een follow up',
@@ -857,7 +891,6 @@ sub Data {
 
         # Template: AdminRoleUserChangeForm
         'Roles <-> Users Management' => 'Rollen <-> Gebruikers beheer',
-        'Active' => 'Actief',
         'Select the role:user relations.' => 'Selecteer de rol : gebruiker relatie',
 
         # Template: AdminRoleUserForm
@@ -868,7 +901,7 @@ sub Data {
         'Add a new Salutation.' => 'Een nieuwe aanhef toevoegen',
 
         # Template: AdminSelectBoxForm
-        'Select Box' => 'SQL select query',
+        'SQL Box' => '',
         'Limit' => 'Beperk tot',
         'Go' => 'Uitvoeren',
         'Select Box Result' => 'keuzekader resultaat',
@@ -877,7 +910,6 @@ sub Data {
         'Service Management' => 'Service beheer',
         'Add Service' => 'Service toevoegen',
         'Add a new Service.' => 'Voeg nieuwe service toe',
-        'Service' => 'Service',
         'Sub-Service of' => 'Service is onderdeel van',
 
         # Template: AdminSession
@@ -898,10 +930,6 @@ sub Data {
         'SLA Management' => 'SLA beheer',
         'Add SLA' => 'SLA toevoegen',
         'Add a new SLA.' => 'Nieuwe SLA toevoegen',
-        'SLA' => 'SLA',
-        'First Response Time' => 'Eerste antwoord tijd',
-        'Update Time' => 'Vervolg tijd',
-        'Solution Time' => 'Oplossing tijd',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => '',
@@ -1056,7 +1084,7 @@ sub Data {
         'Scale' => '',
         'minimal' => 'minimaal',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => '',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => 'Selecteer het element dat gebruikt zal worden voor de X-as',
@@ -1136,6 +1164,17 @@ sub Data {
         'Refresh' => 'Herniew',
         'Clear To' => '"Aan" leeg maken',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => '',
+        'Escalation' => '',
+        'Today' => '',
+        'Tomorrow' => '',
+        'Next Week' => '',
+        'up' => 'naar boven',
+        'down' => 'naar beneden',
+        'Escalation' => '',
+        'Locked' => 'Vergrendeld',
+
         # Template: AgentTicketForward
         'Article type' => 'Artikel type',
 
@@ -1156,8 +1195,6 @@ sub Data {
         'Reminder' => 'Herinnering',
         'Sort by' => 'Sorteer volgens',
         'Order' => 'Volgorde',
-        'up' => 'naar boven',
-        'down' => 'naar beneden',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => 'Ticket samenvoegen',
@@ -1187,7 +1224,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => 'Ticket informatie',
         'Accounted time' => 'Geregistreerde tijd',
-        'Escalation in' => 'Escalatie om',
+        'First Response Time' => 'Eerste antwoord tijd',
+        'Update Time' => 'Vervolg tijd',
+        'Solution Time' => 'Oplossing tijd',
         'Linked-Object' => 'Gelinkt item',
         'Parent-Object' => 'Hoofd item',
         'Child-Object' => 'Sub item',
@@ -1222,29 +1261,35 @@ sub Data {
         'Search-Template' => 'Zoek template',
         'TicketFreeText' => 'Vrije invulvelden van het Ticket',
         'Created in Queue' => 'Aangemaakt in wachtrij',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Result Form' => 'Resultaatformulier',
         'Save Search-Profile as Template?' => 'Zoekprofiel als template bewaren ?',
         'Yes, save it with name' => 'Ja, sla op met naam',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
-        'Search Result' => 'Zoekresultaat',
         'Change search options' => 'Verander zoekopties',
 
         # Template: AgentTicketSearchResultPrint
 
         # Template: AgentTicketSearchResultShort
-        'U' => 'U',
-        'D' => 'D',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => '',
         'Open Tickets' => 'Openstaande tickets',
-        'Locked' => 'Vergrendeld',
 
         # Template: AgentTicketZoom
+        'Expand View' => '',
+        'Collapse View' => '',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1312,15 +1357,18 @@ sub Data {
 
         # Template: Installer
         'Web-Installer' => '',
+        'Welcome to %s' => 'Welkom bij %s',
         'Accept license' => 'Accepteer licentie',
         'Don\'t accept license' => 'Licentie niet accepteren',
         'Admin-User' => 'Admin gebruiker',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => '',
         'Admin-Password' => 'Admin wachtwoord',
-        'your MySQL DB should have a root password! Default is empty!' => '',
         'Database-User' => 'Database gebruiker',
         'default \'hot\'' => '',
         'DB connect host' => '',
         'Database' => 'Database',
+        'Default Charset' => '',
+        'utf8' => '',
         'false' => 'onwaar',
         'SystemID' => 'Systeem ID',
         '(The identify of the system. Each ticket number and each http session id starts with this number)' => '',
@@ -1335,7 +1383,6 @@ sub Data {
         'Logfile' => '',
         '(Logfile just needed for File-LogModule!)' => '',
         'Webfrontend' => '',
-        'Default Charset' => '',
         'Use utf-8 it your database supports it!' => '',
         'Default Language' => '',
         '(Used default language)' => '',
@@ -1345,11 +1392,9 @@ sub Data {
         'Restart your webserver' => '',
         'After doing so your OTRS is up and running.' => '',
         'Start page' => '',
-        'Have a lot of fun!' => '',
         'Your OTRS Team' => '',
 
         # Template: Login
-        'Welcome to %s' => 'Welkom bij %s',
 
         # Template: Motd
 
@@ -1376,10 +1421,11 @@ sub Data {
         'Edit Article' => 'Bewerk artikel',
         'Create new Phone Ticket' => 'Maak nieuw Telefoon Ticket aan',
         'Symptom' => 'Symptoom',
+        'U' => 'U',
         'A message should have a To: recipient!' => 'Een bericht moet een ontvanger (aan:) hebben!',
         'Customer history search (e. g. "ID342425").' => 'Klantgeschiedenis zoeken (bijv. "ID342425").',
-        'Close!' => 'Sluit!',
         'for agent firstname' => 'voornaam van agent',
+        'Close!' => 'Sluit!',
         'The message being composed has been closed.  Exiting.' => 'Het bericht dat werd aangemaakt is gesloten.',
         'A web calendar' => 'Kalender',
         'to get the realname of the sender (if given)' => 'voor de echte naam van de afzender (indien beschikbaar)',
@@ -1416,6 +1462,7 @@ sub Data {
         'to get the first 5 lines of the email' => 'voor de eerste vijf regels van het e-mail bericht',
         'Last update' => 'Laatste wijziging',
         'to get the first 20 character of the subject' => 'voor de eerste 20 tekens van het onderwerp',
+        'Select the customeruser:service relations.' => '',
         'FileManager' => 'Bestandsbeheer',
         'Options of the current customer user data (e. g. <OTRS_CUSTOMER_DATA_UserFirstname>)' => 'Opties van de huidige gebruikersdata van de klant (b.v. <OTRS_CUSTOMER_DATA_UserFirstname>)',
         'Pending type' => 'In de wacht: type',
@@ -1440,11 +1487,12 @@ sub Data {
         'WebWatcher' => '',
         'Finished' => 'Afgerond',
         'Split' => 'Splitsing',
+        'D' => 'D',
         'All messages' => 'Alle berichten',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => 'Mogelijkheden van de ticket gegevens (bijv. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)',
         'A article should have a title!' => 'Een artikel moet een titel hebben!',
-        'Event' => '',
         'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => 'Configuratie mogelijkheden (bijv. &lt;OTRS_CONFIG_HttpType&gt;)',
+        'Event' => '',
         'A web mail client' => 'Webmail gebruiker',
         'WebMail' => 'Webmail',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_TicketID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => 'Mogelijkheden van de ticket gegevens (bijv. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_TicketID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)',
@@ -1455,21 +1503,35 @@ sub Data {
         'Solution' => 'Oplossing',
         'QueueView' => 'Wachtrijen',
         'My Queue' => 'Mijn wachtrij',
+        'Select Box' => 'SQL select query',
         'Welcome to OTRS' => 'Welkom bij OTRS',
         'modified' => 'aangepast',
+        'Escalation in' => 'Escalatie om',
         'sort downward' => 'sorteer aflopend',
         'You need to use a ticket number!' => 'U dient een Ticket nummer te gebruiken.',
         'A web file manager' => 'Een online bestandsbeheer',
+        'Have a lot of fun!' => '',
         'send' => 'verstuur',
         'Note Text' => 'Notitietekst',
+        'POP3 Account Management' => 'POP3 Account beheer',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => 'Mogelijkheden van de huidige klant gegevens (bijv. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)',
         'System State Management' => 'Status beheer',
         'PhoneView' => 'Telefoonscherm',
         'maximal period form' => '',
-        'Verion' => '',
         'TicketID' => 'Ticket ID',
         'Modified' => 'Gewijzigd',
         'Ticket selected for bulk action!' => 'Ticket geselecteerd voor bulk aktie!',
+
+        'Link Object: %s' => '',
+        'Unlink Object: %s' => '',
+        'Linked as' => '',
+        'Can not create link with %s!' => '',
+        'Can not delete link with %s!' => '',
+        'Object already linked as %s.' => '',
+        'Priority Management' => '',
+        'Add a new Priority.' => '',
+        'Add Priority' => '',
+        'Ticket Type is required!' => '',
     };
     # $$STOP$$
     return;
