@@ -1,37 +1,35 @@
 # --
 # Kernel/Language/pl.pm - provides pl language translation
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
-# Translated by Tomasz Melissa <janek at rumianek.com>
+# Copyright (C) 2007 Tomasz Melissa <janek at rumianek.com>
 # --
-# $Id: pl.pm,v 1.49 2007/06/28 23:58:33 martin Exp $
+# $Id: pl.pm,v 1.66 2008/08/06 11:48:12 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Language::pl;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.49 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.66 $) [1];
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Tue May 29 15:20:30 2007
+    # Last translation file sync: Fri May 16 14:08:47 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-2', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%D.%M.%Y %T';
-    $Self->{DateFormatLong} = '%A %D %B %T %Y';
-    $Self->{DateFormatShort} = '%D.%M.%Y';
-    $Self->{DateInputFormat} = '%D.%M.%Y';
+    $Self->{DateFormat}          = '%D.%M.%Y %T';
+    $Self->{DateFormatLong}      = '%A %D %B %T %Y';
+    $Self->{DateFormatShort}     = '%D.%M.%Y';
+    $Self->{DateInputFormat}     = '%D.%M.%Y';
     $Self->{DateInputFormatLong} = '%D.%M.%Y - %T';
 
     $Self->{Translation} = {
@@ -105,6 +103,7 @@ sub Data {
         'please do not edit!' => 'nie edytowa!',
         'AddLink' => 'Dodaj link',
         'Link' => '',
+        'Unlink' => '',
         'Linked' => '',
         'Link (Normal)' => '',
         'Link (Parent)' => '',
@@ -246,6 +245,8 @@ sub Data {
         'Mobile' => '',
         'Zip' => '',
         'City' => '',
+        'Location' => '',
+        'Street' => '',
         'Country' => '',
         'installed' => '',
         'uninstalled' => '',
@@ -254,6 +255,16 @@ sub Data {
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => '',
         'No Packages or no new Packages in selected Online Repository!' => '',
         'printed at' => '',
+        'Dear Mr. %s,' => '',
+        'Dear Mrs. %s,' => '',
+        'Dear %s,' => '',
+        'Hello %s,' => '',
+        'This account exists.' => '',
+        'New account created. Sent Login-Account to %s.' => '',
+        'Please press Back and try again.' => '',
+        'Sent password token to: %s' => '',
+        'Sent new password to: %s' => '',
+        'Invalid Token!' => '',
 
         # Template: AAAMonth
         'Jan' => 'Sty',
@@ -384,6 +395,7 @@ sub Data {
         'Move' => 'Przesu',
         'Queue' => 'Kolejka',
         'Priority' => 'Priorytet',
+        'Priority Update' => '',
         'State' => 'Status',
         'Compose' => 'Stwrz',
         'Pending' => 'Oczekujce',
@@ -452,6 +464,7 @@ sub Data {
         'Phone-Ticket' => '',
         'Search Tickets' => '',
         'Edit Customer Users' => '',
+        'Edit Customer Company' => '',
         'Bulk-Action' => '',
         'Bulk Actions on Tickets' => '',
         'Send Email and create a new Ticket' => '',
@@ -550,6 +563,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Customer request via web.',
         'History::TicketLinkAdd' => 'Added link to ticket "%s".',
         'History::TicketLinkDelete' => 'Deleted link to ticket "%s".',
+        'History::Subscribe' => 'Added subscription for user "%s".',
+        'History::Unsubscribe' => 'Removed subscription for user "%s".',
 
         # Template: AAAWeekDay
         'Sun' => 'Ndz',
@@ -582,6 +597,7 @@ sub Data {
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => '',
+        'Search for' => '',
         'Add Customer Company' => '',
         'Add a new Customer Company.' => '',
         'List' => '',
@@ -590,7 +606,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'Konfiguracja uytkownikw',
-        'Search for' => '',
         'Add Customer User' => '',
         'Source' => 'rdo',
         'Create' => '',
@@ -609,6 +624,16 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
+        # Template: AdminCustomerUserService
+        'Customer Users <-> Services Management' => '',
+        'CustomerUser' => 'Klient',
+        'Service' => '',
+        'Edit default services.' => '',
+        'Search Result' => 'Wyniki wyszukiwania',
+        'Allocate services to CustomerUser' => '',
+        'Active' => '',
+        'Allocate CustomerUser to service' => '',
+
         # Template: AdminEmail
         'Message sent to' => 'Wiadomo wysana do',
         'Recipents' => 'Adresaci',
@@ -630,6 +655,7 @@ sub Data {
         '(e. g. 234321)' => '(np. 3242442)',
         'Customer User Login' => 'Login Klienta',
         '(e. g. U5150)' => '(np. U4543)',
+        'SLA' => '',
         'Agent' => '',
         'Ticket Lock' => '',
         'TicketFreeFields' => '',
@@ -637,10 +663,16 @@ sub Data {
         'No create time settings.' => '',
         'Ticket created' => 'Zgoszenie utworzone',
         'Ticket created between' => 'Zgoszenie utworzone midzy',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Pending Times' => '',
         'No pending time settings.' => '',
         'Ticket pending time reached' => '',
         'Ticket pending time reached between' => '',
+        'New Service' => '',
+        'New SLA' => '',
         'New Priority' => '',
         'New Queue' => 'Nowa kolejka',
         'New State' => '',
@@ -648,7 +680,9 @@ sub Data {
         'New Owner' => 'Nowy waciciel',
         'New Customer' => '',
         'New Ticket Lock' => '',
-        'CustomerUser' => 'Klient',
+        'New Type' => '',
+        'New Title' => '',
+        'New Type' => '',
         'New TicketFreeFields' => '',
         'Add Note' => 'Dodaj notatk',
         'CMD' => '',
@@ -681,6 +715,14 @@ sub Data {
         'System Log' => 'Log Systemu',
         'Time' => '',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => '',
+        'Host' => '',
+        'Trusted' => 'Zaufane',
+        'Dispatching' => 'Przekazanie',
+        'All incoming emails with one account will be dispatched in the selected queue!' => 'Wszystkie przychodzce na jedno konto wiadomoci bd umieszczone w zaznacznej kolejce!',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
+
         # Template: AdminNavigationBar
         'Users' => '',
         'Groups' => 'Grupy',
@@ -735,6 +777,10 @@ sub Data {
         'Min Response' => '',
         'Max Response' => '',
         'Average Response' => '',
+        'Period' => '',
+        'Min' => '',
+        'Max' => '',
+        'Average' => '',
 
         # Template: AdminPGPForm
         'PGP Management' => '',
@@ -746,14 +792,6 @@ sub Data {
         'Expires' => '',
         'In this way you can directly edit the keyring configured in SysConfig.' => '',
 
-        # Template: AdminPOP3
-        'POP3 Account Management' => 'Konfiguracja kont POP3',
-        'Host' => '',
-        'Trusted' => 'Zaufane',
-        'Dispatching' => 'Przekazanie',
-        'All incoming emails with one account will be dispatched in the selected queue!' => 'Wszystkie przychodzce na jedno konto wiadomoci bd umieszczone w zaznacznej kolejce!',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
-
         # Template: AdminPostMasterFilter
         'PostMaster Filter Management' => '',
         'Filtername' => '',
@@ -773,9 +811,13 @@ sub Data {
         'Sub-Queue of' => 'Kolejka podrzdna',
         'Unlock timeout' => 'Limit czasowy odblokowania',
         '0 = no unlock' => '0 = bez odblokowania',
+        'Only business hours are counted.' => '',
         'Escalation - First Response Time' => '',
         '0 = no escalation' => '0 = brak eskalacji',
+        'Only business hours are counted.' => '',
+        'Notify by' => '',
         'Escalation - Update Time' => '',
+        'Notify by' => '',
         'Escalation - Solution Time' => '',
         'Follow up Option' => 'Opcja Follow Up',
         'Ticket lock after a follow up' => 'Zgoszenie zablokowane po odpowiedzi (Follow Up)',
@@ -835,7 +877,6 @@ sub Data {
 
         # Template: AdminRoleUserChangeForm
         'Roles <-> Users Management' => '',
-        'Active' => '',
         'Select the role:user relations.' => '',
 
         # Template: AdminRoleUserForm
@@ -846,7 +887,7 @@ sub Data {
         'Add a new Salutation.' => '',
 
         # Template: AdminSelectBoxForm
-        'Select Box' => 'Zapytanie SQL',
+        'SQL Box' => '',
         'Limit' => '',
         'Go' => '',
         'Select Box Result' => 'Wyniki Zapytania',
@@ -855,7 +896,6 @@ sub Data {
         'Service Management' => '',
         'Add Service' => '',
         'Add a new Service.' => '',
-        'Service' => '',
         'Sub-Service of' => '',
 
         # Template: AdminSession
@@ -876,10 +916,6 @@ sub Data {
         'SLA Management' => '',
         'Add SLA' => '',
         'Add a new SLA.' => '',
-        'SLA' => '',
-        'First Response Time' => '',
-        'Update Time' => '',
-        'Solution Time' => '',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => '',
@@ -1034,7 +1070,7 @@ sub Data {
         'Scale' => '',
         'minimal' => '',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => '',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => '',
@@ -1056,7 +1092,7 @@ sub Data {
 
         # Template: AgentStatsView
         'Export Config' => '',
-        'Informations about the Stat' => '',
+        'Information about the Stat' => '',
         'Exchange Axis' => '',
         'Configurable params of static stat' => '',
         'No element selected.' => '',
@@ -1114,6 +1150,17 @@ sub Data {
         'Refresh' => '',
         'Clear To' => '',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => '',
+        'Escalation' => '',
+        'Today' => '',
+        'Tomorrow' => '',
+        'Next Week' => '',
+        'up' => 'gra',
+        'down' => 'd',
+        'Escalation' => '',
+        'Locked' => '',
+
         # Template: AgentTicketForward
         'Article type' => 'Typ artykuu',
 
@@ -1134,8 +1181,6 @@ sub Data {
         'Reminder' => 'Przypomnienie',
         'Sort by' => 'Sortuj wedug',
         'Order' => 'Porzdek',
-        'up' => 'gra',
-        'down' => 'd',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => '',
@@ -1165,7 +1210,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => '',
         'Accounted time' => 'Zaraportowany czas',
-        'Escalation in' => 'Eskalowane w',
+        'First Response Time' => '',
+        'Update Time' => '',
+        'Solution Time' => '',
         'Linked-Object' => '',
         'Parent-Object' => '',
         'Child-Object' => '',
@@ -1200,29 +1247,35 @@ sub Data {
         'Search-Template' => 'Szablon wyszukiwania',
         'TicketFreeText' => 'Dodatkowe informacje o zgoszeniu',
         'Created in Queue' => '',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Result Form' => 'Formularz wynikw',
         'Save Search-Profile as Template?' => 'Zachowaj profil wyszukiwania jako szablon',
         'Yes, save it with name' => 'Tak, zapisz to pod nazw',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
-        'Search Result' => 'Wyniki wyszukiwania',
         'Change search options' => 'Zmie kryteria wyszukiwania',
 
         # Template: AgentTicketSearchResultPrint
 
         # Template: AgentTicketSearchResultShort
-        'U' => 'G',
-        'D' => '',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => '',
         'Open Tickets' => '',
-        'Locked' => '',
 
         # Template: AgentTicketZoom
+        'Expand View' => '',
+        'Collapse View' => '',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1290,15 +1343,18 @@ sub Data {
 
         # Template: Installer
         'Web-Installer' => 'Instalator Web',
+        'Welcome to %s' => 'Witamy w %s',
         'Accept license' => '',
         'Don\'t accept license' => '',
         'Admin-User' => 'Administrator',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => '',
         'Admin-Password' => '',
-        'your MySQL DB should have a root password! Default is empty!' => 'Twoja baza danych MYSQL powinna mie ustawione jakie haso dla uytkownika root. Domylnie jest puste!',
         'Database-User' => '',
         'default \'hot\'' => 'domylne \'hot\'',
         'DB connect host' => '',
         'Database' => '',
+        'Default Charset' => 'Domylne kodowanie',
+        'utf8' => '',
         'false' => '',
         'SystemID' => 'ID Systemu',
         '(The identify of the system. Each ticket number and each http session id starts with this number)' => '(Identyfikator systemu. Wszystkie zgoszenia oraz sesje http bd zaczynay si od tego cigu)',
@@ -1313,7 +1369,6 @@ sub Data {
         'Logfile' => 'Plik logu',
         '(Logfile just needed for File-LogModule!)' => '(Logfile jest potrzebny jedynie dla moduu File-Log!)',
         'Webfrontend' => 'Interfejs webowy',
-        'Default Charset' => 'Domylne kodowanie',
         'Use utf-8 it your database supports it!' => 'Uywaj kodowania UTF-8 jeli pozwala Ci na to baza danych!',
         'Default Language' => 'Domylny jzyk',
         '(Used default language)' => '(Domylny jzyk)',
@@ -1323,11 +1378,9 @@ sub Data {
         'Restart your webserver' => 'Uruchom ponownie serwer WWW',
         'After doing so your OTRS is up and running.' => 'Po zakoczeniu tych czynnoci Twj system OTRS bdzie gotowy do pracy',
         'Start page' => 'Strona startowa',
-        'Have a lot of fun!' => 'yczymy dobrej zabawy!',
         'Your OTRS Team' => 'Twj Team OTRS',
 
         # Template: Login
-        'Welcome to %s' => 'Witamy w %s',
 
         # Template: Motd
 
@@ -1356,14 +1409,15 @@ sub Data {
         'DB Host' => 'Host bazy danych',
         'Ticket Number Generator' => 'Generator numerw zgosze',
         '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(Identyfikator zgoszenia. np. \'Ticket#\', \'Call#\' lub \'MyTicket#\')',
-        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => '',
         'Create new Phone Ticket' => '',
+        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => '',
         'Symptom' => 'Objawy',
+        'U' => 'G',
         'A message should have a To: recipient!' => 'Wiadomo musi zawiera wypenione adresem polu Do: (odbiorca)!',
         'Site' => 'Witryna',
         'Customer history search (e. g. "ID342425").' => 'Przeszukiwanie historii klienta (np. "ID342425").',
-        'Close!' => 'Zamknij!',
         'for agent firstname' => 'dla imienia agenta',
+        'Close!' => 'Zamknij!',
         'The message being composed has been closed.  Exiting.' => 'Wiadomo edytowana zostaa zamknita.  Wychodz.',
         'A web calendar' => '',
         'to get the realname of the sender (if given)' => 'by wstawi prawdziwe imi i nazwisko klienta (jeli podano)',
@@ -1388,7 +1442,7 @@ sub Data {
         'Admin-Email' => 'Wiadomo od Administratora',
         'Create new database' => 'Stwrz now baz danych',
         'A message must be spell checked!' => 'Wiadomo musi zosta sprawdzona sownikiem!',
-        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => 'Twoja wiadomo o numerze zgoszenia: "<OTRS_TICKET>" zostaa przekazana na adres "<OTRS_BOUNCE_TO>" . Prosimy kontaktowa si pod tym adresem we wszystkich sprawach dotyczcych tego zgoszenia.',
+        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'Twoja wiadomo o numerze zgoszenia: "<OTRS_TICKET>" zostaa przekazana na adres "<OTRS_BOUNCE_TO>" . Prosimy kontaktowa si pod tym adresem we wszystkich sprawach dotyczcych tego zgoszenia.',
         'ArticleID' => 'ID Artykuu',
         'A message should have a body!' => 'Wiadomo powinna zawiera jak tre!',
         'All Agents' => 'Wszyscy agenci',
@@ -1400,6 +1454,7 @@ sub Data {
         'OTRS DB Password' => 'Haso dostpu do bazy dla OTRS',
         'Last update' => 'Ostatnia aktualizacja',
         'to get the first 20 character of the subject' => 'by wstawi pierwsze 20 znakw tematu',
+        'Select the customeruser:service relations.' => '',
         'DB Admin Password' => 'Haso Administratora bazy danych',
         'Drop Database' => 'Usu baz danych',
         'FileManager' => '',
@@ -1429,11 +1484,12 @@ sub Data {
         'WebWatcher' => '',
         'Finished' => 'Zakoczono',
         'Split' => 'Podziel',
+        'D' => '',
         'All messages' => 'Wszystkie wiadomoci',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => '',
         'A article should have a title!' => '',
-        'Event' => '',
         'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => '',
+        'Event' => '',
         'don\'t accept license' => 'nie akceptuj Licencji',
         'A web mail client' => '',
         'WebMail' => '',
@@ -1444,23 +1500,37 @@ sub Data {
         'to get the from line of the email' => 'by wstawi pole Od wiadomoci',
         'Solution' => 'Rozwizanie',
         'QueueView' => 'Podgld kolejki',
+        'Select Box' => 'Zapytanie SQL',
         'Welcome to OTRS' => '',
         'modified' => '',
+        'Escalation in' => 'Eskalowane w',
         'Delete old database' => 'Usu star baz danych',
         'sort downward' => 'sortuj malejco',
         'You need to use a ticket number!' => '',
         'A web file manager' => '',
+        'Have a lot of fun!' => 'yczymy dobrej zabawy!',
         'send' => 'wylij',
         'Note Text' => 'Tekst notatki',
+        'POP3 Account Management' => 'Konfiguracja kont POP3',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => '',
         'System State Management' => 'Konfiguracja statusw',
         'OTRS DB User' => 'Uytkownik bazy danych OTRS',
         'PhoneView' => 'Nowy telefon',
         'maximal period form' => '',
-        'Verion' => '',
         'TicketID' => 'ID Zgoszenia',
         'Modified' => 'Zmodyfikowany',
         'Ticket selected for bulk action!' => '',
+
+        'Link Object: %s' => '',
+        'Unlink Object: %s' => '',
+        'Linked as' => '',
+        'Can not create link with %s!' => '',
+        'Can not delete link with %s!' => '',
+        'Object already linked as %s.' => '',
+        'Priority Management' => '',
+        'Add a new Priority.' => '',
+        'Add Priority' => '',
+        'Ticket Type is required!' => '',
     };
     # $$STOP$$
     return;
