@@ -4,7 +4,7 @@
 # Copyright (C) 2005 Alterado por Glaucia C. Messina (glauglauu@yahoo.com)
 # Copyright (C) 2007 Fabricio Luiz Machado <soprobr gmail.com>
 # --
-# $Id: pt_BR.pm,v 1.56.2.2 2008/05/28 08:03:42 tr Exp $
+# $Id: pt_BR.pm,v 1.74 2008/08/06 11:48:12 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,25 +14,24 @@
 package Kernel::Language::pt_BR;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.56.2.2 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.74 $) [1];
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Tue May 29 15:21:38 2007
+    # Last translation file sync: Fri May 16 14:08:53 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%D.%M.%Y %T';
-    $Self->{DateFormatLong} = '%A %D %B %T %Y';
-    $Self->{DateFormatShort} = '%D.%M.%Y';
-    $Self->{DateInputFormat} = '%D.%M.%Y';
+    $Self->{DateFormat}          = '%D.%M.%Y %T';
+    $Self->{DateFormatLong}      = '%A %D %B %T %Y';
+    $Self->{DateFormatShort}     = '%D.%M.%Y';
+    $Self->{DateInputFormat}     = '%D.%M.%Y';
     $Self->{DateInputFormatLong} = '%D.%M.%Y - %T';
 
     $Self->{Translation} = {
@@ -106,6 +105,7 @@ sub Data {
         'please do not edit!' => 'Por favor, no edite!',
         'AddLink' => 'Adicionar link',
         'Link' => '',
+        'Unlink' => '',
         'Linked' => '',
         'Link (Normal)' => '',
         'Link (Parent)' => 'Link (Pai)',
@@ -247,6 +247,8 @@ sub Data {
         'Mobile' => 'Celular',
         'Zip' => 'CEP',
         'City' => 'Cidade',
+        'Location' => 'Locao',
+        'Street' => 'Rua',
         'Country' => 'Pas',
         'installed' => 'instalado',
         'uninstalled' => 'desinstalado',
@@ -255,6 +257,16 @@ sub Data {
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => '',
         'No Packages or no new Packages in selected Online Repository!' => '',
         'printed at' => 'impresso em',
+        'Dear Mr. %s,' => '',
+        'Dear Mrs. %s,' => '',
+        'Dear %s,' => '',
+        'Hello %s,' => '',
+        'This account exists.' => '',
+        'New account created. Sent Login-Account to %s.' => '',
+        'Please press Back and try again.' => '',
+        'Sent password token to: %s' => '',
+        'Sent new password to: %s' => '',
+        'Invalid Token!' => '',
 
         # Template: AAAMonth
         'Jan' => '',
@@ -385,6 +397,7 @@ sub Data {
         'Move' => 'Mover',
         'Queue' => 'Fila',
         'Priority' => 'Prioridade',
+        'Priority Update' => '',
         'State' => 'Estado',
         'Compose' => 'Compr',
         'Pending' => 'Pendentes',
@@ -453,6 +466,7 @@ sub Data {
         'Phone-Ticket' => 'Chamado-Fone',
         'Search Tickets' => 'Pesquisar Chamados',
         'Edit Customer Users' => 'Editar Clientes(Usurios)',
+        'Edit Customer Company' => '',
         'Bulk-Action' => 'Executar Ao',
         'Bulk Actions on Tickets' => 'Executar Ao nos Chamados',
         'Send Email and create a new Ticket' => 'Enviar mail e criar novo Chamado',
@@ -551,6 +565,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Requisio do Cliente via web.',
         'History::TicketLinkAdd' => 'Adicionados links ao Chamado "%s".',
         'History::TicketLinkDelete' => 'Links do Chamado Excludos "%s".',
+        'History::Subscribe' => 'Added subscription for user "%s".',
+        'History::Unsubscribe' => 'Removed subscription for user "%s".',
 
         # Template: AAAWeekDay
         'Sun' => 'Dom',
@@ -583,6 +599,7 @@ sub Data {
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => '',
+        'Search for' => 'Pesquisar por',
         'Add Customer Company' => '',
         'Add a new Customer Company.' => '',
         'List' => 'Lista',
@@ -591,7 +608,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'Administrao de Clientes',
-        'Search for' => 'Pesquisar por',
         'Add Customer User' => '',
         'Source' => 'Origem',
         'Create' => 'Criar',
@@ -610,14 +626,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
-        # Template: AdminCustomerUserServiceChangeForm
+        # Template: AdminCustomerUserService
         'Customer Users <-> Services Management' => '',
-        'Select the customeruser:service relations.' => '',
-        'Allocate services to CustomerUser' => '',
-        'Allocate CustomerUser to service' => '',
-
-        # Template: AdminCustomerUserServiceForm
+        'CustomerUser' => 'Usurio Cliente',
+        'Service' => '',
         'Edit default services.' => '',
+        'Search Result' => 'Resultado da Busca',
+        'Allocate services to CustomerUser' => '',
+        'Active' => 'Ativo',
+        'Allocate CustomerUser to service' => '',
 
         # Template: AdminEmail
         'Message sent to' => 'Mensagem enviada para',
@@ -640,6 +657,7 @@ sub Data {
         '(e. g. 234321)' => '(ex.: 234321)',
         'Customer User Login' => 'Cliente Login',
         '(e. g. U5150)' => '(ex.: U5150)',
+        'SLA' => '',
         'Agent' => 'Atendente',
         'Ticket Lock' => 'Chamado bloqueado',
         'TicketFreeFields' => 'Campos livres do Chamado',
@@ -647,10 +665,16 @@ sub Data {
         'No create time settings.' => '',
         'Ticket created' => 'Chamado criado',
         'Ticket created between' => 'Chamado criado entre',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Pending Times' => '',
         'No pending time settings.' => '',
         'Ticket pending time reached' => '',
         'Ticket pending time reached between' => '',
+        'New Service' => '',
+        'New SLA' => '',
         'New Priority' => 'Nova Prioridade',
         'New Queue' => 'Nova Fila',
         'New State' => 'Novo Estado',
@@ -658,7 +682,9 @@ sub Data {
         'New Owner' => 'Novo Proprietrio',
         'New Customer' => 'Novo Cliente',
         'New Ticket Lock' => 'Chamado novo bloqueado',
-        'CustomerUser' => 'Usurio Cliente',
+        'New Type' => '',
+        'New Title' => '',
+        'New Type' => '',
         'New TicketFreeFields' => 'Novos campos livres do Chamado',
         'Add Note' => 'Adicionar Nota',
         'CMD' => 'Comando',
@@ -691,6 +717,14 @@ sub Data {
         'System Log' => 'Registro do Sistema',
         'Time' => 'Hora',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => '',
+        'Host' => 'Servidor',
+        'Trusted' => 'Confivel',
+        'Dispatching' => 'Despachando',
+        'All incoming emails with one account will be dispatched in the selected queue!' => 'Todos os emails de entrada com uma conta ser despachado na fila selecionada!',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => 'Se a sua conta for "trusted", os headers "X-OTRS" existentes na recepo (para prioridade, ...) sero utilizados! O filtro ser utilizado mesmo assim.',
+
         # Template: AdminNavigationBar
         'Users' => 'Usurios',
         'Groups' => 'Grupos',
@@ -745,6 +779,10 @@ sub Data {
         'Min Response' => 'Tempo mnimo de resposta',
         'Max Response' => 'Tempo mximo de resposta',
         'Average Response' => 'Mdia de tempo de resposta',
+        'Period' => '',
+        'Min' => '',
+        'Max' => '',
+        'Average' => '',
 
         # Template: AdminPGPForm
         'PGP Management' => 'Gerenciamento do PGP',
@@ -756,14 +794,6 @@ sub Data {
         'Expires' => 'Expira',
         'In this way you can directly edit the keyring configured in SysConfig.' => 'Neste caso, voc pode editar diretamente o "keyring" configurado no "SysConfig".',
 
-        # Template: AdminPOP3
-        'POP3 Account Management' => 'Gerenciamento de Contas POP3',
-        'Host' => 'Servidor',
-        'Trusted' => 'Confivel',
-        'Dispatching' => 'Despachando',
-        'All incoming emails with one account will be dispatched in the selected queue!' => 'Todos os emails de entrada com uma conta ser despachado na fila selecionada!',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => 'Se a sua conta for "trusted", os headers "X-OTRS" existentes na recepo (para prioridade, ...) sero utilizados! O filtro ser utilizado mesmo assim.',
-
         # Template: AdminPostMasterFilter
         'PostMaster Filter Management' => 'Adm Filtros Postmaster',
         'Filtername' => 'Nome Filtro',
@@ -783,9 +813,13 @@ sub Data {
         'Sub-Queue of' => 'Sub-Fila de',
         'Unlock timeout' => 'Tempo de expirao de desbloqueio',
         '0 = no unlock' => '0 = sem desbloqueio',
+        'Only business hours are counted.' => '',
         'Escalation - First Response Time' => '',
         '0 = no escalation' => '0 = sem escalao',
+        'Only business hours are counted.' => '',
+        'Notify by' => '',
         'Escalation - Update Time' => '',
+        'Notify by' => '',
         'Escalation - Solution Time' => '',
         'Follow up Option' => 'Opo de continuao',
         'Ticket lock after a follow up' => 'Bloqueio do chamado aps as continuaes',
@@ -845,7 +879,6 @@ sub Data {
 
         # Template: AdminRoleUserChangeForm
         'Roles <-> Users Management' => 'Papel <-> Gerenciamento de Usurios',
-        'Active' => 'Ativo',
         'Select the role:user relations.' => 'Selecione a relao entre o papel/usurio.',
 
         # Template: AdminRoleUserForm
@@ -856,7 +889,7 @@ sub Data {
         'Add a new Salutation.' => '',
 
         # Template: AdminSelectBoxForm
-        'Select Box' => 'Caixa de Seleo',
+        'SQL Box' => '',
         'Limit' => 'Limite',
         'Go' => '',
         'Select Box Result' => 'Selecione a Caixa de Resultado',
@@ -865,7 +898,6 @@ sub Data {
         'Service Management' => '',
         'Add Service' => '',
         'Add a new Service.' => '',
-        'Service' => '',
         'Sub-Service of' => '',
 
         # Template: AdminSession
@@ -886,10 +918,6 @@ sub Data {
         'SLA Management' => '',
         'Add SLA' => '',
         'Add a new SLA.' => '',
-        'SLA' => '',
-        'First Response Time' => '',
-        'Update Time' => '',
-        'Solution Time' => '',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => 'Gerenciamento S/MIME',
@@ -1044,7 +1072,7 @@ sub Data {
         'Scale' => 'Escala',
         'minimal' => 'mnimo',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => 'Lembre que a escala para o conjunto de valores deve ser mair que o eixo X (ex.: Eixo X => Ms, Conjunto de Valores => Ano).',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => ' possvel escolher um ou dois elementos. Ento voc pode selecionar os atributos dos elementos. Cada atributo ser mostrado como um conjunto nico de valores. Se voc no selecionar nenhum atributo todos os atributos do elemento sero utilizados para gerar a estatstica. Assim como um novo atributo  adicionado desde a ltima configurao.',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => ' possvel escolher um ou dois elementos. Ento voc pode selecionar os atributos dos elementos. Cada atributo ser mostrado como um conjunto nico de valores. Se voc no selecionar nenhum atributo todos os atributos do elemento sero utilizados para gerar a estatstica. Assim como um novo atributo  adicionado desde a ltima configurao.',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => 'Selecione o elemento que ser usado no eixo X',
@@ -1124,6 +1152,17 @@ sub Data {
         'Refresh' => 'Atualizar',
         'Clear To' => 'Limpar',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => '',
+        'Escalation' => '',
+        'Today' => '',
+        'Tomorrow' => '',
+        'Next Week' => '',
+        'up' => 'normal',
+        'down' => 'inversa',
+        'Escalation' => '',
+        'Locked' => 'Bloqueado',
+
         # Template: AgentTicketForward
         'Article type' => 'Tipo de artigo',
 
@@ -1144,8 +1183,6 @@ sub Data {
         'Reminder' => 'Lembretes',
         'Sort by' => 'Ordenado pela',
         'Order' => 'Ordem',
-        'up' => 'normal',
-        'down' => 'inversa',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => 'Unir Chamado',
@@ -1175,7 +1212,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => 'Informao do Chamado',
         'Accounted time' => 'Tempo contabilizado',
-        'Escalation in' => 'Escalado em',
+        'First Response Time' => '',
+        'Update Time' => '',
+        'Solution Time' => '',
         'Linked-Object' => 'Objeto "Linkado"',
         'Parent-Object' => 'Objeto Pai',
         'Child-Object' => 'Objeto Filho',
@@ -1210,29 +1249,35 @@ sub Data {
         'Search-Template' => 'Modelo de Busca',
         'TicketFreeText' => 'Texto livre Chamado',
         'Created in Queue' => 'Criado na Fila',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Result Form' => 'Resultado',
         'Save Search-Profile as Template?' => 'Salvar o Perfil de Busca como Modelo?',
         'Yes, save it with name' => 'Sim, salve-o com o nome',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
-        'Search Result' => 'Resultado da Busca',
         'Change search options' => 'Alterar as oes de busca',
 
         # Template: AgentTicketSearchResultPrint
 
         # Template: AgentTicketSearchResultShort
-        'U' => 'C',
-        'D' => '',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => 'Visualizao do Status do Chamado',
         'Open Tickets' => 'Chamados Abertos',
-        'Locked' => 'Bloqueado',
 
         # Template: AgentTicketZoom
+        'Expand View' => '',
+        'Collapse View' => '',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1300,15 +1345,18 @@ sub Data {
 
         # Template: Installer
         'Web-Installer' => 'Instalador Web',
+        'Welcome to %s' => '',
         'Accept license' => '',
         'Don\'t accept license' => '',
         'Admin-User' => 'Usurio do Administrador',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => '',
         'Admin-Password' => 'Senha do Administrador',
-        'your MySQL DB should have a root password! Default is empty!' => 'O seu MySQL deve ter uma senha de "root"! O padro  em branco!',
         'Database-User' => 'Usurio da Base',
         'default \'hot\'' => 'padro \'hot\'',
         'DB connect host' => 'Servidor da Base',
         'Database' => 'Base de Dados',
+        'Default Charset' => 'Conjunto de Caracteres Padro',
+        'utf8' => '',
         'false' => 'falso',
         'SystemID' => 'ID do sistema',
         '(The identify of the system. Each ticket number and each http session id starts with this number)' => '(A identidade do sistema. Cada nmero de chamado e cada id. da sesso http, inicia com este nmero)',
@@ -1323,7 +1371,6 @@ sub Data {
         'Logfile' => 'Arquivo de registro',
         '(Logfile just needed for File-LogModule!)' => '(Arquivo de registro para File-LogModule)',
         'Webfrontend' => 'Interface Web',
-        'Default Charset' => 'Conjunto de Caracteres Padro',
         'Use utf-8 it your database supports it!' => 'A sua Base de dados suporta utf-8!',
         'Default Language' => 'Idioma Padro',
         '(Used default language)' => '(Idioma padro utilizado)',
@@ -1333,11 +1380,9 @@ sub Data {
         'Restart your webserver' => 'Reiniciar o Webserver',
         'After doing so your OTRS is up and running.' => 'Aps isto, ento seu OTRS est funcionando.',
         'Start page' => 'Iniciar pgina',
-        'Have a lot of fun!' => 'Divirta-se!',
         'Your OTRS Team' => 'Equipe Service Desk SAP',
 
         # Template: Login
-        'Welcome to %s' => '',
 
         # Template: Motd
 
@@ -1365,14 +1410,15 @@ sub Data {
         'Change roles <-> groups settings' => 'Alterar configuraes Regras <-> Grupos',
         'Ticket Number Generator' => 'Gerador de Nmeros de Chamados',
         '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(Identificador Chamado. Algumas pessoas gostam de usar por exemplo \'Chamado#\, \'Chamado#\' ou \'MeuChamado#\')',
-        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'Neste caso, voc pode editar diretamente a "keyring" configurada no Kernel/Config.pm.',
         'Create new Phone Ticket' => 'Criar novo Fone Chamado',
+        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'Neste caso, voc pode editar diretamente a "keyring" configurada no Kernel/Config.pm.',
         'Symptom' => 'Sintoma',
+        'U' => 'C',
         'A message should have a To: recipient!' => 'Uma mensagem deve possuir um To: destinatrio!',
         'Options of the current user who requested this action (e. g. OTRS_CURRENT_USERFIRSTNAME)' => 'Opes do usurio atual que requisitou esta ao (ex.: OTRS_CURRENT_USERFIRSTNAME)',
         'Customer history search (e. g. "ID342425").' => 'Busca no Histrico do cliente (exemplo: "ID342425")',
-        'Close!' => 'Fechar!',
         'for agent firstname' => 'Nome do Atendente',
+        'Close!' => 'Fechar!',
         'The message being composed has been closed.  Exiting.' => 'A mensagem sendo composta foi fechada. Saindo.',
         'A web calendar' => 'Calendrio',
         'to get the realname of the sender (if given)' => 'para obter o nome do remetente (se possuir no email)',
@@ -1380,8 +1426,8 @@ sub Data {
         'Select Source (for add)' => 'Selecione Origem (para adio)',
         'Options of the ticket data (e. g. &lt;OTRS_TICKET_Number&gt;, &lt;OTRS_TICKET_ID&gt;, &lt;OTRS_TICKET_Queue&gt;, &lt;OTRS_TICKET_State&gt;)' => '',
         'Config options (e. g. OTRS_CONFIG_HttpType)' => 'Opes de configurao (ex.: OTRS_CONFIG_HttpType)',
-        'Queue ID' => 'ID da Fila',
         'Locked tickets' => 'Chamados Bloqueados',
+        'Queue ID' => 'ID da Fila',
         'Home' => 'Incio',
         'System History' => 'Histrico do Sistema',
         'customer realname' => 'Nome do cliente',
@@ -1413,6 +1459,7 @@ sub Data {
         'to get the first 5 lines of the email' => 'para obter as 5 primeiras linhas do email',
         'Last update' => 'ltima Atualizao',
         'to get the first 20 character of the subject' => 'para obter os 20 primeiros caracteres do assunto',
+        'Select the customeruser:service relations.' => '',
         'Advisory' => 'Aviso',
         'FileManager' => 'Adm Arquivo',
         'Pending type' => 'Tipo de pendncia',
@@ -1437,6 +1484,7 @@ sub Data {
         'WebWatcher' => 'Visitante',
         'Finished' => 'Finalizado',
         'Split' => 'Dividir',
+        'D' => '',
         'All messages' => 'Todas as mensagens',
         'Artefact' => 'Artefato',
         'A article should have a title!' => 'O Artigo dever ter um Ttulo!',
@@ -1450,21 +1498,35 @@ sub Data {
         'Solution' => 'Soluo',
         'QueueView' => 'Fila',
         'Options of the ticket data (e. g. OTRS_TICKET_TicketNumber, OTRS_TICKET_ID, OTRS_TICKET_Queue, OTRS_TICKET_State)' => 'Opes de dados do chamado (ex.: OTRS_TICKET_TicketNumber, OTRS_TICKET_ID, OTRS_TICKET_Queue, OTRS_TICKET_State)',
+        'Select Box' => 'Caixa de Seleo',
         'Welcome to OTRS' => 'Bem-vindo ao OTRS',
         'modified' => 'modificado',
+        'Escalation in' => 'Escalado em',
         'sort downward' => 'ordem decrescente',
         'You need to use a ticket number!' => 'Voc deve utilizar um nmero de chamado!',
         'A web file manager' => 'Adm Arquivo Web',
+        'Have a lot of fun!' => 'Divirta-se!',
         'send' => 'enviar',
         'Note Text' => 'Nota',
+        'POP3 Account Management' => 'Gerenciamento de Contas POP3',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => '',
         'System State Management' => 'Gerenciamento de Estados do Sistema',
         'PhoneView' => 'Chamada',
         'maximal period form' => 'formulrio de perodo mximo',
-        'Verion' => 'Verso',
         'TicketID' => 'Id.do Chamado',
         'Modified' => 'Modificado',
         'Ticket selected for bulk action!' => 'Chamado selecionado para execuo de ao!',
+
+        'Link Object: %s' => '',
+        'Unlink Object: %s' => '',
+        'Linked as' => '',
+        'Can not create link with %s!' => '',
+        'Can not delete link with %s!' => '',
+        'Object already linked as %s.' => '',
+        'Priority Management' => '',
+        'Add a new Priority.' => '',
+        'Add Priority' => '',
+        'Ticket Type is required!' => '',
     };
     # $$STOP$$
     return;
