@@ -2,7 +2,7 @@
 # Kernel/Language/sk_SK.pm - provides sk_SK language translation
 # Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: sk_SK.pm,v 1.22.2.2 2008/05/28 08:03:42 tr Exp $
+# $Id: sk_SK.pm,v 1.40 2008/08/06 11:48:12 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,25 +12,24 @@
 package Kernel::Language::sk_SK;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.22.2.2 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.40 $) [1];
 
 sub Data {
     my $Self = shift;
-    my %Param = @_;
 
     # $$START$$
-    # Last translation file sync: Tue May 29 15:24:37 2007
+    # Last translation file sync: Fri May 16 14:08:59 2008
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-2', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
-    $Self->{DateFormat} = '%D.%M.%Y %T';
-    $Self->{DateFormatLong} = '%A %D %B %T %Y';
-    $Self->{DateFormatShort} = '%D.%M.%Y';
-    $Self->{DateInputFormat} = '%D.%M.%Y';
+    $Self->{DateFormat}          = '%D.%M.%Y %T';
+    $Self->{DateFormatLong}      = '%A %D %B %T %Y';
+    $Self->{DateFormatShort}     = '%D.%M.%Y';
+    $Self->{DateInputFormat}     = '%D.%M.%Y';
     $Self->{DateInputFormatLong} = '%D.%M.%Y - %T';
 
     $Self->{Translation} = {
@@ -104,6 +103,7 @@ sub Data {
         'please do not edit!' => 'Prosm neupravova!',
         'AddLink' => 'Prida odkaz.',
         'Link' => 'Prepojenie',
+        'Unlink' => '',
         'Linked' => 'spojen',
         'Link (Normal)' => 'Prepojenie (obyajn)',
         'Link (Parent)' => 'Prepojenie (zdroj)',
@@ -199,7 +199,7 @@ sub Data {
         'There is no account with that login name.' => 'Neexistuje iadny et s tmto vateskm menom',
         'Login failed! Your username or password was entered incorrectly.' => 'Prihlsenie zlyhalo! Vae pouvatesk meno alebo heslo bolo vloen nesprvne.',
         'Please contact your admin' => 'Prosm kontaktujte vho administrtora.',
-        'Logout successful. Thank you for using OTRS!' => 'Odhlsenie spen. akujeme za pouvanie ORTS!',
+        'Logout successful. Thank you for using OTRS!' => 'Odhlsenie spen. akujeme za pouvanie OTRS!',
         'Invalid SessionID!' => 'Neplatn SessionID',
         'Feature not active!' => 'Funkcia neaktvna!',
         'Login is needed!' => '',
@@ -245,6 +245,8 @@ sub Data {
         'Mobile' => '',
         'Zip' => '',
         'City' => '',
+        'Location' => '',
+        'Street' => '',
         'Country' => '',
         'installed' => 'naintalovan',
         'uninstalled' => 'odintalovan',
@@ -253,6 +255,16 @@ sub Data {
         'No Packages for requested Framework in this Online Repository, but Packages for other Frameworks!' => '',
         'No Packages or no new Packages in selected Online Repository!' => '',
         'printed at' => '',
+        'Dear Mr. %s,' => '',
+        'Dear Mrs. %s,' => '',
+        'Dear %s,' => '',
+        'Hello %s,' => '',
+        'This account exists.' => '',
+        'New account created. Sent Login-Account to %s.' => '',
+        'Please press Back and try again.' => '',
+        'Sent password token to: %s' => '',
+        'Sent new password to: %s' => '',
+        'Invalid Token!' => '',
 
         # Template: AAAMonth
         'Jan' => 'jan',
@@ -383,6 +395,7 @@ sub Data {
         'Move' => 'Presun',
         'Queue' => 'Fronta',
         'Priority' => 'Priorita',
+        'Priority Update' => '',
         'State' => 'Stav',
         'Compose' => 'Vytvori',
         'Pending' => 'akanie',
@@ -451,6 +464,7 @@ sub Data {
         'Phone-Ticket' => 'Telefonick poiadavka',
         'Search Tickets' => 'Hadaj poiadavky',
         'Edit Customer Users' => 'Uprav zkaznckeho uvatea.',
+        'Edit Customer Company' => '',
         'Bulk-Action' => 'Hromadn akcia',
         'Bulk Actions on Tickets' => 'hromadn akcie na poiadavkch.',
         'Send Email and create a new Ticket' => 'Poli e-mail a vytvor nov poiadavku',
@@ -549,6 +563,8 @@ sub Data {
         'History::WebRequestCustomer' => 'Histria: ',
         'History::TicketLinkAdd' => 'Histria: ',
         'History::TicketLinkDelete' => 'Histria: ',
+        'History::Subscribe' => 'Added subscription for user "%s".',
+        'History::Unsubscribe' => 'Removed subscription for user "%s".',
 
         # Template: AAAWeekDay
         'Sun' => 'Ned',
@@ -581,6 +597,7 @@ sub Data {
 
         # Template: AdminCustomerCompanyForm
         'Customer Company Management' => '',
+        'Search for' => 'Hada',
         'Add Customer Company' => '',
         'Add a new Customer Company.' => '',
         'List' => '',
@@ -589,7 +606,6 @@ sub Data {
 
         # Template: AdminCustomerUserForm
         'Customer User Management' => 'Riadenie klientskch uvateov.',
-        'Search for' => 'Hada',
         'Add Customer User' => '',
         'Source' => 'zdroj',
         'Create' => '',
@@ -608,14 +624,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
-        # Template: AdminCustomerUserServiceChangeForm
+        # Template: AdminCustomerUserService
         'Customer Users <-> Services Management' => '',
-        'Select the customeruser:service relations.' => '',
-        'Allocate services to CustomerUser' => '',
-        'Allocate CustomerUser to service' => '',
-
-        # Template: AdminCustomerUserServiceForm
+        'CustomerUser' => '',
+        'Service' => '',
         'Edit default services.' => '',
+        'Search Result' => '',
+        'Allocate services to CustomerUser' => '',
+        'Active' => '',
+        'Allocate CustomerUser to service' => '',
 
         # Template: AdminEmail
         'Message sent to' => '',
@@ -638,6 +655,7 @@ sub Data {
         '(e. g. 234321)' => '',
         'Customer User Login' => '',
         '(e. g. U5150)' => '',
+        'SLA' => '',
         'Agent' => '',
         'Ticket Lock' => '',
         'TicketFreeFields' => '',
@@ -645,10 +663,16 @@ sub Data {
         'No create time settings.' => '',
         'Ticket created' => 'Pripomienka vytvoren',
         'Ticket created between' => 'Pripomienka vytvoren medzi',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Pending Times' => '',
         'No pending time settings.' => '',
         'Ticket pending time reached' => '',
         'Ticket pending time reached between' => '',
+        'New Service' => '',
+        'New SLA' => '',
         'New Priority' => 'Nov priorita',
         'New Queue' => 'Nov rad',
         'New State' => 'Nov stav',
@@ -656,7 +680,9 @@ sub Data {
         'New Owner' => 'Nov ',
         'New Customer' => 'Nov zkaznk',
         'New Ticket Lock' => 'CustomerUser',
-        'CustomerUser' => '',
+        'New Type' => '',
+        'New Title' => '',
+        'New Type' => '',
         'New TicketFreeFields' => '',
         'Add Note' => '',
         'CMD' => 'This command will be executed. ARG[0] will be the ticket number. ARG[1] the ticket id.',
@@ -689,6 +715,14 @@ sub Data {
         'System Log' => '',
         'Time' => '',
 
+        # Template: AdminMailAccount
+        'Mail Account Management' => '',
+        'Host' => 'Trusted',
+        'Trusted' => '',
+        'Dispatching' => '',
+        'All incoming emails with one account will be dispatched in the selected queue!' => '',
+        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
+
         # Template: AdminNavigationBar
         'Users' => '',
         'Groups' => '',
@@ -743,6 +777,10 @@ sub Data {
         'Min Response' => '',
         'Max Response' => '',
         'Average Response' => '',
+        'Period' => '',
+        'Min' => '',
+        'Max' => '',
+        'Average' => '',
 
         # Template: AdminPGPForm
         'PGP Management' => '',
@@ -754,14 +792,6 @@ sub Data {
         'Expires' => '',
         'In this way you can directly edit the keyring configured in SysConfig.' => '',
 
-        # Template: AdminPOP3
-        'POP3 Account Management' => 'Host',
-        'Host' => 'Trusted',
-        'Trusted' => '',
-        'Dispatching' => '',
-        'All incoming emails with one account will be dispatched in the selected queue!' => '',
-        'If your account is trusted, the already existing X-OTRS header at arrival time (for priority, ...) will be used! PostMaster filter will be used anyway.' => '',
-
         # Template: AdminPostMasterFilter
         'PostMaster Filter Management' => 'Filtername',
         'Filtername' => 'Match',
@@ -781,9 +811,13 @@ sub Data {
         'Sub-Queue of' => '',
         'Unlock timeout' => '0 = no unlock',
         '0 = no unlock' => '',
+        'Only business hours are counted.' => '',
         'Escalation - First Response Time' => '',
         '0 = no escalation' => '',
+        'Only business hours are counted.' => '',
+        'Notify by' => '',
         'Escalation - Update Time' => '',
+        'Notify by' => '',
         'Escalation - Solution Time' => '',
         'Follow up Option' => '',
         'Ticket lock after a follow up' => '',
@@ -843,7 +877,6 @@ sub Data {
 
         # Template: AdminRoleUserChangeForm
         'Roles <-> Users Management' => '',
-        'Active' => '',
         'Select the role:user relations.' => '',
 
         # Template: AdminRoleUserForm
@@ -854,7 +887,7 @@ sub Data {
         'Add a new Salutation.' => '',
 
         # Template: AdminSelectBoxForm
-        'Select Box' => '',
+        'SQL Box' => '',
         'Limit' => '',
         'Go' => '',
         'Select Box Result' => '',
@@ -863,7 +896,6 @@ sub Data {
         'Service Management' => '',
         'Add Service' => '',
         'Add a new Service.' => '',
-        'Service' => '',
         'Sub-Service of' => '',
 
         # Template: AdminSession
@@ -884,10 +916,6 @@ sub Data {
         'SLA Management' => '',
         'Add SLA' => '',
         'Add a new SLA.' => '',
-        'SLA' => '',
-        'First Response Time' => '',
-        'Update Time' => '',
-        'Solution Time' => '',
 
         # Template: AdminSMIMEForm
         'S/MIME Management' => '',
@@ -1042,7 +1070,7 @@ sub Data {
         'Scale' => '',
         'minimal' => '',
         'Please remember, that the scale for value series has to be larger than the scale for the X-axis (e.g. X-Axis => Month, ValueSeries => Year).' => '',
-        'Here you can the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
+        'Here you can define the value series. You have the possibility to select one or two elements. Then you can select the attributes of elements. Each attribute will be shown as single value series. If you don\'t select any attribute all attributes of the element will be used if you generate a stat. As well a new attribute is added since the last configuration.' => '',
 
         # Template: AgentStatsEditXaxis
         'Select the element, which will be used at the X-axis' => '',
@@ -1122,6 +1150,17 @@ sub Data {
         'Refresh' => '',
         'Clear To' => 'vyma: Komu',
 
+        # Template: AgentTicketEscalationView
+        'Ticket Escalation View' => '',
+        'Escalation' => '',
+        'Today' => '',
+        'Tomorrow' => '',
+        'Next Week' => '',
+        'up' => '',
+        'down' => '',
+        'Escalation' => '',
+        'Locked' => '',
+
         # Template: AgentTicketForward
         'Article type' => 'typ lnku',
 
@@ -1142,8 +1181,6 @@ sub Data {
         'Reminder' => '',
         'Sort by' => '',
         'Order' => '',
-        'up' => '',
-        'down' => '',
 
         # Template: AgentTicketMerge
         'Ticket Merge' => '',
@@ -1173,7 +1210,9 @@ sub Data {
         # Template: AgentTicketPrint
         'Ticket-Info' => 'info o poiadavkch',
         'Accounted time' => 'Escalation in',
-        'Escalation in' => '',
+        'First Response Time' => '',
+        'Update Time' => '',
+        'Solution Time' => '',
         'Linked-Object' => '',
         'Parent-Object' => '',
         'Child-Object' => '',
@@ -1208,29 +1247,35 @@ sub Data {
         'Search-Template' => '',
         'TicketFreeText' => '',
         'Created in Queue' => '',
+        'Close Times' => '',
+        'No close time settings.' => '',
+        'Ticket closed' => '',
+        'Ticket closed between' => '',
         'Result Form' => '',
         'Save Search-Profile as Template?' => '',
         'Yes, save it with name' => '',
 
+        # Template: AgentTicketSearchOpenSearchDescription
+
         # Template: AgentTicketSearchResult
-        'Search Result' => '',
         'Change search options' => '',
 
         # Template: AgentTicketSearchResultPrint
 
         # Template: AgentTicketSearchResultShort
-        'U' => 'sort downward',
-        'D' => 'Ticket Status View',
 
         # Template: AgentTicketStatusView
         'Ticket Status View' => '',
         'Open Tickets' => '',
-        'Locked' => '',
 
         # Template: AgentTicketZoom
+        'Expand View' => '',
+        'Collapse View' => '',
 
         # Template: AgentWindowTab
 
+        # Template: AJAX
+
         # Template: Copyright
 
         # Template: css
@@ -1298,15 +1343,18 @@ sub Data {
 
         # Template: Installer
         'Web-Installer' => 'accept license',
+        'Welcome to %s' => 'Vitajte v %',
         'Accept license' => '',
         'Don\'t accept license' => '',
         'Admin-User' => '',
+        'If you have set a root password for your database, it must be entered here. If not, leave this field empty. For security reasons we do recommend setting a root password. For more information please refer to your database documentation.' => '',
         'Admin-Password' => '',
-        'your MySQL DB should have a root password! Default is empty!' => '',
         'Database-User' => '',
         'default \'hot\'' => '',
         'DB connect host' => '',
         'Database' => '',
+        'Default Charset' => 'Predvolen znakov sada',
+        'utf8' => '',
         'false' => '',
         'SystemID' => '',
         '(The identify of the system. Each ticket number and each http session id starts with this number)' => 'Identifikcia systmu. Kad slo poiadavky a kad http zana tmto slo.',
@@ -1321,7 +1369,6 @@ sub Data {
         'Logfile' => '',
         '(Logfile just needed for File-LogModule!)' => 'Sbor zznamov je potrebn pre Sbor Log Module!',
         'Webfrontend' => 'webov rozhranie',
-        'Default Charset' => 'Predvolen znakov sada',
         'Use utf-8 it your database supports it!' => 'Poui utf-8 na podporu Vaej databzy.',
         'Default Language' => 'Predvolen jazyk',
         '(Used default language)' => 'Pouvan predvolen jazyk',
@@ -1331,11 +1378,9 @@ sub Data {
         'Restart your webserver' => 'dat "nasledovne") do Vasho prikazoveho riadku (terminal/shell) =>  pricom musite byt prihlaseny ako root:',
         'After doing so your OTRS is up and running.' => 'Ak to urobte =>  V OTRS je spusten.',
         'Start page' => 'Prv strana',
-        'Have a lot of fun!' => 'Vea zbavy',
         'Your OTRS Team' => 'V OTRS tm',
 
         # Template: Login
-        'Welcome to %s' => 'Vitajte v %',
 
         # Template: Motd
 
@@ -1364,25 +1409,25 @@ sub Data {
         'Hlsenia s poslan zstupcovi alebo zkaznkovi.' => 'Config options (e. g. <OTRS_CONFIG_HttpType>)',
         'Nhad' => 'Download',
         'Poli mail!' => 'A message should have a subject!',
-        'Moduly' => 'Param 1',
         'Create Database' => 'Vytvor databzu',
+        'Moduly' => 'Param 1',
         'vsetky zakaznikove premenne ako tie definovane v konfiguracnej moznosti (volbe) CustomerUser' => 'The current ticket state is',
         'parameter 1' => 'Param 2',
-        'Skupiny' => 'Misc',
         'DB Host' => 'DB ',
+        'Skupiny' => 'Misc',
         'V e-mail s slom poiadavky <OTRS_POIADAVKA> je pripojen k <OTRS_PRIPOJI_K_POIADAVKE>' => 'Queue ID',
         'monosti konfigurcie (napr. <OTRS_CONFIG_HttpType>)' => 'Ticket owner options (e. g. <OTRS_OWNER_UserFirstname>)',
         'Meno' => 'Lastname',
         'Stiahnu' => 'Rebuild',
         'bit' => 'Key',
         'Reakcie <-> Rady manamentu' => 'Answer',
-        'dolu' => 'You need to use a ticket number!',
         'Ticket Number Generator' => 'Generova sel poiadaviek',
+        'dolu' => 'You need to use a ticket number!',
         'vsledok hadania ' => 'Change search options',
         'predchdzajci' => 'Block',
-        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'Tmto spsobom mete priamo upravova kov nastavenie v Kenel/Config.',
         'Create new Phone Ticket' => 'Vytvor nov telefonick poiadavku',
-        'Admin-heslo' => 'your MySQL DB should have a root password! Default is empty!',
+        'In this way you can directly edit the keyring configured in Kernel/Config.pm.' => 'Tmto spsobom mete priamo upravova kov nastavenie v Kenel/Config.',
+        'U' => 'sort downward',
         'riadenie relcie' => 'Sessions',
         'A message should have a To: recipient!' => '',
         'Poiadavky vybran pre hromadn akciu!' => 'You need min. one selected Ticket!',
@@ -1408,8 +1453,8 @@ sub Data {
         'Added User %s""' => 'Pridan pouvate %',
         'The message being composed has been closed.  Exiting.' => 'Vytvoren sprva bola zatvoren. ',
         'Prestava' => 'Reinstall',
-        'Rady <-> Riadenie automatickch odpoved' => 'Queue Management',
         'predvolen (?)' => 'DB connect host',
+        'Rady <-> Riadenie automatickch odpoved' => 'Queue Management',
         'A web calendar' => 'webov kalendr',
         'Tmto spsobom moene priamo meni osvedenie a osobn k v systme sborov.' => 'System State Management',
         'to get the realname of the sender (if given)' => 'zobrazi skuton meno odosielatea (ak je dan)',
@@ -1437,8 +1482,8 @@ sub Data {
         'Zaiatok strany' => 'Home',
         'Config options (e. g. <OTRS_CONFIG_HttpType>)' => '',
         'systmov zznam' => 'Time',
-        'pre priezvisko agenta' => 'for agent user id',
         'ID radu' => 'Move Ticket',
+        'pre priezvisko agenta' => 'for agent user id',
         'OTRS posiela klientom oznmenie e-mailom =>  ak bola poiadavka premiestnen.' => 'OTRS sends an notification email to the customer if the ticket state has changed.',
         'as' => 'Users',
         'pre meno agenta' => 'for agent lastname',
@@ -1447,11 +1492,11 @@ sub Data {
         'with' => 's',
         'Tlai' => 'Keywords',
         'Sprva poslan' => 'Recipents',
-        'riadenie balka' => 'Uninstall',
         'prida poznmku k poiadavke' => 'Inform Agent',
+        'riadenie balka' => 'Uninstall',
         'vyber prieinok' => 'SQL',
-        'Ticket %s" created!"' => 'poiadavka % vytvoren',
         'pripomienkov sprva' => 'Reminder',
+        'Ticket %s" created!"' => 'poiadavka % vytvoren',
         'DB Admin User' => 'DB admin pouvate',
         'detail' => 'Lookup',
         'for agent user id' => '',
@@ -1461,12 +1506,12 @@ sub Data {
         'Change user <-> group settings' => 'Zme pouvatea <-> nastavenie skupiny',
         'No such Ticket Number %s"! Can\'t link it!"' => 'iadna poiadavka slo %. ',
         'Can\'t update password =>  need 2 lower and 2 upper characters!' => 'Nemono aktualizova heslo =>  potrebujete 2 mal a 2 vek psmen',
-        'klientsk uvate' => 'Add Note',
         'Je to pouiten pre mnostvo uvateov a skupn.' => 'Roles <-> Groups Management',
+        'klientsk uvate' => 'Add Note',
         'vber skupiny' => 'Show',
         'Problem' => 'Solution',
-        'Zmazan poiadavky' => 'Warning! This tickets will be removed from the database! This tickets are lost!',
         'vsledky' => 'Total hits',
+        'Zmazan poiadavky' => 'Warning! This tickets will be removed from the database! This tickets are lost!',
         'Podrad (oho)' => 'Unlock timeout',
         'poiadavky' => 'All messages',
         'next step' => 'da krok',
@@ -1477,8 +1522,8 @@ sub Data {
         'hlsenie majitea klienta' => 'If an agent locks a ticket and he/she will not send an answer within this time =>  the ticket will be unlock automatically. So the ticket is viewable for all other agents.',
         'OTRS posiela klientom oznmenie e-mailom =>  ak sa zmenil stav poiadavky.' => 'OTRS sends an notification email to the customer if the ticket owner has changed.',
         'Spusti!' => 'x',
-        'Ine' => 'Notification Management',
         'Create new database' => 'Vytvor nov databzu',
+        'Ine' => 'Notification Management',
         'nov skupina RO' => 'New Group Ro',
         'Kontrola pravopisu' => 'spelling error(s)',
         'A message must be spell checked!' => '',
@@ -1504,8 +1549,8 @@ sub Data {
         'A message should have a body!' => '',
         'Kov slov' => 'Symptom',
         'as eskalcie' => '0 = no escalation',
-        'pridaj osobn k' => 'Secret',
         '(Ticket identifier. Some people want to set this to e. g. \'Ticket#\',\'Call#\' or \'MyTicket#\')' => '(Identifiktor poiadavky. Niektor udia to chc nastavi naprklad: \'Ticket#\', \'Call#\' alebo \'MyTicket#\')',
+        'pridaj osobn k' => 'Secret',
         'All Agents' => 'vetci agenti',
         'monosti' => 'Inform involved Agents',
         'Balk' => 'Online Repository',
@@ -1524,12 +1569,13 @@ sub Data {
         'OTRS DB Password' => 'OTRS DB heslo',
         'Hlavika' => 'Value',
         'matersk objekt' => 'Child-Object',
-        'Zatvori poiadavku' => 'Note Text',
-        'Options of the ticket data (e. g. <OTRS_TICKET_Number> =>  <OTRS_TICKET_ID> =>  <OTRS_TICKET_Queue> =>  <OTRS_TICKET_State>)' => 'Monosti dajov poiadavky (napr. <OTRS_TICKET_Number> =>  <OTRS_TICKET_ID> =>  <OTRS_TICKET_Queue> =>  <OTRS_TICKET_State>)',
         'to get the first 20 character of the subject' => 'zobrazi prvch 20 vlastnost subjektu',
+        'Options of the ticket data (e. g. <OTRS_TICKET_Number> =>  <OTRS_TICKET_ID> =>  <OTRS_TICKET_Queue> =>  <OTRS_TICKET_State>)' => 'Monosti dajov poiadavky (napr. <OTRS_TICKET_Number> =>  <OTRS_TICKET_ID> =>  <OTRS_TICKET_Queue> =>  <OTRS_TICKET_State>)',
+        'Zatvori poiadavku' => 'Note Text',
+        'Select the customeruser:service relations.' => '',
         'DB Admin Password' => 'DB heslo administrtora',
-        'miestna schrnka' => 'Status',
         'zrui relcie' => 'Signature Management',
+        'miestna schrnka' => 'Status',
         'histria klientskho hadania' => 'Customer history search (e. g. ID342425")."',
         'Povolenie zmeni majitea poiadavky v tejto skupine/rade.' => 'priority',
         'preskoi poiadavku' => 'Bounce to',
@@ -1600,8 +1646,8 @@ sub Data {
         'presu poiadavku' => 'Previous Owner',
         'You need a email address (e. g. customer@example.com) in To:!' => '',
         'triedi dolu' => 'D',
-        'Uvatelia' => 'Groups',
         'CreateTicket' => 'Vytvor poiadavku',
+        'Uvatelia' => 'Groups',
         'If nothing is selected =>  then there are no permissions in this group (tickets will not be available for the user).' => 'Ak nie je ni vybran =>  nie je dovolen pracova v tejto skupine (poiadavky nie s dostupn pre uvatea)',
         'vytvori nasledujcu' => 'Compose Answer',
         'parameter 2' => 'Param 3',
@@ -1611,23 +1657,24 @@ sub Data {
         'System Settings' => 'Systmov nastavenia',
         'WebWatcher' => '',
         'stav' => 'Overview',
-        'Povolenie zmeni prioritu poiadavky v tejto skupine/rade.' => 'Role',
         'Finished' => 'Ukonen',
+        'Povolenie zmeni prioritu poiadavky v tejto skupine/rade.' => 'Role',
         'vyhada' => 'Ticket selected for bulk action!',
         'nov sprvy' => 'Pending messages',
-        'typ poznmky' => 'Unlock Tickets',
         'Split' => '',
+        'typ poznmky' => 'Unlock Tickets',
+        'D' => 'Ticket Status View',
         'nov skupina' => 'Group Ro',
-        'All messages' => '',
         'System Status' => '',
+        'All messages' => '',
         'Options of the ticket data (e. g. <OTRS_TICKET_TicketNumber>, <OTRS_TICKET_ID>, <OTRS_TICKET_Queue>, <OTRS_TICKET_State>)' => '',
         'lohy  <-> riadenie skupn' => 'move_into',
         'odpove riadenia' => 'A response is default text to write faster answer (with default text) to customers.',
         'Artefact' => 'Artefakt',
         'zru vetky relcie' => 'Session',
         '0 = iadne zvyovanie' => 'Follow up Option',
-        'relcie' => 'Uniq',
         'pripojen poiadavka' => 'Merge to',
+        'relcie' => 'Uniq',
         'uzamkn poiadavku po nasledovnom' => 'Systemaddress',
         'Pozor! Tto poiadavka bude vymazan z databzy. Tieto poiadavky s straten!' => 'Modules',
         'profil' => 'Search-Template',
@@ -1645,13 +1692,13 @@ sub Data {
         'Ak je v et ' => 'PostMaster Filter Management',
         'poradie' => 'up',
         'dcrsky objekt' => 'by',
-        '(napr. U5150)' => 'Agent',
         'identifiktor' => 'Bit',
+        '(napr. U5150)' => 'Agent',
         'parameter 3' => 'Param 4',
         'pripoji k' => 'Your email with ticket number <OTRS_TICKET>" is merged to "<OTRS_MERGE_TO_TICKET>"."',
         'zmeni rady' => 'Ticket Search',
-        'Databza' => 'Create',
         'WebMail' => '',
+        'Databza' => 'Create',
         'generovan zstupca' => 'Job-List',
         'Potrebujete minimlne 1 vybran poiadavku!' => 'Spell Checker',
         'Ticket owner options (e. g. <OTRS_OWNER_UserFirstname>)' => '',
@@ -1675,6 +1722,7 @@ sub Data {
         'zvyova v' => 'Linked-Object',
         'My Queue' => 'Mj rad',
         'intalova' => 'Package',
+        'Select Box' => '',
         'Riadenie stavu systmu.' => 'State Type',
         'Admin-pouvate' => 'Admin-Password',
         'Monosti aktulneho pouvatea =>  ktor poaduje tieto akcie (napr. <OTRS_CURRENT_UserFirstname>)' => 'Options of the current customer user data (e. g. <OTRS_CUSTOMER_DATA_UserFirstname>)',
@@ -1684,14 +1732,14 @@ sub Data {
         'Can\'t update password =>  invalid characters!' => 'Nemono aktualizova heslo =>  neplatn znaky.',
         '(pracovn jednotka)' => 'A message must be spell checked!',
         'stupovanie poiadaviek' => 'Your own Ticket',
-        'Sajn' => 'Hash',
         'vber' => 'Results',
+        'Sajn' => 'Hash',
         'Adresa odosielatea tohto radu pre e-mailov odpove.' => 'The salutation for email answers.',
         'majite' => 'Permissions to change the ticket owner in this group/queue.',
         'Povolenie vytvori poiadavku v tejto skupine/rade.' => 'owner',
         'Ak nebude na poiadavku odpovedan do uritho asu =>  bude tto poiadavka zobrazen!' => 'If a ticket is closed and the customer sends a follow up the ticket will be locked for the old owner.',
-        '(napr. 234321)' => 'Customer User Login',
         'hlsenie stavu klienta' => 'Customer Owner Notify',
+        '(napr. 234321)' => 'Customer User Login',
         'typ postavenia' => 'Take care that you also updated the default states in you Kernel/Config.pm!',
         'Stiahnu nastavenia.' => 'Download all system config changes.',
         'Zme prioritu poiadavky.' => 'Tickets shown',
@@ -1700,11 +1748,12 @@ sub Data {
         'Dveryhodn' => 'Dispatching',
         'Zabudli ste heslo?' => 'Request new password',
         'Priezvisko' => 'User will be needed to handle tickets.',
+        'Escalation in' => '',
         'asti' => 'Config Options',
         'Sprva mus ma prjemcu!' => 'You need a email address (e. g. customer@example.com) in To:!',
         'Delete old database' => 'Vyma star databzu',
-        'Skuton meno' => 'All incoming emails with this Email" (To:) will be dispatched in the selected queue!"',
         'alebo' => 'Apply these changes',
+        'Skuton meno' => 'All incoming emails with this Email" (To:) will be dispatched in the selected queue!"',
         'Vsledok z' => 'Save Search-Profile as Template?',
         'sort downward' => '',
         'Vetky prichdzajce e-maily s prjemcom =>  bud vybaven v radoch.' => 'User Management',
@@ -1714,12 +1763,14 @@ sub Data {
         'riadenie funkci' => 'Create a role and put groups in it. Then add the role to the users.',
         'Muste napsa emailov adresu (napr. klient@prklad.com) do Prjemca:!' => 'Bounce ticket',
         'Tmto spsobom mete priamo upravova konfigurcie' => 'POP3 Account Management',
-        'Muste pouva slo poiadavky!' => 'Ticket Merge',
         'A web file manager' => 'Sprvca weborch sborov',
+        'Muste pouva slo poiadavky!' => 'Ticket Merge',
+        'Have a lot of fun!' => 'Vea zbavy',
         'Symptm' => 'Problem',
-        'Uloi prcu ako?' => 'Is Job Valid?',
         'no =>  ulo s menom.' => 'Customer history search',
+        'Uloi prcu ako?' => 'Is Job Valid?',
         'Platnos' => 'In this way you can directly edit the keyring configured in SysConfig.',
+        'POP3 Account Management' => 'Host',
         'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => '',
         'sprva systmovej e-mailovej adresy' => 'Email',
         'Skutone chcete odintalova tento balk?' => 'Install',
@@ -1727,7 +1778,6 @@ sub Data {
         'OTRS DB User' => 'OTRS DB pouvate',
         'systmov adresa' => 'Customer Move Notify',
         'maximal period form' => '',
-        'Verion' => 'Do you really want to uninstall this package?',
         'Vytvori et' => 'Welcome %s',
         'Unlock poiadavky.' => 'A message should have a body!',
         'TicketID' => 'ID poiadavky',
@@ -1750,6 +1800,17 @@ sub Data {
         'Sprva by mala ma predmet!' => 'Ticket Bulk Action',
         'blokova' => 'NavBar',
         'Ticket selected for bulk action!' => '',
+
+        'Link Object: %s' => '',
+        'Unlink Object: %s' => '',
+        'Linked as' => '',
+        'Can not create link with %s!' => '',
+        'Can not delete link with %s!' => '',
+        'Object already linked as %s.' => '',
+        'Priority Management' => '',
+        'Add a new Priority.' => '',
+        'Add Priority' => '',
+        'Ticket Type is required!' => '',
     };
     # $$STOP$$
     return;
