@@ -1,12 +1,12 @@
 # --
 # Kernel/Modules/AdminCustomerUserService.pm - to add/update/delete customerusers <-> services
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminCustomerUserService.pm,v 1.3 2007/07/30 14:51:02 mh Exp $
+# $Id: AdminCustomerUserService.pm,v 1.7 2008/05/08 09:36:36 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Modules::AdminCustomerUserService;
@@ -19,82 +19,83 @@ use Kernel::System::Service;
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.3 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.7 $) [1];
 
 sub new {
-    my $Type = shift;
-    my %Param = @_;
+    my ( $Type, %Param ) = @_;
 
     # allocate new hash for object
-    my $Self = {};
-    bless ($Self, $Type);
-
-    # get common opjects
-    foreach (keys %Param) {
-        $Self->{$_} = $Param{$_};
-    }
+    my $Self = {%Param};
+    bless( $Self, $Type );
 
     # check all needed objects
-    foreach (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
-        if (!$Self->{$_}) {
-            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+    for (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
+        if ( !$Self->{$_} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
         }
     }
     $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
-    $Self->{ServiceObject} = Kernel::System::Service->new(%Param);
-    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
+    $Self->{ServiceObject}      = Kernel::System::Service->new(%Param);
+    $Self->{ValidObject}        = Kernel::System::Valid->new(%Param);
 
     return $Self;
 }
 
 sub Run {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     # set search limit
     my $SearchLimit = 200;
 
     # ------------------------------------------------------------ #
     # allocate customer user
     # ------------------------------------------------------------ #
-    if ($Self->{Subaction} eq 'AllocateCustomerUser') {
+    if ( $Self->{Subaction} eq 'AllocateCustomerUser' ) {
+
         # get params
-        $Param{CustomerUserLogin} = $Self->{ParamObject}->GetParam(Param => "CustomerUserLogin") || '<DEFAULT>';
-        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam(Param => "CustomerUserSearch") || '*';
-        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam(Param => "ServiceSearch") || '*';
+        $Param{CustomerUserLogin} = $Self->{ParamObject}->GetParam( Param => 'CustomerUserLogin' )
+            || '<DEFAULT>';
+        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam( Param => 'CustomerUserSearch' )
+            || '*';
+        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam( Param => 'ServiceSearch' ) || '*';
+
         # output header
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
+
         # output search block
         $Self->{LayoutObject}->Block(
             Name => 'Search',
             Data => {
                 %Param,
                 CustomerUserSearch => $Param{CustomerUserSearch},
-                ServiceSearch => $Param{ServiceSearch},
+                ServiceSearch      => $Param{ServiceSearch},
             },
         );
+
         # output default block
-        $Self->{LayoutObject}->Block(
-            Name => 'Default',
-        );
+        $Self->{LayoutObject}->Block( Name => 'Default', );
+
         # get service member
         my %ServiceMemberList = $Self->{ServiceObject}->CustomerUserServiceMemberList(
             CustomerUserLogin => $Param{CustomerUserLogin},
-            Result => 'HASH',
-            DefaultServices => 0,
+            Result            => 'HASH',
+            DefaultServices   => 0,
         );
+
         # search services
         my @ServiceList = $Self->{ServiceObject}->ServiceSearch(
-            Name => $Param{ServiceSearch},
-            Limit => $SearchLimit + 1,
+            Name   => $Param{ServiceSearch},
+            Limit  => $SearchLimit + 1,
             UserID => $Self->{UserID},
         );
+
         # set max count
         my $MaxCount = @ServiceList;
-        if ($MaxCount > $SearchLimit) {
+        if ( $MaxCount > $SearchLimit ) {
             $MaxCount = $SearchLimit;
         }
+
         # output allocate block
         $Self->{LayoutObject}->Block(
             Name => 'AllocateCustomerUser',
@@ -104,116 +105,126 @@ sub Run {
                 %Param,
             },
         );
+
         # output count block
-        if (!@ServiceList) {
+        if ( !@ServiceList ) {
             $Self->{LayoutObject}->Block(
                 Name => 'AllocateCustomerUserServiceCountLimit',
-                Data => {
-                    ServiceCount => 0,
-                },
+                Data => { ServiceCount => 0, },
             );
         }
-        elsif (@ServiceList > $SearchLimit) {
+        elsif ( @ServiceList > $SearchLimit ) {
             $Self->{LayoutObject}->Block(
                 Name => 'AllocateCustomerUserServiceCountLimit',
-                Data => {
-                    ServiceCount => ">" . $SearchLimit,
-                },
+                Data => { ServiceCount => ">" . $SearchLimit, },
             );
         }
         else {
             $Self->{LayoutObject}->Block(
                 Name => 'AllocateCustomerUserServiceCount',
-                Data => {
-                    ServiceCount => scalar @ServiceList,
-                },
+                Data => { ServiceCount => scalar @ServiceList, },
             );
         }
         my $CssClass;
+
         # output rows
-        foreach my $Counter (1..$MaxCount) {
+        for my $Counter ( 1 .. $MaxCount ) {
+
             # set output class
-            if ($CssClass && $CssClass eq 'searchactive') {
+            if ( $CssClass && $CssClass eq 'searchactive' ) {
                 $CssClass = 'searchpassive';
             }
             else {
                 $CssClass = 'searchactive';
             }
+
             # get service
             my %Service = $Self->{ServiceObject}->ServiceGet(
-                ServiceID => $ServiceList[$Counter - 1],
-                UserID => $Self->{UserID},
+                ServiceID => $ServiceList[ $Counter - 1 ],
+                UserID    => $Self->{UserID},
             );
+
             # set checked
             my $Checked = '';
-            if ($ServiceMemberList{$Service{ServiceID}}) {
+            if ( $ServiceMemberList{ $Service{ServiceID} } ) {
                 $Checked = 'checked';
             }
+
             # output row block
             $Self->{LayoutObject}->Block(
                 Name => 'AllocateCustomerUserRow',
                 Data => {
-                    Service => $Service{Name},
+                    Service   => $Service{Name},
                     ServiceID => $Service{ServiceID},
-                    Checked => $Checked,
-                    CssClass => $CssClass,
+                    Checked   => $Checked,
+                    CssClass  => $CssClass,
                 },
             );
         }
+
         # generate output
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminCustomerUserService',
-            Data => \%Param,
+            Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
 
         return $Output;
     }
+
     # ------------------------------------------------------------ #
     # allocate service
     # ------------------------------------------------------------ #
-    elsif ($Self->{Subaction} eq 'AllocateService') {
+    elsif ( $Self->{Subaction} eq 'AllocateService' ) {
+
         # get params
-        $Param{ServiceID} = $Self->{ParamObject}->GetParam(Param => "ServiceID");
-        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam(Param => "CustomerUserSearch") || '*';
-        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam(Param => "ServiceSearch") || '*';
+        $Param{ServiceID}          = $Self->{ParamObject}->GetParam( Param => "ServiceID" );
+        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam( Param => "CustomerUserSearch" )
+            || '*';
+        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam( Param => "ServiceSearch" ) || '*';
+
         # output header
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
+
         # output search block
         $Self->{LayoutObject}->Block(
             Name => 'Search',
             Data => {
                 %Param,
                 CustomerUserSearch => $Param{CustomerUserSearch},
-                ServiceSearch => $Param{ServiceSearch},
+                ServiceSearch      => $Param{ServiceSearch},
             },
         );
+
         # output default block
-        $Self->{LayoutObject}->Block(
-            Name => 'Default',
-        );
+        $Self->{LayoutObject}->Block( Name => 'Default', );
+
         # get service
         my %Service = $Self->{ServiceObject}->ServiceGet(
             ServiceID => $Param{ServiceID},
-            UserID => $Self->{UserID},
+            UserID    => $Self->{UserID},
         );
+
         # get customer user member
         my %CustomerUserMemberList = $Self->{ServiceObject}->CustomerUserServiceMemberList(
-            ServiceID => $Param{ServiceID},
-            Result => 'HASH',
+            ServiceID       => $Param{ServiceID},
+            Result          => 'HASH',
             DefaultServices => 0,
         );
+
         # search customer user
-        my %CustomerUserList = $Self->{CustomerUserObject}->CustomerSearch(
-            Search => $Param{CustomerUserSearch},
-        );
-        my @CustomerUserKeyList = sort {$CustomerUserList{$a} cmp $CustomerUserList{$b}} keys %CustomerUserList;
+        my %CustomerUserList
+            = $Self->{CustomerUserObject}->CustomerSearch( Search => $Param{CustomerUserSearch}, );
+        my @CustomerUserKeyList
+            = sort { $CustomerUserList{$a} cmp $CustomerUserList{$b} } keys %CustomerUserList;
+
         # set max count
         my $MaxCount = @CustomerUserKeyList;
-        if ($MaxCount > $SearchLimit) {
+        if ( $MaxCount > $SearchLimit ) {
             $MaxCount = $SearchLimit;
         }
+
         # output allocate block
         $Self->{LayoutObject}->Block(
             Name => 'AllocateService',
@@ -223,276 +234,298 @@ sub Run {
                 %Param,
             },
         );
+
         # output count block
-        if (!@CustomerUserKeyList) {
+        if ( !@CustomerUserKeyList ) {
             $Self->{LayoutObject}->Block(
                 Name => 'AllocateServiceCustomerUserCountLimit',
-                Data => {
-                    CustomerUserCount => 0,
-                },
+                Data => { CustomerUserCount => 0, },
             );
         }
-        elsif (@CustomerUserKeyList > $SearchLimit) {
+        elsif ( @CustomerUserKeyList > $SearchLimit ) {
             $Self->{LayoutObject}->Block(
                 Name => 'AllocateServiceCustomerUserCountLimit',
-                Data => {
-                    CustomerUserCount => ">" . $SearchLimit,
-                },
+                Data => { CustomerUserCount => ">" . $SearchLimit, },
             );
         }
         else {
             $Self->{LayoutObject}->Block(
                 Name => 'AllocateServiceCustomerUserCount',
-                Data => {
-                    CustomerUserCount => scalar @CustomerUserKeyList,
-                },
+                Data => { CustomerUserCount => scalar @CustomerUserKeyList, },
             );
         }
         my $CssClass;
+
         # output rows
-        foreach my $Counter (1..$MaxCount) {
+        for my $Counter ( 1 .. $MaxCount ) {
+
             # set output class
-            if ($CssClass && $CssClass eq 'searchactive') {
+            if ( $CssClass && $CssClass eq 'searchactive' ) {
                 $CssClass = 'searchpassive';
             }
             else {
                 $CssClass = 'searchactive';
             }
+
             # set checked
             my $Checked = '';
-            if ($CustomerUserMemberList{$CustomerUserKeyList[$Counter - 1]}) {
+            if ( $CustomerUserMemberList{ $CustomerUserKeyList[ $Counter - 1 ] } ) {
                 $Checked = 'checked';
             }
+
             # output row block
             $Self->{LayoutObject}->Block(
                 Name => 'AllocateServiceRow',
                 Data => {
-                    CustomerUserLogin => $CustomerUserKeyList[$Counter - 1],
-                    CustomerUser => $CustomerUserList{$CustomerUserKeyList[$Counter - 1]},
-                    Checked => $Checked,
-                    CssClass => $CssClass,
+                    CustomerUserLogin => $CustomerUserKeyList[ $Counter - 1 ],
+                    CustomerUser      => $CustomerUserList{ $CustomerUserKeyList[ $Counter - 1 ] },
+                    Checked           => $Checked,
+                    CssClass          => $CssClass,
                 },
             );
         }
+
         # generate output
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminCustomerUserService',
-            Data => \%Param,
+            Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
 
         return $Output;
     }
+
     # ------------------------------------------------------------ #
     # allocate customer user save
     # ------------------------------------------------------------ #
-    elsif ($Self->{Subaction} eq 'AllocateCustomerUserSave') {
+    elsif ( $Self->{Subaction} eq 'AllocateCustomerUserSave' ) {
+
         # get params
-        $Param{CustomerUserLogin} = $Self->{ParamObject}->GetParam(Param => "CustomerUserLogin");
-        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam(Param => "CustomerUserSearch") || '*';
-        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam(Param => "ServiceSearch") || '*';
-        my @ServiceIDsSelected = $Self->{ParamObject}->GetArray(Param => "ServiceIDsSelected");
-        my @ServiceIDsAll = $Self->{ParamObject}->GetArray(Param => "ServiceIDsAll");
+        $Param{CustomerUserLogin}  = $Self->{ParamObject}->GetParam( Param => "CustomerUserLogin" );
+        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam( Param => "CustomerUserSearch" )
+            || '*';
+        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam( Param => "ServiceSearch" ) || '*';
+        my @ServiceIDsSelected = $Self->{ParamObject}->GetArray( Param => "ServiceIDsSelected" );
+        my @ServiceIDsAll      = $Self->{ParamObject}->GetArray( Param => "ServiceIDsAll" );
 
         # create hash with selected ids
         my %ServiceIDSelected;
-        foreach my $ServiceID (@ServiceIDsSelected) {
+        for my $ServiceID (@ServiceIDsSelected) {
             $ServiceIDSelected{$ServiceID} = 1;
         }
+
         # check all used service ids
-        foreach my $ServiceID (@ServiceIDsAll) {
+        for my $ServiceID (@ServiceIDsAll) {
             my $Active = 0;
-            if ($ServiceIDSelected{$ServiceID}) {
+            if ( $ServiceIDSelected{$ServiceID} ) {
                 $Active = 1;
             }
+
             # set customer user service member
             $Self->{ServiceObject}->CustomerUserServiceMemberAdd(
                 CustomerUserLogin => $Param{CustomerUserLogin},
-                ServiceID => $ServiceID,
-                Active => $Active,
-                UserID => $Self->{UserID},
+                ServiceID         => $ServiceID,
+                Active            => $Active,
+                UserID            => $Self->{UserID},
             );
         }
+
         # redirect to overview
-        return $Self->{LayoutObject}->Redirect(OP => "Action=$Self->{Action}&CustomerUserSearch=$Param{CustomerUserSearch}&ServiceSearch=$Param{ServiceSearch}");
+        return $Self->{LayoutObject}->Redirect(
+            OP =>
+                "Action=$Self->{Action}&CustomerUserSearch=$Param{CustomerUserSearch}&ServiceSearch=$Param{ServiceSearch}"
+        );
     }
+
     # ------------------------------------------------------------ #
     # allocate service save
     # ------------------------------------------------------------ #
-    elsif ($Self->{Subaction} eq 'AllocateServiceSave') {
+    elsif ( $Self->{Subaction} eq 'AllocateServiceSave' ) {
+
         # get params
-        $Param{ServiceID} = $Self->{ParamObject}->GetParam(Param => "ServiceID");
-        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam(Param => "CustomerUserSearch") || '*';
-        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam(Param => "ServiceSearch") || '*';
-        my @CustomerUserLoginsSelected = $Self->{ParamObject}->GetArray(Param => "CustomerUserLoginsSelected");
-        my @CustomerUserLoginsAll = $Self->{ParamObject}->GetArray(Param => "CustomerUserLoginsAll");
+        $Param{ServiceID}          = $Self->{ParamObject}->GetParam( Param => "ServiceID" );
+        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam( Param => "CustomerUserSearch" )
+            || '*';
+        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam( Param => "ServiceSearch" ) || '*';
+        my @CustomerUserLoginsSelected
+            = $Self->{ParamObject}->GetArray( Param => "CustomerUserLoginsSelected" );
+        my @CustomerUserLoginsAll
+            = $Self->{ParamObject}->GetArray( Param => "CustomerUserLoginsAll" );
 
         # create hash with selected customer users
         my %CustomerUserLoginsSelected;
-        foreach my $CustomerUserLogin (@CustomerUserLoginsSelected) {
+        for my $CustomerUserLogin (@CustomerUserLoginsSelected) {
             $CustomerUserLoginsSelected{$CustomerUserLogin} = 1;
         }
+
         # check all used customer users
-        foreach my $CustomerUserLogin (@CustomerUserLoginsAll) {
+        for my $CustomerUserLogin (@CustomerUserLoginsAll) {
             my $Active = 0;
-            if ($CustomerUserLoginsSelected{$CustomerUserLogin}) {
+            if ( $CustomerUserLoginsSelected{$CustomerUserLogin} ) {
                 $Active = 1;
             }
+
             # set customer user service member
             $Self->{ServiceObject}->CustomerUserServiceMemberAdd(
                 CustomerUserLogin => $CustomerUserLogin,
-                ServiceID => $Param{ServiceID},
-                Active => $Active,
-                UserID => $Self->{UserID},
+                ServiceID         => $Param{ServiceID},
+                Active            => $Active,
+                UserID            => $Self->{UserID},
             );
         }
+
         # redirect to overview
-        return $Self->{LayoutObject}->Redirect(OP => "Action=$Self->{Action}&CustomerUserSearch=$Param{CustomerUserSearch}&ServiceSearch=$Param{ServiceSearch}");
+        return $Self->{LayoutObject}->Redirect(
+            OP =>
+                "Action=$Self->{Action}&CustomerUserSearch=$Param{CustomerUserSearch}&ServiceSearch=$Param{ServiceSearch}"
+        );
     }
+
     # ------------------------------------------------------------ #
     # overview
     # ------------------------------------------------------------ #
     else {
+
         # get params
-        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam(Param => "CustomerUserSearch") || '*';
-        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam(Param => "ServiceSearch") || '*';
+        $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam( Param => "CustomerUserSearch" )
+            || '*';
+        $Param{ServiceSearch} = $Self->{ParamObject}->GetParam( Param => "ServiceSearch" ) || '*';
+
         # output header
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
+
         # output search block
         $Self->{LayoutObject}->Block(
             Name => 'Search',
             Data => {
                 %Param,
                 CustomerUserSearch => $Param{CustomerUserSearch},
-                ServiceSearch => $Param{ServiceSearch},
+                ServiceSearch      => $Param{ServiceSearch},
             },
         );
+
         # output default block
-        $Self->{LayoutObject}->Block(
-            Name => 'Default',
-        );
+        $Self->{LayoutObject}->Block( Name => 'Default', );
+
         # search customer user
-        my %CustomerUserList = $Self->{CustomerUserObject}->CustomerSearch(
-            Search => $Param{CustomerUserSearch},
-        );
-        my @CustomerUserKeyList = sort {$CustomerUserList{$a} cmp $CustomerUserList{$b}} keys %CustomerUserList;
+        my %CustomerUserList
+            = $Self->{CustomerUserObject}->CustomerSearch( Search => $Param{CustomerUserSearch}, );
+        my @CustomerUserKeyList
+            = sort { $CustomerUserList{$a} cmp $CustomerUserList{$b} } keys %CustomerUserList;
+
         # search services
         my @ServiceList = $Self->{ServiceObject}->ServiceSearch(
-            Name => $Param{ServiceSearch},
-            Limit => $SearchLimit + 1,
+            Name   => $Param{ServiceSearch},
+            Limit  => $SearchLimit + 1,
             UserID => $Self->{UserID},
         );
+
         # count results
         my $CustomerUserCount = @CustomerUserKeyList;
-        my $ServiceCount = @ServiceList;
+        my $ServiceCount      = @ServiceList;
+
         # set max count
         my $MaxCount = $CustomerUserCount;
-        if ($ServiceCount > $MaxCount) {
+        if ( $ServiceCount > $MaxCount ) {
             $MaxCount = $ServiceCount;
         }
-        if ($MaxCount > $SearchLimit) {
+        if ( $MaxCount > $SearchLimit ) {
             $MaxCount = $SearchLimit;
         }
+
         # output result block
         $Self->{LayoutObject}->Block(
             Name => 'Result',
             Data => {
                 %Param,
                 CustomerUserCount => $CustomerUserCount,
-                ServiceCount => $ServiceCount,
+                ServiceCount      => $ServiceCount,
             },
         );
+
         # output customer user count block
-        if (!@CustomerUserKeyList) {
+        if ( !@CustomerUserKeyList ) {
             $Self->{LayoutObject}->Block(
                 Name => 'ResultCustomerUserCountLimit',
-                Data => {
-                    CustomerUserCount => 0,
-                },
+                Data => { CustomerUserCount => 0, },
             );
         }
-        elsif (@CustomerUserKeyList > $SearchLimit) {
+        elsif ( @CustomerUserKeyList > $SearchLimit ) {
             $Self->{LayoutObject}->Block(
                 Name => 'ResultCustomerUserCountLimit',
-                Data => {
-                    CustomerUserCount => ">" . $SearchLimit,
-                },
+                Data => { CustomerUserCount => ">" . $SearchLimit, },
             );
         }
         else {
             $Self->{LayoutObject}->Block(
                 Name => 'ResultCustomerUserCount',
-                Data => {
-                    CustomerUserCount => scalar @CustomerUserKeyList,
-                },
+                Data => { CustomerUserCount => scalar @CustomerUserKeyList, },
             );
         }
+
         # output service count block
-        if (!@ServiceList) {
+        if ( !@ServiceList ) {
             $Self->{LayoutObject}->Block(
                 Name => 'ResultServiceCountLimit',
-                Data => {
-                    ServiceCount => 0,
-                },
+                Data => { ServiceCount => 0, },
             );
         }
-        elsif (@ServiceList > $SearchLimit) {
+        elsif ( @ServiceList > $SearchLimit ) {
             $Self->{LayoutObject}->Block(
                 Name => 'ResultServiceCountLimit',
-                Data => {
-                    ServiceCount => ">" . $SearchLimit,
-                },
+                Data => { ServiceCount => ">" . $SearchLimit, },
             );
         }
         else {
             $Self->{LayoutObject}->Block(
                 Name => 'ResultServiceCount',
-                Data => {
-                    ServiceCount => scalar @ServiceList,
-                },
+                Data => { ServiceCount => scalar @ServiceList, },
             );
         }
         my $CssClass;
+
         # output rows
-        foreach my $Counter (1..$MaxCount) {
+        for my $Counter ( 1 .. $MaxCount ) {
+
             # set output class
-            if ($CssClass && $CssClass eq 'searchactive') {
+            if ( $CssClass && $CssClass eq 'searchactive' ) {
                 $CssClass = 'searchpassive';
             }
             else {
                 $CssClass = 'searchactive';
             }
             my %RowParam;
+
             # set customer user row params
-            if (defined($CustomerUserKeyList[$Counter - 1])) {
-                $RowParam{CustomerUserLogin} = $CustomerUserKeyList[$Counter - 1];
-                $RowParam{CustomerUser} = $CustomerUserList{$CustomerUserKeyList[$Counter - 1]};
+            if ( defined( $CustomerUserKeyList[ $Counter - 1 ] ) ) {
+                $RowParam{CustomerUserLogin} = $CustomerUserKeyList[ $Counter - 1 ];
+                $RowParam{CustomerUser} = $CustomerUserList{ $CustomerUserKeyList[ $Counter - 1 ] };
                 $RowParam{CustomerUserCssClass} = $CssClass;
             }
+
             # set service row params
-            if ($ServiceList[$Counter - 1]) {
+            if ( $ServiceList[ $Counter - 1 ] ) {
                 my %Service = $Self->{ServiceObject}->ServiceGet(
-                    ServiceID => $ServiceList[$Counter - 1],
-                    UserID => $Self->{UserID},
+                    ServiceID => $ServiceList[ $Counter - 1 ],
+                    UserID    => $Self->{UserID},
                 );
-                $RowParam{ServiceID} = $Service{ServiceID};
-                $RowParam{Service} = $Service{Name};
+                $RowParam{ServiceID}       = $Service{ServiceID};
+                $RowParam{Service}         = $Service{Name};
                 $RowParam{ServiceCssClass} = $CssClass;
             }
+
             # output row block
             $Self->{LayoutObject}->Block(
                 Name => 'ResultRow',
-                Data => {
-                    %Param,
-                    %RowParam,
-                },
+                Data => { %Param, %RowParam, },
             );
         }
+
         # generate output
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminCustomerUserService',
-            Data => \%Param,
+            Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
 
@@ -500,4 +533,4 @@ sub Run {
     }
 }
 
-1;
\ No newline at end of file
+1;
