@@ -2,7 +2,7 @@
 # Kernel/Modules/AdminGenericAgent.pm - admin generic agent interface
 # Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminGenericAgent.pm,v 1.40.2.2 2008/03/25 13:27:05 ub Exp $
+# $Id: AdminGenericAgent.pm,v 1.51 2008/06/19 18:42:28 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -23,17 +23,14 @@ use Kernel::System::Type;
 use Kernel::System::GenericAgent;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.40.2.2 $) [1];
+$VERSION = qw($Revision: 1.51 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
 
     # allocate new hash for object
-    my $Self = {};
+    my $Self = {%Param};
     bless( $Self, $Type );
-    for ( keys %Param ) {
-        $Self->{$_} = $Param{$_};
-    }
 
     # check needed objects
     for (qw(ParamObject DBObject TicketObject LayoutObject LogObject ConfigObject)) {
@@ -56,8 +53,6 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $Output = '';
-
     # get confid data
     $Self->{Profile}    = $Self->{ParamObject}->GetParam( Param => 'Profile' )    || '';
     $Self->{OldProfile} = $Self->{ParamObject}->GetParam( Param => 'OldProfile' ) || '';
@@ -67,21 +62,18 @@ sub Run {
     # run a generic agent job -> "run now"
     # ---------------------------------------------------------- #
     if ( $Self->{Subaction} eq 'RunNow' ) {
-        if ($Self->{GenericAgentObject}->JobRun(
-                Job    => $Self->{Profile},
-                UserID => 1,
-            )
-            )
-        {
+        my $Run = $Self->{GenericAgentObject}->JobRun(
+            Job    => $Self->{Profile},
+            UserID => 1,
+        );
 
-            # redirect
+        # redirect
+        if ($Run) {
             return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}", );
         }
-        else {
 
-            # redirect
-            return $Self->{LayoutObject}->ErrorScreen();
-        }
+        # redirect
+        return $Self->{LayoutObject}->ErrorScreen();
     }
 
     # ---------------------------------------------------------- #
@@ -97,8 +89,9 @@ sub Run {
         );
 
         # redirect
-        return $Self->{LayoutObject}
-            ->Redirect( OP => "Action=$Self->{Action}&Subaction=Update&Profile=$Self->{Profile}", );
+        return $Self->{LayoutObject}->Redirect(
+            OP => "Action=$Self->{Action}&Subaction=Update&Profile=$Self->{Profile}",
+        );
     }
 
     # --------------------------------------------------------------- #
@@ -109,7 +102,7 @@ sub Run {
 
         # fill up profile name (e.g. with last-search)
         if ( !$Self->{Profile} ) {
-            $Output = $Self->{LayoutObject}->Header( Title => 'Error' );
+            my $Output = $Self->{LayoutObject}->Header( Title => 'Error' );
             $Output .= $Self->{LayoutObject}->Warning( Message => 'Need Job Name!' );
             $Output .= $Self->{LayoutObject}->Footer();
             return $Output;
@@ -118,23 +111,30 @@ sub Run {
         # get single params
         my %GetParam = ();
         for (
-            qw(TicketNumber From To Cc Subject Body CustomerID CustomerUserLogin Agent
+            qw(TicketNumber Title From To Cc Subject Body CustomerID CustomerUserLogin Agent
             TimeSearchType TicketCreateTimePointFormat TicketCreateTimePoint
             TicketCreateTimePointStart
             TicketCreateTimeStart TicketCreateTimeStartDay TicketCreateTimeStartMonth
             TicketCreateTimeStartYear
             TicketCreateTimeStop TicketCreateTimeStopDay TicketCreateTimeStopMonth
             TicketCreateTimeStopYear
+            CloseTimeSearchType TicketCloseTimePointFormat TicketCloseTimePoint
+            TicketCloseTimePointStart
+            TicketCloseTimeStart TicketCloseTimeStartDay TicketCloseTimeStartMonth
+            TicketCloseTimeStartYear
+            TicketCloseTimeStop TicketCloseTimeStopDay TicketCloseTimeStopMonth
+            TicketCloseTimeStopYear
             TimePendingSearchType TicketPendingTimePointFormat TicketPendingTimePoint
             TicketPendingTimePointStart
             TicketPendingTimeStart TicketPendingTimeStartDay TicketPendingTimeStartMonth
             TicketPendingTimeStartYear
             TicketPendingTimeStop TicketPendingTimeStopDay TicketPendingTimeStopMonth
             TicketPendingTimeStopYear
+            NewTitle
             NewCustomerID NewCustomerUserLogin
             NewStateID NewQueueID NewPriorityID NewOwnerID
             NewTypeID NewServiceID NewSLAID
-            NewNoteFrom NewNoteSubject NewNoteBody NewModule
+            NewNoteFrom NewNoteSubject NewNoteBody NewNoteTimeUnits NewModule
             NewParamKey1 NewParamKey2 NewParamKey3 NewParamKey4
             NewParamValue1 NewParamValue2 NewParamValue3 NewParamValue4
             NewParamKey5 NewParamKey6 NewParamKey7 NewParamKey8
@@ -158,8 +158,9 @@ sub Run {
 
             # ticket free keys
             if ( defined( $Self->{ParamObject}->GetParam( Param => "NewTicketFreeKey$ID" ) ) ) {
-                $GetParam{"NewTicketFreeKey$ID"}
-                    = $Self->{ParamObject}->GetParam( Param => "NewTicketFreeKey" . $ID );
+                $GetParam{"NewTicketFreeKey$ID"} = $Self->{ParamObject}->GetParam(
+                    Param => 'NewTicketFreeKey' . $ID,
+                );
 
                 # remove white space on the end
                 if ( $GetParam{"NewTicketFreeKey$ID"} ) {
@@ -169,13 +170,17 @@ sub Run {
             }
 
             # ticket free text
-            if ($Self->{ParamObject}->GetParam( Param => "NewTicketFreeText$ID" )
-                || ( defined( $Self->{ParamObject}->GetParam( Param => "NewTicketFreeText$ID" ) )
-                    && $Self->{ConfigObject}->Get("TicketFreeText$ID") )
+            if (
+                $Self->{ParamObject}->GetParam( Param => "NewTicketFreeText$ID" )
+                || (
+                    defined( $Self->{ParamObject}->GetParam( Param => "NewTicketFreeText$ID" ) )
+                    && $Self->{ConfigObject}->Get("TicketFreeText$ID")
+                )
                 )
             {
-                $GetParam{"NewTicketFreeText$ID"}
-                    = $Self->{ParamObject}->GetParam( Param => "NewTicketFreeText$ID" );
+                $GetParam{"NewTicketFreeText$ID"} = $Self->{ParamObject}->GetParam(
+                    Param => 'NewTicketFreeText' . $ID,
+                );
 
                 # remove white space on the end
                 if ( $GetParam{"NewTicketFreeText$ID"} ) {
@@ -205,20 +210,22 @@ sub Run {
 
             # get search array params for free key (get submitted params)
             if ( $Self->{ParamObject}->GetArray( Param => "TicketFreeKey$ID" ) ) {
-                @{ $GetParam{"TicketFreeKey$ID"} }
-                    = $Self->{ParamObject}->GetArray( Param => "TicketFreeKey$ID" );
+                @{ $GetParam{"TicketFreeKey$ID"} } = $Self->{ParamObject}->GetArray(
+                    Param => 'TicketFreeKey' . $ID,
+                );
             }
 
             # get search array params for free text (get submitted params)
 
             if ( $Self->{ConfigObject}->Get("TicketFreeText$ID") ) {
                 if ( $Self->{ParamObject}->GetArray( Param => "TicketFreeText$ID" ) ) {
-                    @{ $GetParam{"TicketFreeText$ID"} }
-                        = $Self->{ParamObject}->GetArray( Param => "TicketFreeText$ID" );
+                    @{ $GetParam{"TicketFreeText$ID"} } = $Self->{ParamObject}->GetArray(
+                        Param => 'TicketFreeText' . $ID,
+                    );
                 }
             }
             else {
-                my @Array = $Self->{ParamObject}->GetArray( Param => "TicketFreeText$ID" );
+                my @Array = $Self->{ParamObject}->GetArray( Param => 'TicketFreeText' . $ID );
                 if ( $Array[0] ) {
                     @{ $GetParam{"TicketFreeText$ID"} } = @Array;
                 }
@@ -238,7 +245,7 @@ sub Run {
             UserID => $Self->{UserID},
         );
 
-        # get time settings
+        # get create time settings
         if ( !$GetParam{TimeSearchType} || $GetParam{TimeSearchType} eq 'None' ) {
 
             # do noting on time stuff
@@ -255,9 +262,11 @@ sub Run {
                     $GetParam{"TicketCreateTimeStop$_"} = '0' . $GetParam{"TicketCreateTimeStop$_"};
                 }
             }
-            if (   $GetParam{TicketCreateTimeStartDay}
+            if (
+                $GetParam{TicketCreateTimeStartDay}
                 && $GetParam{TicketCreateTimeStartMonth}
-                && $GetParam{TicketCreateTimeStartYear} )
+                && $GetParam{TicketCreateTimeStartYear}
+                )
             {
                 $GetParam{TicketCreateTimeNewerDate}
                     = $GetParam{TicketCreateTimeStartYear} . '-'
@@ -265,9 +274,11 @@ sub Run {
                     . $GetParam{TicketCreateTimeStartDay}
                     . ' 00:00:01';
             }
-            if (   $GetParam{TicketCreateTimeStopDay}
+            if (
+                $GetParam{TicketCreateTimeStopDay}
                 && $GetParam{TicketCreateTimeStopMonth}
-                && $GetParam{TicketCreateTimeStopYear} )
+                && $GetParam{TicketCreateTimeStopYear}
+                )
             {
                 $GetParam{TicketCreateTimeOlderDate}
                     = $GetParam{TicketCreateTimeStopYear} . '-'
@@ -277,9 +288,11 @@ sub Run {
             }
         }
         elsif ( $GetParam{TimeSearchType} eq 'TimePoint' ) {
-            if (   $GetParam{TicketCreateTimePoint}
+            if (
+                $GetParam{TicketCreateTimePoint}
                 && $GetParam{TicketCreateTimePointStart}
-                && $GetParam{TicketCreateTimePointFormat} )
+                && $GetParam{TicketCreateTimePointFormat}
+                )
             {
                 my $Time = 0;
                 if ( $GetParam{TicketCreateTimePointFormat} eq 'minute' ) {
@@ -309,6 +322,83 @@ sub Run {
             }
         }
 
+        # get create time settings
+        if ( !$GetParam{CloseTimeSearchType} || $GetParam{CloseTimeSearchType} eq 'None' ) {
+
+            # do noting on time stuff
+        }
+        elsif ( $GetParam{CloseTimeSearchType} eq 'TimeSlot' ) {
+            for (qw(Month Day)) {
+                if ( $GetParam{"TicketCloseTimeStart$_"} <= 9 ) {
+                    $GetParam{"TicketCloseTimeStart$_"}
+                        = '0' . $GetParam{"TicketCloseTimeStart$_"};
+                }
+            }
+            for (qw(Month Day)) {
+                if ( $GetParam{"TicketCloseTimeStop$_"} <= 9 ) {
+                    $GetParam{"TicketCloseTimeStop$_"} = '0' . $GetParam{"TicketCloseTimeStop$_"};
+                }
+            }
+            if (
+                $GetParam{TicketCloseTimeStartDay}
+                && $GetParam{TicketCloseTimeStartMonth}
+                && $GetParam{TicketCloseTimeStartYear}
+                )
+            {
+                $GetParam{TicketCloseTimeNewerDate}
+                    = $GetParam{TicketCloseTimeStartYear} . '-'
+                    . $GetParam{TicketCloseTimeStartMonth} . '-'
+                    . $GetParam{TicketCloseTimeStartDay}
+                    . ' 00:00:01';
+            }
+            if (
+                $GetParam{TicketCloseTimeStopDay}
+                && $GetParam{TicketCloseTimeStopMonth}
+                && $GetParam{TicketCloseTimeStopYear}
+                )
+            {
+                $GetParam{TicketCloseTimeOlderDate}
+                    = $GetParam{TicketCloseTimeStopYear} . '-'
+                    . $GetParam{TicketCloseTimeStopMonth} . '-'
+                    . $GetParam{TicketCloseTimeStopDay}
+                    . ' 23:59:59';
+            }
+        }
+        elsif ( $GetParam{CloseTimeSearchType} eq 'TimePoint' ) {
+            if (
+                $GetParam{TicketCloseTimePoint}
+                && $GetParam{TicketCloseTimePointStart}
+                && $GetParam{TicketCloseTimePointFormat}
+                )
+            {
+                my $Time = 0;
+                if ( $GetParam{TicketCloseTimePointFormat} eq 'minute' ) {
+                    $Time = $GetParam{TicketCloseTimePoint};
+                }
+                elsif ( $GetParam{TicketCloseTimePointFormat} eq 'hour' ) {
+                    $Time = $GetParam{TicketCloseTimePoint} * 60;
+                }
+                elsif ( $GetParam{TicketCloseTimePointFormat} eq 'day' ) {
+                    $Time = $GetParam{TicketCloseTimePoint} * 60 * 24;
+                }
+                elsif ( $GetParam{TicketCloseTimePointFormat} eq 'week' ) {
+                    $Time = $GetParam{TicketCloseTimePoint} * 60 * 24 * 7;
+                }
+                elsif ( $GetParam{TicketCloseTimePointFormat} eq 'month' ) {
+                    $Time = $GetParam{TicketCloseTimePoint} * 60 * 24 * 30;
+                }
+                elsif ( $GetParam{TicketCloseTimePointFormat} eq 'year' ) {
+                    $Time = $GetParam{TicketCloseTimePoint} * 60 * 24 * 365;
+                }
+                if ( $GetParam{TicketCloseTimePointStart} eq 'Before' ) {
+                    $GetParam{TicketCloseTimeOlderMinutes} = $Time;
+                }
+                else {
+                    $GetParam{TicketCloseTimeNewerMinutes} = $Time;
+                }
+            }
+        }
+
         # get time settings
         if ( !$GetParam{TimePendingSearchType} || $GetParam{TimePendingSearchType} eq 'None' ) {
 
@@ -327,9 +417,11 @@ sub Run {
                         = '0' . $GetParam{"TicketPendingTimeStop$_"};
                 }
             }
-            if (   $GetParam{TicketPendingTimeStartDay}
+            if (
+                $GetParam{TicketPendingTimeStartDay}
                 && $GetParam{TicketPendingTimeStartMonth}
-                && $GetParam{TicketPendingTimeStartYear} )
+                && $GetParam{TicketPendingTimeStartYear}
+                )
             {
                 $GetParam{TicketPendingTimeNewerDate}
                     = $GetParam{TicketPendingTimeStartYear} . '-'
@@ -337,9 +429,11 @@ sub Run {
                     . $GetParam{TicketPendingTimeStartDay}
                     . ' 00:00:01';
             }
-            if (   $GetParam{TicketPendingTimeStopDay}
+            if (
+                $GetParam{TicketPendingTimeStopDay}
                 && $GetParam{TicketPendingTimeStopMonth}
-                && $GetParam{TicketPendingTimeStopYear} )
+                && $GetParam{TicketPendingTimeStopYear}
+                )
             {
                 $GetParam{TicketPendingTimeOlderDate}
                     = $GetParam{TicketPendingTimeStopYear} . '-'
@@ -349,9 +443,11 @@ sub Run {
             }
         }
         elsif ( $GetParam{TimePendingSearchType} eq 'TimePoint' ) {
-            if (   $GetParam{TicketPendingTimePoint}
+            if (
+                $GetParam{TicketPendingTimePoint}
                 && $GetParam{TicketPendingTimePointStart}
-                && $GetParam{TicketPendingTimePointFormat} )
+                && $GetParam{TicketPendingTimePointFormat}
+                )
             {
                 my $Time = 0;
                 if ( $GetParam{TicketPendingTimePointFormat} eq 'minute' ) {
@@ -436,14 +532,12 @@ sub Run {
                 );
 
                 # just show 25 tickts
-                if ( $_ > 25 ) {
-                    last;
-                }
+                last if $_ > 25;
             }
         }
 
         # html search mask output
-        $Output = $Self->{LayoutObject}->Header( Title => "Affected Tickets" );
+        my $Output = $Self->{LayoutObject}->Header( Title => 'Affected Tickets' );
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminGenericAgent',
@@ -468,14 +562,14 @@ sub Run {
             Type  => 'Long',
             Valid => 1,
         );
-        $Param{'OwnerStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{OwnerStrg} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data               => \%ShownUsers,
             Name               => 'OwnerIDs',
             Multiple           => 1,
             Size               => 5,
             SelectedIDRefArray => $Param{OwnerIDs},
         );
-        $Param{'NewOwnerStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{NewOwnerStrg} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data       => \%ShownUsers,
             Name       => 'NewOwnerID',
             Size       => 5,
@@ -486,14 +580,14 @@ sub Run {
         for ( 0 .. 23 ) {
             $Hours{$_} = sprintf( "%02d", $_ );
         }
-        $Param{'ScheduleHours'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{ScheduleHours} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data               => \%Hours,
             Name               => 'ScheduleHours',
             Size               => 6,
             Multiple           => 1,
             SelectedIDRefArray => $Param{ScheduleHours},
         );
-        $Param{'ScheduleMinutes'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{ScheduleMinutes} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 '00' => '00',
                 10   => '10',
@@ -507,7 +601,7 @@ sub Run {
             Multiple           => 1,
             SelectedIDRefArray => $Param{ScheduleMinutes},
         );
-        $Param{'ScheduleDays'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{ScheduleDays} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 1 => 'Mon',
                 2 => 'Tue',
@@ -524,7 +618,7 @@ sub Run {
             SelectedIDRefArray => $Param{ScheduleDays},
         );
 
-        $Param{'StatesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{StatesStrg} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 $Self->{StateObject}->StateList(
                     UserID => 1,
@@ -536,7 +630,7 @@ sub Run {
             Size               => 5,
             SelectedIDRefArray => $Param{StateIDs},
         );
-        $Param{'NewStatesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{NewStatesStrg} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 $Self->{StateObject}->StateList(
                     UserID => 1,
@@ -548,7 +642,7 @@ sub Run {
             Multiple   => 1,
             SelectedID => $Param{NewStateID},
         );
-        $Param{'QueuesStrg'} = $Self->{LayoutObject}->AgentQueueListOption(
+        $Param{QueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
             Data               => { $Self->{QueueObject}->GetAllQueues(), },
             Size               => 5,
             Multiple           => 1,
@@ -556,7 +650,7 @@ sub Run {
             SelectedIDRefArray => $Param{QueueIDs},
             OnChangeSubmit     => 0,
         );
-        $Param{'NewQueuesStrg'} = $Self->{LayoutObject}->AgentQueueListOption(
+        $Param{NewQueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
             Data           => { $Self->{QueueObject}->GetAllQueues(), },
             Size           => 5,
             Multiple       => 1,
@@ -564,7 +658,7 @@ sub Run {
             SelectedID     => $Param{NewQueueID},
             OnChangeSubmit => 0,
         );
-        $Param{'PrioritiesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{PrioritiesStrg} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 $Self->{PriorityObject}->PriorityList(
                     UserID => 1,
@@ -576,7 +670,7 @@ sub Run {
             Size               => 5,
             SelectedIDRefArray => $Param{PriorityIDs},
         );
-        $Param{'NewPrioritiesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{NewPrioritiesStrg} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 $Self->{PriorityObject}->PriorityList(
                     UserID => 1,
@@ -600,6 +694,17 @@ sub Run {
             $Param{'TimeSearchType::TimeSlot'} = 'checked';
         }
 
+        # get close time option
+        if ( !$Param{CloseTimeSearchType} ) {
+            $Param{'CloseTimeSearchType::None'} = 'checked';
+        }
+        elsif ( $Param{CloseTimeSearchType} eq 'TimePoint' ) {
+            $Param{'CloseTimeSearchType::TimePoint'} = 'checked';
+        }
+        elsif ( $Param{CloseTimeSearchType} eq 'TimeSlot' ) {
+            $Param{'CloseTimeSearchType::TimeSlot'} = 'checked';
+        }
+
         # get pending time option
         if ( !$Param{TimePendingSearchType} ) {
             $Param{'TimePendingSearchType::None'} = 'checked';
@@ -617,20 +722,20 @@ sub Run {
         }
 
         # create time
-        $Param{'TicketCreateTimePoint'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{TicketCreateTimePoint} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data       => \%Counter,
             Name       => 'TicketCreateTimePoint',
             SelectedID => $Param{TicketCreateTimePoint},
         );
-        $Param{'TicketCreateTimePointStart'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{TicketCreateTimePointStart} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 'Last'   => 'last',
                 'Before' => 'before',
             },
-            Name       => 'TicketCreateTimePointStart',
+            Name => 'TicketCreateTimePointStart',
             SelectedID => $Param{TicketCreateTimePointStart} || 'Last',
         );
-        $Param{'TicketCreateTimePointFormat'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{TicketCreateTimePointFormat} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 minute => 'minute(s)',
                 hour   => 'hour(s)',
@@ -654,21 +759,59 @@ sub Run {
             Format => 'DateInputFormat',
         );
 
-        # pending time
-        $Param{'TicketPendingTimePoint'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        # close time
+        $Param{TicketCloseTimePoint} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data       => \%Counter,
-            Name       => 'TicketPendingTimePoint',
-            SelectedID => $Param{TicketPendingTimePoint},
+            Name       => 'TicketCloseTimePoint',
+            SelectedID => $Param{TicketCloseTimePoint},
         );
-        $Param{'TicketPendingTimePointStart'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{TicketCloseTimePointStart} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 'Last'   => 'last',
                 'Before' => 'before',
             },
-            Name       => 'TicketPendingTimePointStart',
+            Name => 'TicketCloseTimePointStart',
+            SelectedID => $Param{TicketCloseTimePointStart} || 'Last',
+        );
+        $Param{TicketCloseTimePointFormat} = $Self->{LayoutObject}->OptionStrgHashRef(
+            Data => {
+                minute => 'minute(s)',
+                hour   => 'hour(s)',
+                day    => 'day(s)',
+                week   => 'week(s)',
+                month  => 'month(s)',
+                year   => 'year(s)',
+            },
+            Name       => 'TicketCloseTimePointFormat',
+            SelectedID => $Param{TicketCloseTimePointFormat},
+        );
+        $Param{TicketCloseTimeStart} = $Self->{LayoutObject}->BuildDateSelection(
+            %Param,
+            Prefix   => 'TicketCloseTimeStart',
+            Format   => 'DateInputFormat',
+            DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+        );
+        $Param{TicketCloseTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
+            %Param,
+            Prefix => 'TicketCloseTimeStop',
+            Format => 'DateInputFormat',
+        );
+
+        # pending time
+        $Param{TicketPendingTimePoint} = $Self->{LayoutObject}->OptionStrgHashRef(
+            Data       => \%Counter,
+            Name       => 'TicketPendingTimePoint',
+            SelectedID => $Param{TicketPendingTimePoint},
+        );
+        $Param{TicketPendingTimePointStart} = $Self->{LayoutObject}->OptionStrgHashRef(
+            Data => {
+                'Last'   => 'last',
+                'Before' => 'before',
+            },
+            Name => 'TicketPendingTimePointStart',
             SelectedID => $Param{TicketPendingTimePointStart} || 'Last',
         );
-        $Param{'TicketPendingTimePointFormat'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{TicketPendingTimePointFormat} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 minute => 'minute(s)',
                 hour   => 'hour(s)',
@@ -691,17 +834,17 @@ sub Run {
             Prefix => 'TicketPendingTimeStop',
             Format => 'DateInputFormat',
         );
-        $Param{'DeleteOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{DeleteOption} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data       => $Self->{ConfigObject}->Get('YesNoOptions'),
             Name       => 'NewDelete',
             SelectedID => $Param{NewDelete},
         );
-        $Param{'ValidOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{ValidOption} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data       => $Self->{ConfigObject}->Get('YesNoOptions'),
             Name       => 'Valid',
             SelectedID => defined( $Param{Valid} ) ? $Param{Valid} : 1,
         );
-        $Param{'LockOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{LockOption} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 $Self->{LockObject}->LockList(
                     UserID => 1,
@@ -713,7 +856,7 @@ sub Run {
             Size               => 3,
             SelectedIDRefArray => $Param{LockIDs},
         );
-        $Param{'NewLockOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{NewLockOption} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data => {
                 $Self->{LockObject}->LockList(
                     UserID => 1,
@@ -726,7 +869,7 @@ sub Run {
             SelectedID => $Param{NewLockID},
         );
 
-        $Param{'SendNoNotificationOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        $Param{SendNoNotificationOption} = $Self->{LayoutObject}->OptionStrgHashRef(
             Data       => $Self->{ConfigObject}->Get('YesNoOptions'),
             Name       => 'NewSendNoNotification',
             SelectedID => $Param{NewSendNoNotification} || 0,
@@ -737,6 +880,18 @@ sub Run {
             Data => \%Param,
         );
 
+        # add ticket title
+        if ( $Self->{ConfigObject}->Get('Ticket::Frontend::Title') ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketTitle',
+                Data => {%Param},
+            );
+            $Self->{LayoutObject}->Block(
+                Name => 'NewTicketTitle',
+                Data => {%Param},
+            );
+        }
+
         # build type string
         if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
             my %Type = $Self->{TypeObject}->TypeList( UserID => $Self->{UserID}, );
@@ -753,7 +908,7 @@ sub Run {
                 Name => 'TicketType',
                 Data => {%Param},
             );
-            $Param{'NewTypesStrg'} = $Self->{LayoutObject}->BuildSelection(
+            $Param{NewTypesStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%Type,
                 Name        => 'NewTypeID',
                 SelectedID  => $Param{NewTypeID},
@@ -777,7 +932,7 @@ sub Run {
                 $TreeView = 1;
             }
             my %Service = $Self->{ServiceObject}->ServiceList( UserID => $Self->{UserID}, );
-            $Param{'ServicesStrg'} = $Self->{LayoutObject}->BuildSelection(
+            $Param{ServicesStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%Service,
                 Name        => 'ServiceIDs',
                 SelectedID  => $Param{ServiceIDs},
@@ -788,7 +943,7 @@ sub Run {
                 Translation => 0,
                 Max         => 200,
             );
-            $Param{'NewServicesStrg'} = $Self->{LayoutObject}->BuildSelection(
+            $Param{NewServicesStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%Service,
                 Name        => 'NewServiceID',
                 SelectedID  => $Param{NewServiceID},
@@ -800,7 +955,7 @@ sub Run {
                 Max         => 200,
             );
             my %SLA = $Self->{SLAObject}->SLAList( UserID => $Self->{UserID}, );
-            $Param{'SLAsStrg'} = $Self->{LayoutObject}->BuildSelection(
+            $Param{SLAsStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data        => \%SLA,
                 Name        => 'SLAIDs',
                 SelectedID  => $Param{SLAIDs},
@@ -810,10 +965,10 @@ sub Run {
                 Translation => 0,
                 Max         => 200,
             );
-            $Param{'NewSLAsStrg'} = $Self->{LayoutObject}->BuildSelection(
-                Data       => \%SLA,
-                Name       => 'NewSLAID',
-                SelectedID => $Param{NewSLAID},
+            $Param{NewSLAsStrg} = $Self->{LayoutObject}->BuildSelection(
+                Data        => \%SLA,
+                Name        => 'NewSLAID',
+                SelectedID  => $Param{NewSLAID},
                 Sort        => 'AlphanumericValue',
                 Size        => 5,
                 Multiple    => 1,
@@ -953,7 +1108,7 @@ sub Run {
         }
 
         # generate search mask
-        my $Output = $Self->{LayoutObject}->Header( Title => "Edit" );
+        my $Output = $Self->{LayoutObject}->Header( Title => 'Edit' );
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminGenericAgent',
@@ -986,12 +1141,12 @@ sub Run {
 
         # css setting and text for valid or invalid jobs
         if ( $JobData{Valid} ) {
-            $JobData{ShownValid} = "valid";
-            $JobData{cssValid}   = "";
+            $JobData{ShownValid} = 'valid';
+            $JobData{cssValid}   = '';
         }
         else {
-            $JobData{ShownValid} = "invalid";
-            $JobData{cssValid}   = "contentvaluepassiv";
+            $JobData{ShownValid} = 'invalid';
+            $JobData{cssValid}   = 'contentvaluepassiv';
         }
 
         # seperate each searchresult line by using several css
@@ -1010,7 +1165,7 @@ sub Run {
     }
 
     # generate search mask
-    $Output = $Self->{LayoutObject}->Header( Title => "Overview" );
+    my $Output = $Self->{LayoutObject}->Header( Title => 'Overview' );
     $Output .= $Self->{LayoutObject}->NavigationBar();
     $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AdminGenericAgent',
