@@ -1,92 +1,86 @@
 # --
 # Kernel/Modules/AdminSalutation.pm - to add/update/delete system addresses
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminSalutation.pm,v 1.24 2007/03/21 11:12:05 martin Exp $
+# $Id: AdminSalutation.pm,v 1.28 2008/05/08 09:36:36 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Modules::AdminSalutation;
 
 use strict;
+use warnings;
+
 use Kernel::System::Salutation;
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.24 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.28 $) [1];
 
 sub new {
-    my $Type = shift;
-    my %Param = @_;
+    my ( $Type, %Param ) = @_;
 
     # allocate new hash for object
-    my $Self = {};
-    bless ($Self, $Type);
-
-    # allocate new hash for objects
-    foreach (keys %Param) {
-        $Self->{$_} = $Param{$_};
-    }
+    my $Self = {%Param};
+    bless( $Self, $Type );
 
     # check all needed objects
-    foreach (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
-        if (!$Self->{$_}) {
-            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+    for (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
+        if ( !$Self->{$_} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
         }
     }
     $Self->{SalutationObject} = Kernel::System::Salutation->new(%Param);
-    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
+    $Self->{ValidObject}      = Kernel::System::Valid->new(%Param);
 
     return $Self;
 }
 
 sub Run {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
 
     # ------------------------------------------------------------ #
     # change
     # ------------------------------------------------------------ #
-    if ($Self->{Subaction} eq 'Change') {
-        my $ID = $Self->{ParamObject}->GetParam(Param => 'ID') || '';
-        my %Data = $Self->{SalutationObject}->SalutationGet(
-            ID => $ID,
-        );
+    if ( $Self->{Subaction} eq 'Change' ) {
+        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
+        my %Data = $Self->{SalutationObject}->SalutationGet( ID => $ID, );
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
-            Action => "Change",
+            Action => 'Change',
             %Data,
         );
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminSalutationForm',
-            Data => \%Param,
+            Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
+
     # ------------------------------------------------------------ #
     # change action
     # ------------------------------------------------------------ #
-    elsif ($Self->{Subaction} eq 'ChangeAction') {
+    elsif ( $Self->{Subaction} eq 'ChangeAction' ) {
         my $Note = '';
         my %GetParam;
-        foreach (qw(ID Name Text Comment ValidID)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam(Param => $_) || '';
+        for (qw(ID Name Text Comment ValidID)) {
+            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ ) || '';
         }
+
         # update group
-        if ($Self->{SalutationObject}->SalutationUpdate(%GetParam, UserID => $Self->{UserID})) {
+        if ( $Self->{SalutationObject}->SalutationUpdate( %GetParam, UserID => $Self->{UserID} ) ) {
             $Self->_Overview();
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify(Info => 'System Address updated!');
+            $Output .= $Self->{LayoutObject}->Notify( Info => 'System Address updated!' );
             $Output .= $Self->{LayoutObject}->Output(
                 TemplateFile => 'AdminSalutationForm',
-                Data => \%Param,
+                Data         => \%Param,
             );
             $Output .= $Self->{LayoutObject}->Footer();
             return $Output;
@@ -94,26 +88,27 @@ sub Run {
         else {
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify(Priority => 'Error');
+            $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
             $Self->_Edit(
                 Action => "Change",
                 %GetParam,
             );
             $Output .= $Self->{LayoutObject}->Output(
                 TemplateFile => 'AdminSalutationForm',
-                Data => \%Param,
+                Data         => \%Param,
             );
             $Output .= $Self->{LayoutObject}->Footer();
             return $Output;
         }
     }
+
     # ------------------------------------------------------------ #
     # add
     # ------------------------------------------------------------ #
-    elsif ($Self->{Subaction} eq 'Add') {
+    elsif ( $Self->{Subaction} eq 'Add' ) {
         my %GetParam = ();
-        foreach (qw(Name)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam(Param => $_);
+        for (qw(Name)) {
+            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
         }
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
@@ -123,29 +118,35 @@ sub Run {
         );
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminSalutationForm',
-            Data => \%Param,
+            Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
+
     # ------------------------------------------------------------ #
     # add action
     # ------------------------------------------------------------ #
-    elsif ($Self->{Subaction} eq 'AddAction') {
+    elsif ( $Self->{Subaction} eq 'AddAction' ) {
         my $Note = '';
         my %GetParam;
-        foreach (qw(ID Name Text Comment ValidID)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam(Param => $_) || '';
+        for (qw(ID Name Text Comment ValidID)) {
+            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ ) || '';
         }
+
         # add user
-        if (my $AddressID = $Self->{SalutationObject}->SalutationAdd(%GetParam, UserID => $Self->{UserID})) {
+        if (
+            my $AddressID
+            = $Self->{SalutationObject}->SalutationAdd( %GetParam, UserID => $Self->{UserID} )
+            )
+        {
             $Self->_Overview();
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify(Info => 'System Address added!');
+            $Output .= $Self->{LayoutObject}->Notify( Info => 'System Address added!' );
             $Output .= $Self->{LayoutObject}->Output(
                 TemplateFile => 'AdminSalutationForm',
-                Data => \%Param,
+                Data         => \%Param,
             );
             $Output .= $Self->{LayoutObject}->Footer();
             return $Output;
@@ -153,19 +154,20 @@ sub Run {
         else {
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify(Priority => 'Error');
+            $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
             $Self->_Edit(
                 Action => "Add",
                 %GetParam,
             );
             $Output .= $Self->{LayoutObject}->Output(
                 TemplateFile => 'AdminSalutationForm',
-                Data => \%Param,
+                Data         => \%Param,
             );
             $Output .= $Self->{LayoutObject}->Footer();
             return $Output;
         }
     }
+
     # ------------------------------------------------------------
     # overview
     # ------------------------------------------------------------
@@ -175,7 +177,7 @@ sub Run {
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminSalutationForm',
-            Data => \%Param,
+            Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
@@ -184,30 +186,27 @@ sub Run {
 }
 
 sub _Edit {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
 
     $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
     );
     $Param{'ValidOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
-        Data => {
-            $Self->{ValidObject}->ValidList(),
-        },
-        Name => 'ValidID',
+        Data       => { $Self->{ValidObject}->ValidList(), },
+        Name       => 'ValidID',
         SelectedID => $Param{ValidID},
     );
     $Param{'QueueOption'} = $Self->{LayoutObject}->AgentQueueListOption(
         Data => {
             $Self->{DBObject}->GetTableData(
-                What => 'id, name',
+                What  => 'id, name',
                 Table => 'queue',
                 Valid => 1,
-            )
+                )
         },
-        Name => 'QueueID',
-        SelectedID => $Param{QueueID},
+        Name           => 'QueueID',
+        SelectedID     => $Param{QueueID},
         OnChangeSubmit => 0,
     );
 
@@ -219,8 +218,8 @@ sub _Edit {
 }
 
 sub _Overview {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     my $Output = '';
 
     $Self->{LayoutObject}->Block(
@@ -231,27 +230,25 @@ sub _Overview {
         Name => 'OverviewResult',
         Data => \%Param,
     );
-    my %List = $Self->{SalutationObject}->SalutationList(
-        Valid => 0,
-    );
+    my %List = $Self->{SalutationObject}->SalutationList( Valid => 0, );
+
     # get valid list
     my %ValidList = $Self->{ValidObject}->ValidList();
-    my $CssClass = '';
-    foreach (sort {$List{$a} cmp $List{$b}}  keys %List) {
+    my $CssClass  = '';
+    for ( sort { $List{$a} cmp $List{$b} } keys %List ) {
+
         # set output class
-        if ($CssClass && $CssClass eq 'searchactive') {
+        if ( $CssClass && $CssClass eq 'searchactive' ) {
             $CssClass = 'searchpassive';
         }
         else {
             $CssClass = 'searchactive';
         }
-        my %Data = $Self->{SalutationObject}->SalutationGet(
-            ID => $_,
-        );
+        my %Data = $Self->{SalutationObject}->SalutationGet( ID => $_, );
         $Self->{LayoutObject}->Block(
             Name => 'OverviewResultRow',
             Data => {
-                Valid => $ValidList{$Data{ValidID}},
+                Valid    => $ValidList{ $Data{ValidID} },
                 CssClass => $CssClass,
                 %Data,
             },
