@@ -1,23 +1,24 @@
 # --
 # Kernel/System/Crypt.pm - the main crypt module
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: Crypt.pm,v 1.9 2007/08/21 19:55:45 martin Exp $
+# $Id: Crypt.pm,v 1.13 2008/05/08 09:36:19 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::System::Crypt;
 
 use strict;
+use warnings;
+
 use Kernel::System::FileTemp;
 use Kernel::System::Encode;
 
 use vars qw($VERSION @ISA);
-$VERSION = '$Revision: 1.9 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
+$VERSION = qw($Revision: 1.13 $) [1];
 
 =head1 NAME
 
@@ -51,50 +52,49 @@ create new object
     );
     my $MainObject = Kernel::System::DB->new(
         ConfigObject => $ConfigObject,
-        LogObject => $LogObject,
+        LogObject    => $LogObject,
     );
     my $DBObject = Kernel::System::DB->new(
-        MainObject => $MainObject,
+        MainObject   => $MainObject,
         ConfigObject => $ConfigObject,
-        LogObject => $LogObject,
+        LogObject    => $LogObject,
     );
     my $CryptObject = Kernel::System::Crypt->new(
-        DBObject => $DBObject,
-        MainObject => $MainObject,
+        DBObject     => $DBObject,
+        MainObject   => $MainObject,
         ConfigObject => $ConfigObject,
-        LogObject => $LogObject,
-        CryptType => 'PGP',   # PGP or SMIME
+        LogObject    => $LogObject,
+        CryptType    => 'PGP',   # PGP or SMIME
     );
 
 =cut
 
 sub new {
-    my $Type = shift;
-    my %Param = @_;
+    my ( $Type, %Param ) = @_;
 
     # allocate new hash for object
     my $Self = {};
-    bless ($Self, $Type);
+    bless( $Self, $Type );
 
     $Self->{Debug} = $Param{Debug} || 0;
 
     # get needed opbjects
-    foreach (qw(ConfigObject LogObject DBObject CryptType MainObject)) {
+    for (qw(ConfigObject LogObject DBObject CryptType MainObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
 
     # check if module is enabled
-    if (!$Self->{ConfigObject}->Get($Param{CryptType})) {
+    if ( !$Self->{ConfigObject}->Get( $Param{CryptType} ) ) {
         return;
     }
 
     # create file template object
     $Self->{FileTempObject} = Kernel::System::FileTemp->new(%Param);
-    $Self->{EncodeObject} = Kernel::System::Encode->new(%Param);
+    $Self->{EncodeObject}   = Kernel::System::Encode->new(%Param);
 
     # load generator crypt module
     $Self->{GenericModule} = "Kernel::System::Crypt::$Param{CryptType}";
-    if (!$Self->{MainObject}->Require($Self->{GenericModule})) {
+    if ( !$Self->{MainObject}->Require( $Self->{GenericModule} ) ) {
         return;
     }
 
@@ -105,7 +105,7 @@ sub new {
     $Self->_Init();
 
     # check working env
-    if ($Self->Check()) {
+    if ( $Self->Check() ) {
         return;
     }
 
@@ -122,12 +122,12 @@ This software is part of the OTRS project (http://otrs.org/).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.9 $ $Date: 2007/08/21 19:55:45 $
+$Revision: 1.13 $ $Date: 2008/05/08 09:36:19 $
 
 =cut
