@@ -2,7 +2,7 @@
 # Kernel/System/EmailParser.pm - the global email parser module
 # Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: EmailParser.pm,v 1.50.2.7 2008/05/22 17:55:46 martin Exp $
+# $Id: EmailParser.pm,v 1.71 2008/08/02 13:14:12 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,6 +12,7 @@
 package Kernel::System::EmailParser;
 
 use strict;
+use warnings;
 use Mail::Internet;
 use MIME::Parser;
 use MIME::QuotedPrint;
@@ -21,8 +22,7 @@ use Mail::Address;
 use Kernel::System::Encode;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.50.2.7 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.71 $) [1];
 
 =head1 NAME
 
@@ -40,65 +40,71 @@ A module to parse and encode a email.
 
 =item new()
 
-create a object
+create an object
 
     use Kernel::Config;
     use Kernel::System::Log;
     use Kernel::System::EmailParser;
 
     my $ConfigObject = Kernel::Config->new();
-    my $LogObject = Kernel::System::Log->new(
+    my $LogObject    = Kernel::System::Log->new(
         ConfigObject => $ConfigObject,
     );
-    my $ParseObject = Kernel::System::EmailParser->new(
+    my $ParserObject = Kernel::System::EmailParser->new(
         ConfigObject => $ConfigObject,
-        LogObject => $LogObject,
-        Email => \@ArrayOfEmail,
-        Debug => 0,
+        LogObject    => $LogObject,
+        Email        => \@ArrayOfEmail,
+        Debug        => 0,
     );
 
 =cut
 
 sub new {
-    my $Type = shift;
-    my %Param = @_;
+    my ( $Type, %Param ) = @_;
 
     # allocate new hash for object
     my $Self = {};
-    bless ($Self, $Type);
+    bless( $Self, $Type );
 
     # get debug level from parent
     $Self->{Debug} = $Param{Debug} || 0;
 
     # check needed objects
-    foreach (qw(LogObject ConfigObject)) {
+    for (qw(LogObject ConfigObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
+
     # check needed objects
-    if (!$Param{Email} && !$Param{Entity}) {
+    if ( !$Param{Email} && !$Param{Entity} ) {
         die "Need Email or Entity!";
     }
+
     # encode object
     $Self->{EncodeObject} = Kernel::System::Encode->new(%Param);
 
-    if ($Param{Email}) {
+    if ( $Param{Email} ) {
+
         # create Mail::Internet object
-        $Self->{Email} = new Mail::Internet($Param{Email});
+        $Self->{Email} = new Mail::Internet( $Param{Email} );
+
         # create a Mail::Header object with email
         $Self->{HeaderObject} = $Self->{Email}->head();
+
         # create MIME::Parser object and get message body or body of first attachemnt
         my $Parser = new MIME::Parser;
-        $Parser->output_to_core("ALL");
-        $Self->{ParserParts} = $Parser->parse_data($Self->{Email}->as_string());
+        $Parser->output_to_core('ALL');
+        $Self->{ParserParts} = $Parser->parse_data( $Self->{Email}->as_string() );
     }
     else {
         $Self->{ParserParts} = $Param{Entity};
-        $Self->{EntityMode} = 1;
+        $Self->{EntityMode}  = 1;
     }
+
     # get NoHTMLChecks param
-    if ($Param{NoHTMLChecks}) {
+    if ( $Param{NoHTMLChecks} ) {
         $Self->{NoHTMLChecks} = $Param{NoHTMLChecks};
     }
+
     # parse email at first
     $Self->GetMessageBody();
 
@@ -109,12 +115,13 @@ sub new {
 
 To get a email as a string back (plain email).
 
-    my $Email = $ParseObject->GetPlainEmail();
+    my $Email = $ParserObject->GetPlainEmail();
 
 =cut
 
 sub GetPlainEmail {
     my $Self = shift;
+
     return $Self->{Email}->as_string();
 }
 
@@ -123,56 +130,59 @@ sub GetPlainEmail {
 To get a header (e. g. Subject, To, ContentType, ...) of an email
 (mime is already done!).
 
-    my $To = $ParseObject->GetParam(WHAT => 'To');
+    my $To = $ParserObject->GetParam( WHAT => 'To' );
 
 =cut
 
 sub GetParam {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     my $What = $Param{WHAT} || return;
 
     $Self->{HeaderObject}->unfold();
     $Self->{HeaderObject}->combine($What);
     my $Line = $Self->{HeaderObject}->get($What) || '';
-    chomp ($Line);
+    chomp($Line);
     my $ReturnLine = '';
-    my %Remember = ();
-    foreach my $Array (decode_mimewords($Line)) {
-        foreach (@{$Array}) {
+    my %Remember   = ();
+    for my $Array ( decode_mimewords($Line) ) {
+        for ( @{$Array} ) {
+
             # I don't know, but decode_mimewords() returns each mime
             # word two times! Remember to the old one. :-(
-            if (!$Remember{$Array->[0]}) {
-                if ($Array->[0] && $Array->[1]) {
-                    $Remember{$Array->[0]} = 1;
+            if ( !$Remember{ $Array->[0] } ) {
+                if ( $Array->[0] && $Array->[1] ) {
+                    $Remember{ $Array->[0] } = 1;
                 }
+
                 # Workaround for OE problem:
                 # If a header contains =?iso-8859-1?Q?Fr=F6hlich=2C_Roman?=
                 # which is decoded ->Fröhlich, Roman<- which gets an problem
                 # because this means two email addresses. We add " at
                 # the start and at the end of this types of words mime.
-                if ($What =~ /^(From|To|Cc)/ && $Array->[1]) {
-                    if ($Array->[0] !~ /^("|')/ && $Array->[0] =~ /,/) {
-                        $Array->[0] = '"'.$Array->[0].'"';
-                        $Remember{$Array->[0]} = 1;
+                if ( $What =~ /^(From|To|Cc)/ && $Array->[1] ) {
+                    if ( $Array->[0] !~ /^("|')/ && $Array->[0] =~ /,/ ) {
+                        $Array->[0] = '"' . $Array->[0] . '"';
+                        $Remember{ $Array->[0] } = 1;
                     }
                 }
                 $ReturnLine .= $Self->{EncodeObject}->Decode(
-                    Text => $Array->[0],
-                    From => $Array->[1] || $Self->GetCharset() || 'us-ascii',
+                    Text  => $Array->[0],
+                    From  => $Array->[1] || $Self->GetCharset() || 'us-ascii',
                     Check => 1,
                 );
             }
             else {
-                $Remember{$Array->[0]} = undef;
+                $Remember{ $Array->[0] } = undef;
             }
         }
     }
+
     # debug
-    if ($Self->{Debug} > 1) {
+    if ( $Self->{Debug} > 1 ) {
         $Self->{LogObject}->Log(
             Priority => 'debug',
-            Message => "Get: $What; ReturnLine: $ReturnLine; OrigLine: $Line",
+            Message  => "Get: $What; ReturnLine: $ReturnLine; OrigLine: $Line",
         );
     }
     return $ReturnLine;
@@ -182,15 +192,17 @@ sub GetParam {
 
 To get the senders email address back.
 
-    my $SenderEmail = $ParseObject->GetEmailAddress(Email => 'Juergen Weber <juergen.qeber@air.com>');
+    my $SenderEmail = $ParserObject->GetEmailAddress(
+        Email => 'Juergen Weber <juergen.qeber@air.com>',
+    );
 
 =cut
 
 sub GetEmailAddress {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     my $Email = '';
-    foreach my $EmailSplit (Mail::Address->parse($Param{Email})) {
+    for my $EmailSplit ( Mail::Address->parse( $Param{Email} ) ) {
         $Email = $EmailSplit->address();
     }
     return $Email;
@@ -200,18 +212,20 @@ sub GetEmailAddress {
 
 To get an array of email addresses of an To, Cc or Bcc line back.
 
-    my @Addresses = $ParseObject->SplitAddressLine(Line => 'Juergen Weber <juergen.qeber@air.com>, me@example.com, hans@example.com (Hans Huber)');
+    my @Addresses = $ParserObject->SplitAddressLine(
+        Line => 'Juergen Weber <juergen.qeber@air.com>, me@example.com, hans@example.com (Hans Huber)',
+    );
 
 This returns an array with ('Juergen Weber <juergen.qeber@air.com>', 'me@example.com', 'hans@example.com (Hans Huber)').
 
 =cut
 
 sub SplitAddressLine {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     my @GetParam = ();
-    foreach my $Line (Mail::Address->parse($Param{Line})) {
-        push (@GetParam, $Line->format());
+    for my $Line ( Mail::Address->parse( $Param{Line} ) ) {
+        push( @GetParam, $Line->format() );
     }
     return @GetParam;
 }
@@ -220,20 +234,23 @@ sub SplitAddressLine {
 
 Returns the message body (or from the first attachment) "ContentType" header.
 
-    my $ContentType = $ParseObject->GetContentType();
+    my $ContentType = $ParserObject->GetContentType();
 
 (e. g. 'text/plain; charset="iso-8859-1"')
 
 =cut
 
 sub GetContentType {
-    my $Self = shift;
-    my $ContentType = shift || '';
-    if ($Self->{ContentType}) {
+    my ( $Self, $ContentType ) = @_;
+    if ( !$ContentType ) {
+        $ContentType = '';
+    }
+
+    if ( $Self->{ContentType} ) {
         return $Self->{ContentType};
     }
     else {
-        return $Self->GetParam(WHAT => 'Content-Type');
+        return $Self->GetParam( WHAT => 'Content-Type' );
     }
 }
 
@@ -241,21 +258,25 @@ sub GetContentType {
 
 Returns the message body (or from the first attachment) "charset".
 
-    my $Charset = $ParseObject->GetCharset();
+    my $Charset = $ParserObject->GetCharset();
 
 (e. g. iso-8859-1, utf-8, ...)
 
 =cut
 
 sub GetCharset {
-    my $Self = shift;
-    my $ContentType = shift || '';
+    my ( $Self, $ContentType ) = @_;
+    if ( !$ContentType ) {
+        $ContentType = '';
+    }
+
     if ( defined( $Self->{Charset} ) ) {
+
         # debug
-        if ($Self->{Debug} > 0) {
+        if ( $Self->{Debug} > 0 ) {
             $Self->{LogObject}->Log(
                 Priority => 'debug',
-                Message => "Got charset from mime body: $Self->{Charset}",
+                Message  => "Got charset from mime body: $Self->{Charset}",
             );
         }
         return $Self->{Charset};
@@ -264,16 +285,20 @@ sub GetCharset {
         $Self->{HeaderObject}->unfold();
         $Self->{HeaderObject}->combine('Content-Type');
         my $Line = $Self->{HeaderObject}->get('Content-Type') || '';
-        chomp ($Line);
-        my %Data = $Self->GetContentTypeParams(ContentType => $Line);
+        chomp($Line);
+        my %Data = $Self->GetContentTypeParams( ContentType => $Line );
+
+        # check content type (only do charset decode if no Content-Type or ContentType
+        # with text/* exists) if it's not a text content type (e. g. pdf, png, ...),
+        # return no charset
+        if ( $Data{ContentType} && $Data{ContentType} !~ /text/i ) {
 
-        # if it's not a text content type (e. g. pdf, png, ...), return no charset
-        if ( $Data{ContentType} && $Data{ContentType} !~ /text/i) {
             # debug
             if ( $Self->{Debug} > 0 ) {
                 $Self->{LogObject}->Log(
                     Priority => 'debug',
-                    Message  => "Got no charset from email body because of ContentType ($Data{ContentType})!",
+                    Message =>
+                        "Got no charset from email body because of ContentType ($Data{ContentType})!",
                 );
             }
 
@@ -285,16 +310,19 @@ sub GetCharset {
         }
 
         # return charset if it can be detected
-        elsif ($Data{Charset}) {
+        elsif ( $Data{Charset} ) {
+
             # debug
-            if ($Self->{Debug} > 0) {
+            if ( $Self->{Debug} > 0 ) {
                 $Self->{LogObject}->Log(
                     Priority => 'debug',
-                    Message => "Got charset from email body: $Data{Charset}",
+                    Message  => "Got charset from email body: $Data{Charset}",
                 );
             }
+
             # remember to charset
             $Self->{Charset} = $Data{Charset};
+
             # return charset
             return $Data{Charset};
         }
@@ -302,15 +330,18 @@ sub GetCharset {
         # if there is no available header for charset and content type, use
         # iso-8859-1 as charset
         else {
+
             # debug
-            if ($Self->{Debug} > 0) {
+            if ( $Self->{Debug} > 0 ) {
                 $Self->{LogObject}->Log(
                     Priority => 'debug',
-                    Message => "Got no charset from email body! Take iso-8859-1!",
+                    Message  => 'Got no charset from email body! Take iso-8859-1!',
                 );
             }
+
             # remember to charset
             $Self->{Charset} = 'ISO-8859-1';
+
             # return charset
             return 'ISO-8859-1';
         }
@@ -322,7 +353,7 @@ sub GetCharset {
 Returns the new message body (or from the first attachment) "ContentType" header
 (maybe the message is converted to utf-8).
 
-    my $ContentType = $ParseObject->GetReturnContentType();
+    my $ContentType = $ParserObject->GetReturnContentType();
 
 (e. g. 'text/plain; charset="utf-8"')
 
@@ -330,25 +361,30 @@ Returns the new message body (or from the first attachment) "ContentType" header
 
 sub GetReturnContentType {
     my $Self = shift;
+
     my $ContentType = $Self->GetContentType();
-    if ($Self->{EncodeObject}->EncodeInternalUsed()) {
+    if ( $Self->{EncodeObject}->EncodeInternalUsed() ) {
         my $InternalCharset = $Self->{EncodeObject}->EncodeInternalUsed();
         $ContentType =~ s/(charset=)(.*)/$1$InternalCharset/ig;
+
         # debug
-        if ($Self->{Debug} > 0) {
+        if ( $Self->{Debug} > 0 ) {
             $Self->{LogObject}->Log(
                 Priority => 'debug',
-                Message => "Changed ContentType from '".$Self->GetContentType()."' to '$ContentType'.",
+                Message  => "Changed ContentType from '"
+                    . $Self->GetContentType()
+                    . "' to '$ContentType'.",
             );
         }
         return $ContentType;
     }
     else {
+
         # debug
-        if ($Self->{Debug} > 0) {
+        if ( $Self->{Debug} > 0 ) {
             $Self->{LogObject}->Log(
                 Priority => 'debug',
-                Message => "Changed no ContentType",
+                Message  => 'Changed no ContentType',
             );
         }
         return $ContentType;
@@ -360,7 +396,7 @@ sub GetReturnContentType {
 Returns the charset of the new message body "Charset"
 (maybe the message is converted to utf-8).
 
-    my $Charset = $ParseObject->GetReturnCharset();
+    my $Charset = $ParserObject->GetReturnCharset();
 
 (e. g. 'text/plain; charset="utf-8"')
 
@@ -368,8 +404,9 @@ Returns the charset of the new message body "Charset"
 
 sub GetReturnCharset {
     my $Self = shift;
+
     my $ContentType = $Self->GetContentType();
-    if ($Self->{EncodeObject}->EncodeInternalUsed()) {
+    if ( $Self->{EncodeObject}->EncodeInternalUsed() ) {
         return $Self->{EncodeObject}->EncodeInternalUsed();
     }
     else {
@@ -381,83 +418,95 @@ sub GetReturnCharset {
 
 Returns the message body (or from the first attachment) from the email.
 
-    my $Body = $ParseObject->GetMessageBody();
+    my $Body = $ParserObject->GetMessageBody();
 
 =cut
 
 sub GetMessageBody {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     # check if message body is already there
-    if ($Self->{MessageBody}) {
+    if ( $Self->{MessageBody} ) {
         return $Self->{MessageBody};
     }
 
-    if (!$Self->{EntityMode} && $Self->{ParserParts}->parts() == 0) {
+    if ( !$Self->{EntityMode} && $Self->{ParserParts}->parts() == 0 ) {
         $Self->{MimeEmail} = 0;
-        if ($Self->{Debug} > 0) {
+        if ( $Self->{Debug} > 0 ) {
             $Self->{LogObject}->Log(
                 Priority => 'debug',
-                Message => "It's a plain (not mime) email!",
+                Message  => 'It\'s a plain (not mime) email!',
             );
         }
-        my $BodyStrg = join('', @{$Self->{Email}->body()});
+        my $BodyStrg = join( '', @{ $Self->{Email}->body() } );
+
         # quoted printable!
-        if ($Self->GetParam(WHAT => 'Content-Transfer-Encoding') =~ /quoted-printable/i) {
+        if ( $Self->GetParam( WHAT => 'Content-Transfer-Encoding' ) =~ /quoted-printable/i ) {
             $BodyStrg = MIME::QuotedPrint::decode($BodyStrg);
         }
+
         # base 64 encode
-        elsif ($Self->GetParam(WHAT => 'Content-Transfer-Encoding') =~ /base64/i) {
+        elsif ( $Self->GetParam( WHAT => 'Content-Transfer-Encoding' ) =~ /base64/i ) {
             $BodyStrg = decode_base64($BodyStrg);
         }
+
         # charset decode
         if ( $Self->GetCharset() ) {
             $Self->{MessageBody} = $Self->{EncodeObject}->Decode(
-                Text => $BodyStrg,
-                From => $Self->GetCharset(),
+                Text  => $BodyStrg,
+                From  => $Self->GetCharset(),
                 Check => 1,
             );
         }
         else {
             $Self->{MessageBody} = $BodyStrg;
         }
-        # check it it's juat a html email (store it as attachment and add text/plain)
+
+        # check if it's juat a html email (store it as attachment and add text/plain)
         $Self->CheckMessageBody();
+
         # return message body
         return $Self->{MessageBody};
     }
     else {
         $Self->{MimeEmail} = 1;
-        if ($Self->{Debug} > 0) {
+        if ( $Self->{Debug} > 0 ) {
             $Self->{LogObject}->Log(
                 Priority => 'debug',
-                Message => "It's a mime email!",
+                Message  => 'It\'s a mime email!',
             );
         }
-        my @Attachments = $Self->GetAttachments();
+
         # check if there is an valid attachment there, if yes, return
         # first attachment (normally text/plain) as message body
-        if (@Attachments > 0) {
-            my %Attachment = %{$Attachments[0]};
-            if ($Attachment{ContentType} =~ /text/i) {
-               $Self->{Charset} = $Attachment{Charset};
-                $Self->{ContentType} = $Attachment{ContentType};
-                if ($Self->{Debug} > 0) {
-                    $Self->{LogObject}->Log(
-                        Priority => 'debug',
-                        Message => "First atm ContentType: $Self->{ContentType}",
-                    );
-                }
+        my @Attachments = $Self->GetAttachments();
+        if ( @Attachments > 0 ) {
+            $Self->{Charset}     = $Attachments[0]->{Charset};
+            $Self->{ContentType} = $Attachments[0]->{ContentType};
+            if ( $Self->{Debug} > 0 ) {
+                $Self->{LogObject}->Log(
+                    Priority => 'debug',
+                    Message  => "First attachment ContentType: $Self->{ContentType}",
+                );
+            }
+
+            # check if charset is given, set iso-8859-1 if content is text
+            if ( !$Self->{Charset} && $Self->{ContentType} =~ /\btext\b/ ) {
+                $Self->{Charset} = 'iso-8859-1';
+            }
+
+            # check if charset exists
+            if ( $Self->GetCharset() ) {
                 $Self->{MessageBody} = $Self->{EncodeObject}->Decode(
-                    Text => $Attachment{Content},
-                    From => $Self->GetCharset(),
+                    Text  => $Attachments[0]->{Content},
+                    From  => $Self->GetCharset(),
                     Check => 1,
                 );
             }
             else {
                 $Self->{Charset}     = 'us-ascii';
                 $Self->{ContentType} = 'text/plain';
-                $Self->{MessageBody} = '- no text message -';
+                $Self->{MessageBody} = '- no text message => see attachment -';
             }
 
             # check it it's juat a html email (store it as attachment and add text/plain)
@@ -467,14 +516,16 @@ sub GetMessageBody {
             return $Self->{MessageBody};
         }
         else {
-            if ($Self->{Debug} > 0) {
+            if ( $Self->{Debug} > 0 ) {
                 $Self->{LogObject}->Log(
-                Priority => 'debug',
-                Message => "No attachments returned from GetAttachments(), just a null attachment!?",
+                    Priority => 'debug',
+                    Message =>
+                        'No attachments returned from GetAttachments(), just a null attachment!?',
                 );
             }
+
             # return empty attachment
-            $Self->{Charset} = 'iso-8859-1';
+            $Self->{Charset}     = 'iso-8859-1';
             $Self->{ContentType} = 'text/plain';
             return '-';
         }
@@ -486,9 +537,8 @@ sub GetMessageBody {
 
 Returns an array of the email attachments.
 
-    my @Attachments = $ParseObject->GetAttachments();
-
-    foreach my $Attachment (@Attachments) {
+    my @Attachments = $ParserObject->GetAttachments();
+    for my $Attachment (@Attachments) {
         print $Attachment->{Filename};
         print $Attachment->{Charset};
         print $Attachment->{MimeType};
@@ -499,118 +549,136 @@ Returns an array of the email attachments.
 =cut
 
 sub GetAttachments {
-    my $Self = shift;
-    my %Param = @_;
-    if (!$Self->{MimeEmail}) {
+    my ( $Self, %Param ) = @_;
+
+    if ( !$Self->{MimeEmail} ) {
         return;
     }
-    elsif ($Self->{Attachments}) {
-        return @{$Self->{Attachments}};
+    elsif ( $Self->{Attachments} ) {
+        return @{ $Self->{Attachments} };
     }
     else {
-        $Self->PartsAttachments(Part => $Self->{ParserParts});
-        if ($Self->{Attachments}) {
-            return @{$Self->{Attachments}};
+        $Self->PartsAttachments( Part => $Self->{ParserParts} );
+        if ( $Self->{Attachments} ) {
+            return @{ $Self->{Attachments} };
         }
         else {
             return;
         }
     }
 }
+
 # just for internal
 sub PartsAttachments {
-    my $Self = shift;
-    my %Param = @_;
-    my $Part = $Param{Part} || $Self->{ParserParts};
-    my $PartCounter = $Param{PartCounter} || 0;
+    my ( $Self, %Param ) = @_;
+
+    my $Part           = $Param{Part}           || $Self->{ParserParts};
+    my $PartCounter    = $Param{PartCounter}    || 0;
     my $SubPartCounter = $Param{SubPartCounter} || 0;
     $Self->{PartCounter}++;
-    if ($Part->parts() > 0) {
+    if ( $Part->parts() > 0 ) {
         $PartCounter++;
-        foreach ($Part->parts()) {
+        for ( $Part->parts() ) {
             $SubPartCounter++;
-            if ($Self->{Debug} > 0) {
+            if ( $Self->{Debug} > 0 ) {
                 print STDERR "Sub part($PartCounter/$SubPartCounter)!\n";
             }
-            $Self->PartsAttachments(Part => $_, PartCounter => $PartCounter);
+            $Self->PartsAttachments( Part => $_, PartCounter => $PartCounter );
         }
+        return 1;
     }
     else {
+
         # get attachment meta stuff
         my %PartData = ();
+
         # get ContentType
         $Part->head()->unfold();
         $Part->head()->combine('Content-Type');
+
         # get Content-Type, use text/plain if no content type is given
         $PartData{ContentType} = $Part->head()->get('Content-Type') || 'text/plain;';
-        chomp ($PartData{ContentType});
+        chomp( $PartData{ContentType} );
+
         # get mime type
         $PartData{MimeType} = $Part->head()->mime_type();
+
         # get charset
-        my %Data = $Self->GetContentTypeParams(ContentType => $PartData{ContentType});
-        if ($Data{Charset}) {
+        my %Data = $Self->GetContentTypeParams( ContentType => $PartData{ContentType} );
+        if ( $Data{Charset} ) {
             $PartData{Charset} = $Data{Charset};
         }
         else {
-            $PartData{Charset} = 'ISO-8859-1';
+            $PartData{Charset} = '';
         }
+
         # get content (if possible)
-        if ($Part->bodyhandle()) {
+        if ( $Part->bodyhandle() ) {
             $PartData{Content} = $Part->bodyhandle()->as_string();
-            if (!$PartData{Content}) {
+            if ( !$PartData{Content} ) {
                 $Self->{LogObject}->Log(
                     Priority => 'notice',
-                    Message => "Totally empty attachment part ($PartCounter)",
+                    Message  => "Totally empty attachment part ($PartCounter)",
                 );
                 return;
             }
         }
+
         # log error if there is an corrupt MIME email
         else {
             $Self->{LogObject}->Log(
                 Priority => 'notice',
-                Message => "Was not able to parse corrupt MIME email! Skipped attachment ($PartCounter)",
+                Message =>
+                    "Was not able to parse corrupt MIME email! Skipped attachment ($PartCounter)",
             );
             return;
         }
+
         # check if there is no recommended_filename -> add file-NoFilenamePartCounter
-        if (!$Part->head()->recommended_filename()) {
+        if ( !$Part->head()->recommended_filename() ) {
             $Self->{NoFilenamePartCounter}++;
             $PartData{Filename} = "file-$Self->{NoFilenamePartCounter}";
         }
         else {
-            $PartData{Filename} = decode_mimewords($Part->head()->recommended_filename());
+            $PartData{Filename} = decode_mimewords( $Part->head()->recommended_filename() );
             $PartData{ContentDisposition} = $Part->head()->get('Content-Disposition');
-            if ($PartData{ContentDisposition}) {
-               my %Data = $Self->GetContentTypeParams(ContentType => $PartData{ContentDisposition});
-               if ($Data{Charset}) {
-                   $PartData{Charset} = $Data{Charset};
-               }
+            if ( $PartData{ContentDisposition} ) {
+                my %Data = $Self->GetContentTypeParams(
+                    ContentType => $PartData{ContentDisposition},
+                );
+                if ( $Data{Charset} ) {
+                    $PartData{Charset} = $Data{Charset};
+                }
             }
             else {
                 $PartData{Charset} = '';
             }
+
             # convert the file name in utf-8 if utf-8 is used
-            if ($PartData{Charset}) {
+            if ( $PartData{Charset} ) {
                 $PartData{Filename} = $Self->{EncodeObject}->Decode(
-                    Text => $PartData{Filename},
-                    From => $PartData{Charset},
+                    Text  => $PartData{Filename},
+                    From  => $PartData{Charset},
                     Check => 1,
                 );
             }
         }
+
         # debug
-        if ($Self->{Debug} > 0) {
+        if ( $Self->{Debug} > 0 ) {
             print STDERR "->GotArticle::Atm: '$PartData{Filename}' '$PartData{ContentType}'\n";
         }
+
         # get attachment size
         {
             use bytes;
-            $PartData{Filesize} = length($PartData{Content});
+            $PartData{Filesize} = length( $PartData{Content} );
             no bytes;
         }
+
         # store data
-        push(@{$Self->{Attachments}}, \%PartData);
+        push( @{ $Self->{Attachments} }, \%PartData );
+        return 1;
     }
 }
 
@@ -618,34 +686,37 @@ sub PartsAttachments {
 
 To get an array of reference ids of the parsed email
 
-    my @References = $ParseObject->GetReferences();
+    my @References = $ParserObject->GetReferences();
 
 This returns an array with ('fasfda@host.de', '4124.2313.1231@host.com').
 
 =cut
 
 sub GetReferences {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     my @ReferencesAll = ();
-    my @References = ();
+    my @References    = ();
+
     # get references ids
-    my $ReferencesString = $Self->GetParam(WHAT => 'References');
+    my $ReferencesString = $Self->GetParam( WHAT => 'References' );
     if ($ReferencesString) {
-        push (@ReferencesAll, ($ReferencesString =~ /<([^>]+)>/g));
+        push( @ReferencesAll, ( $ReferencesString =~ /<([^>]+)>/g ) );
     }
+
     # get in reply to id
-    my $InReplyToString = $Self->GetParam(WHAT => 'In-Reply-To');
+    my $InReplyToString = $Self->GetParam( WHAT => 'In-Reply-To' );
     if ($InReplyToString) {
         chomp $InReplyToString;
         $InReplyToString =~ s/.*?<([^>]+)>.*/$1/;
-        push (@ReferencesAll, $InReplyToString);
+        push( @ReferencesAll, $InReplyToString );
     }
     my %Checked = ();
+
     # get uniq
-    foreach (reverse @ReferencesAll) {
-        if (!$Checked{$_}) {
-            push (@References, $_);
+    for ( reverse @ReferencesAll ) {
+        if ( !$Checked{$_} ) {
+            push( @References, $_ );
         }
         $Checked{$_} = 1;
     }
@@ -654,66 +725,87 @@ sub GetReferences {
 
 # just for internal
 sub GetContentTypeParams {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     my $ContentType = $Param{ContentType} || return;
-    if ($Param{ContentType} =~ /charset=.+?/i) {
+    if ( $Param{ContentType} =~ /charset=.+?/i ) {
         $Param{Charset} = $Param{ContentType};
         $Param{Charset} =~ s/.+?charset=("|'|)(\w+)/$2/gi;
-        $Param{Charset} =~ s/"|'//g ;
+        $Param{Charset} =~ s/"|'//g;
         $Param{Charset} =~ s/(.+?);.*/$1/g;
     }
-    if (!$Param{Charset}) {
-        if ( $Param{ContentType} =~ /\?(iso-\d{3,4}-(\d{1,2}|[A-z]{1,2})|utf(-8|8)|windows-\d{3,5}|koi8-.+?|cp(-|)\d{2,4}|big5(|.+?)|shift(_|-)jis|euc-.+?|tcvn|visii|vps|gb.+?)\?/i ) {
+    if ( !$Param{Charset} ) {
+        if (
+            $Param{ContentType}
+            =~ /\?(iso-\d{3,4}-(\d{1,2}|[A-z]{1,2})|utf(-8|8)|windows-\d{3,5}|koi8-.+?|cp(-|)\d{2,4}|big5(|.+?)|shift(_|-)jis|euc-.+?|tcvn|visii|vps|gb.+?)\?/i
+            )
+        {
             $Param{Charset} = $1;
         }
         elsif ( $Param{ContentType} =~ /name\*0\*=(utf-8|utf8)/i ) {
             $Param{Charset} = $1;
         }
-        elsif ( $Param{ContentType} =~ /filename\*=(iso-\d{3,4}-(\d{1,2}|[A-z]{1,2})|utf(-8|8)|windows-\d{3,5}|koi8-.+?|cp(-|)\d{2,4}|big5(|.+?)|shift(_|-)jis|euc-.+?|tcvn|visii|vps|gb.+?)''/i ) {
+        elsif (
+            $Param{ContentType}
+            =~ /filename\*=(iso-\d{3,4}-(\d{1,2}|[A-z]{1,2})|utf(-8|8)|windows-\d{3,5}|koi8-.+?|cp(-|)\d{2,4}|big5(|.+?)|shift(_|-)jis|euc-.+?|tcvn|visii|vps|gb.+?)''/i
+            )
+        {
             $Param{Charset} = $1;
         }
     }
-    if ($Param{ContentType} =~ /^(\w+\/\w+)/i) {
+    if ( $Param{ContentType} =~ /^(\w+\/\w+)/i ) {
         $Param{MimeType} = $1;
-        $Param{MimeType} =~ s/"|'//g ;
+        $Param{MimeType} =~ s/"|'//g;
     }
     return %Param;
 }
 
 # just for internal
 sub CheckMessageBody {
-    my $Self = shift;
-    my %Param = @_;
+    my ( $Self, %Param ) = @_;
+
     # if already checked, just return
-    if ($Self->{MessageChecked} || !$Self->{ConfigObject}->Get('PostmasterAutoHTML2Text') || $Self->{NoHTMLChecks}) {
+    if (
+        $Self->{MessageChecked}
+        || !$Self->{ConfigObject}->Get('PostmasterAutoHTML2Text')
+        || $Self->{NoHTMLChecks}
+        )
+    {
         return;
     }
+
     # check it it's juat a html email (store it as attachment and add text/plain)
-    if ($Self->GetReturnContentType() =~ /text\/html/i) {
+    if ( $Self->GetReturnContentType() =~ /text\/html/i ) {
         $Self->{MessageChecked} = 1;
+
         # add html email as attachment (if needed)
-        if (!$Self->{MimeEmail}) {
-            push (@{$Self->{Attachments}}, {
-                Charset => $Self->GetCharset(),
-                ContentType => $Self->GetReturnContentType(),
-                Content => $Self->{MessageBody},
-                Filename => 'orig-html-email.html',
-            });
+        if ( !$Self->{MimeEmail} ) {
+            push(
+                @{ $Self->{Attachments} },
+                {
+                    Charset     => $Self->GetCharset(),
+                    ContentType => $Self->GetReturnContentType(),
+                    Content     => $Self->{MessageBody},
+                    Filename    => 'orig-html-email.html',
+                }
+            );
         }
+
         # remember to html file if not aleady there
         else {
-            if ($Self->{Attachments}->[0]->{Filename}) {
-                if ($Self->{Attachments}->[0]->{Filename} !~ /\.(htm|html)/i) {
+            if ( $Self->{Attachments}->[0]->{Filename} ) {
+                if ( $Self->{Attachments}->[0]->{Filename} !~ /\.(htm|html)/i ) {
                     $Self->{Attachments}->[0]->{Filename} .= '.html';
                 }
             }
         }
+
         # remember to be an mime email now
         $Self->{MimeEmail} = 1;
+
         # html2text filter for message body
         my $LinkList = '';
-        my $Counter = 0;
+        my $Counter  = 0;
 
         # find <a href=....> and replace it with [x]
         $Self->{MessageBody} =~ s{
@@ -869,8 +961,10 @@ sub CheckMessageBody {
             'times' => chr(215),    # times is a keyword in perl
             divide  => chr(247),
 
-            (   $] > 5.007
-                ? ( OElig    => chr(338),
+            (
+                $] > 5.007
+                ? (
+                    OElig    => chr(338),
                     oelig    => chr(339),
                     Scaron   => chr(352),
                     scaron   => chr(353),
@@ -1024,7 +1118,7 @@ sub CheckMessageBody {
                     diams    => chr(9830),
                     )
                 : ()
-            )
+                )
         );
 
         # encode html entities like "&#8211;"
@@ -1085,10 +1179,11 @@ sub CheckMessageBody {
         $Self->{MessageBody} .= "\n\n" . $LinkList;
 
         $Self->{ContentType} = 'text/plain';
-        if ($Self->{Debug} > 0) {
+        if ( $Self->{Debug} > 0 ) {
             $Self->{LogObject}->Log(
                 Priority => 'debug',
-                Message => "It's an html only email, added ascii dump, attached html email as attachment.",
+                Message =>
+                    'It\'s an html only email, added ascii dump, attached html email as attachment.',
             );
         }
     }
@@ -1109,6 +1204,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 
 =head1 VERSION
 
-$Revision: 1.50.2.7 $ $Date: 2008/05/22 17:55:46 $
+$Revision: 1.71 $ $Date: 2008/08/02 13:14:12 $
 
 =cut
