@@ -2,7 +2,7 @@
 # Ticket/Number/AutoIncrement.pm - a ticket number auto increment generator
 # Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AutoIncrement.pm,v 1.18.2.3 2008/04/23 20:29:29 martin Exp $
+# $Id: AutoIncrement.pm,v 1.27 2008/07/13 23:14:45 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -17,113 +17,122 @@
 package Kernel::System::Ticket::Number::AutoIncrement;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.18.2.3 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.27 $) [1];
 
 sub TicketCreateNumber {
-    my $Self = shift;
-    my $JumpCounter = shift || 0;
+    my ( $Self, $JumpCounter ) = @_;
+    if ( !$JumpCounter ) {
+        $JumpCounter = 0;
+    }
+
     # get needed config options
     my $CounterLog = $Self->{ConfigObject}->Get('Ticket::CounterLog');
-    my $SystemID = $Self->{ConfigObject}->Get('SystemID');
-    my $MinSize = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::AutoIncrement::MinCounterSize')
+    my $SystemID   = $Self->{ConfigObject}->Get('SystemID');
+    my $MinSize
+        = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::AutoIncrement::MinCounterSize')
         || $Self->{ConfigObject}->Get('Ticket::NumberGenerator::MinCounterSize')
         || 5;
+
     # read count
     my $Count = 0;
-    if (-f $CounterLog) {
-        open (DATA, "< $CounterLog") || die "Can't open $CounterLog: $!";
-        my $Line = <DATA>;
-        if ( $Line ) {
-            ($Count) = split(/;/, $Line);
-        }
-        close (DATA);
-        if ($Self->{Debug} > 0) {
-            $Self->{LogObject}->Log(
-                Priority => 'debug',
-                Message => "Read counter from $CounterLog: $Count",
-            );
+    if ( -f $CounterLog ) {
+        my $ContentSCALARRef = $Self->{MainObject}->FileRead(
+            Location => $CounterLog,
+        );
+        if ( $ContentSCALARRef && ${$ContentSCALARRef} ) {
+            ($Count) = split( /;/, ${$ContentSCALARRef} );
+            if ( $Self->{Debug} > 0 ) {
+                $Self->{LogObject}->Log(
+                    Priority => 'debug',
+                    Message  => "Read counter from $CounterLog: $Count",
+                );
+            }
         }
     }
+
     # count auto increment ($Count++)
     $Count++;
     $Count = $Count + $JumpCounter;
+
     # write new count
-    if (open (DATA, "> $CounterLog")) {
-        flock (DATA, 2) || warn "Can't set file lock ($CounterLog): $!";
-        print DATA $Count . "\n";
-        close (DATA);
-        if ($Self->{Debug} > 0) {
+    my $Write = $Self->{MainObject}->FileWrite(
+        Location => $CounterLog,
+        Content  => \$Count,
+    );
+    if ($Write) {
+        if ( $Self->{Debug} > 0 ) {
             $Self->{LogObject}->Log(
                 Priority => 'debug',
-                Message => "Write counter: $Count",
+                Message  => "Write counter: $Count",
             );
         }
     }
-    else {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message => "Can't write $CounterLog: $!",
-        );
-        die "Can't write $CounterLog: $!";
-    }
+
     # pad ticket number with leading '0' to length $MinSize (config option)
-    while (length($Count) < $MinSize) {
-        $Count = "0".$Count;
+    while ( length($Count) < $MinSize ) {
+        $Count = '0' . $Count;
     }
+
     # create new ticket number
     my $Tn = $SystemID . $Count;
+
     # Check ticket number. If exists generate new one!
-    if ($Self->TicketCheckNumber(Tn=>$Tn)) {
+    if ( $Self->TicketCheckNumber( Tn => $Tn ) ) {
         $Self->{LoopProtectionCounter}++;
-        if ($Self->{LoopProtectionCounter} >= 16000) {
+        if ( $Self->{LoopProtectionCounter} >= 16000 ) {
+
             # loop protection
             $Self->{LogObject}->Log(
                 Priority => 'error',
-                Message => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!".
-                    " Stoped TicketCreateNumber()!",
+                Message  => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!"
+                    . " Stoped TicketCreateNumber()!",
             );
             return;
         }
+
         # create new ticket number again
         $Self->{LogObject}->Log(
             Priority => 'notice',
-            Message => "Tn ($Tn) exists! Creating a new one.",
+            Message  => "Tn ($Tn) exists! Creating a new one.",
         );
-        $Tn = $Self->TicketCreateNumber($Self->{LoopProtectionCounter});
+        $Tn = $Self->TicketCreateNumber( $Self->{LoopProtectionCounter} );
     }
     return $Tn;
 }
 
 sub GetTNByString {
-    my $Self = shift;
-    my $String = shift || return;
+    my ( $Self, $String ) = @_;
+    if ( !$String ) {
+        return;
+    }
+
     # get needed config options
     my $CheckSystemID = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::CheckSystemID');
-    my $SystemID = '';
+    my $SystemID      = '';
     if ($CheckSystemID) {
         $SystemID = $Self->{ConfigObject}->Get('SystemID');
     }
-    my $TicketHook = $Self->{ConfigObject}->Get('Ticket::Hook');
+    my $TicketHook        = $Self->{ConfigObject}->Get('Ticket::Hook');
     my $TicketHookDivider = $Self->{ConfigObject}->Get('Ticket::HookDivider');
-    my $MinSize = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::AutoIncrement::MinCounterSize')
+    my $MinSize
+        = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::AutoIncrement::MinCounterSize')
         || $Self->{ConfigObject}->Get('Ticket::NumberGenerator::MinCounterSize')
         || 5;
     my $MaxSize = $MinSize + 5;
+
     # check ticket number
-    if ($String =~ /\Q$TicketHook$TicketHookDivider\E($SystemID\d{$MinSize,$MaxSize})/i) {
+    if ( $String =~ /\Q$TicketHook$TicketHookDivider\E($SystemID\d{$MinSize,$MaxSize})/i ) {
         return $1;
     }
-    else {
-        if ($String =~ /\Q$TicketHook\E:\s{0,2}($SystemID\d{$MinSize,$MaxSize})/i) {
-            return $1;
-        }
-        else {
-            return;
-        }
+
+    if ( $String =~ /\Q$TicketHook\E:\s{0,2}($SystemID\d{$MinSize,$MaxSize})/i ) {
+        return $1;
     }
+
+    return;
 }
 
 1;
