@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # bin/cgi-bin/customer.pl - the global CGI handle file (incl. auth) for OTRS
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: customer.pl,v 1.37 2006/08/26 17:33:32 martin Exp $
+# $Id: customer.pl,v 1.41 2008/02/01 12:49:21 tr Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,19 +20,19 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # --
 
+use strict;
+use warnings;
+
 # use ../../ as lib location
 use FindBin qw($Bin);
 use lib "$Bin/../..";
 use lib "$Bin/../../Kernel/cpan-lib";
 
-use strict;
-
 use vars qw($VERSION @INC);
-$VERSION = '$Revision: 1.37 $';
-$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
+$VERSION = qw($Revision: 1.41 $) [1];
 
 # check @INC for mod_perl (add lib path for "require module"!)
-push (@INC, "$Bin/../..", "$Bin/../../Kernel/cpan-lib");
+push( @INC, "$Bin/../..", "$Bin/../../Kernel/cpan-lib" );
 
 # 0=off;1=on;
 my $Debug = 0;
@@ -41,8 +41,7 @@ my $Debug = 0;
 use Kernel::System::Web::InterfaceCustomer();
 
 # create new object
-my $Interface = Kernel::System::Web::InterfaceCustomer->new(Debug => $Debug);
+my $Interface = Kernel::System::Web::InterfaceCustomer->new( Debug => $Debug );
 
 # execute object
 $Interface->Run();
-
