@@ -1,5 +1,5 @@
 -- ----------------------------------------------------------
---  driver: oracle, generated: 2007-11-05 14:29:59
+--  driver: oracle, generated: 2008-07-07 02:07:29
 -- ----------------------------------------------------------
 SET DEFINE OFF;
 -- ----------------------------------------------------------
@@ -21,9 +21,9 @@ INSERT INTO valid (name, create_by, create_time, change_by, change_time)
     VALUES
     ('invalid-temporarily', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
---  insert into table system_user
+--  insert into table users
 -- ----------------------------------------------------------
-INSERT INTO system_user (first_name, last_name, login, pw, valid_id, create_by, create_time, change_by, change_time)
+INSERT INTO users (first_name, last_name, login, pw, valid_id, create_by, create_time, change_by, change_time)
     VALUES
     ('Admin', 'OTRS', 'root@localhost', 'roK20XGbWEsSM', 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
@@ -75,6 +75,30 @@ INSERT INTO theme (theme, valid_id, create_by, create_time, change_by, change_ti
     VALUES
     ('Lite', 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
+--  insert into table link_type
+-- ----------------------------------------------------------
+INSERT INTO link_type (name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    ('Normal', 1, 1, current_timestamp, 1, current_timestamp);
+-- ----------------------------------------------------------
+--  insert into table link_type
+-- ----------------------------------------------------------
+INSERT INTO link_type (name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    ('ParentChild', 1, 1, current_timestamp, 1, current_timestamp);
+-- ----------------------------------------------------------
+--  insert into table link_state
+-- ----------------------------------------------------------
+INSERT INTO link_state (name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    ('Valid', 1, 1, current_timestamp, 1, current_timestamp);
+-- ----------------------------------------------------------
+--  insert into table link_state
+-- ----------------------------------------------------------
+INSERT INTO link_state (name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    ('Temporary', 1, 1, current_timestamp, 1, current_timestamp);
+-- ----------------------------------------------------------
 --  insert into table ticket_state_type
 -- ----------------------------------------------------------
 INSERT INTO ticket_state_type (name, comments, create_by, create_time, change_by, change_time)
@@ -178,6 +202,7 @@ INSERT INTO salutation (name, text, comments, valid_id, create_by, create_time,
     ('system standard salutation (en)', 'Dear <OTRS_CUSTOMER_REALNAME>,
 
 Thank you for your request.
+
 ', 'Standard Salutation.', 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 --  insert into table signature
@@ -749,9 +774,9 @@ INSERT INTO article_sender_type (name, valid_id, create_by, create_time, change_
 -- ----------------------------------------------------------
 --  insert into table ticket
 -- ----------------------------------------------------------
-INSERT INTO ticket (tn, queue_id, ticket_lock_id, ticket_answered, user_id, responsible_user_id, group_id, ticket_priority_id, ticket_state_id, create_time_unix, escalation_response_time, escalation_start_time, escalation_solution_time, valid_id, create_by, create_time, change_by, change_time)
+INSERT INTO ticket (tn, queue_id, ticket_lock_id, ticket_answered, user_id, responsible_user_id, group_id, ticket_priority_id, ticket_state_id, title, create_time_unix, escalation_time, escalation_response_time, escalation_update_time, escalation_solution_time, valid_id, create_by, create_time, change_by, change_time)
     VALUES
-    ('1010001', 2, 1, 0, 1, 1, 1, 3, 1, 1173345999, 0, 1173345999, 0, 1, 1, current_timestamp, 1, current_timestamp);
+    ('1010001', 2, 1, 0, 1, 1, 1, 3, 1, 'Welcome to OTRS!', 1173345999, 0, 0, 0, 0, 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 --  insert into table article
 -- ----------------------------------------------------------
@@ -924,6 +949,33 @@ INSERT INTO notifications (notification_type, notification_charset, notification
 
 the ticket "<OTRS_TICKET_TicketNumber>" is escalated!
 
+Escalated at:    <OTRS_TICKET_EscalationDestinationDate>
+Escalated since: <OTRS_TICKET_EscalationDestinationIn>
+
+<OTRS_CUSTOMER_FROM>
+
+wrote:
+<snip>
+<OTRS_CUSTOMER_EMAIL[30]>
+<snip>
+
+Please have a look at:
+
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
+
+Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
+-- ----------------------------------------------------------
+--  insert into table notifications
+-- ----------------------------------------------------------
+INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
+    VALUES
+    ('Agent::EscalationNotifyBefore', 'iso-8859-1', 'en', 'Ticket Escalation Warning! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
+
+the ticket "<OTRS_TICKET_TicketNumber>" will escalate!
+
+Escalation at: <OTRS_TICKET_EscalationDestinationDate>
+Escalation in: <OTRS_TICKET_EscalationDestinationIn>
+
 <OTRS_CUSTOMER_FROM>
 
 wrote:
@@ -1083,6 +1135,33 @@ INSERT INTO notifications (notification_type, notification_charset, notification
 
 das Ticket "<OTRS_TICKET_TicketNumber>" ist eskaliert!
 
+Eskaliert am:   <OTRS_TICKET_EscalationDestinationDate>
+Eskaliert seit: <OTRS_TICKET_EscalationDestinationIn>
+
+<OTRS_CUSTOMER_FROM>
+
+schrieb:
+<snip>
+<OTRS_CUSTOMER_EMAIL[30]>
+<snip>
+
+Bitte um Bearbeitung:
+
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
+
+Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
+-- ----------------------------------------------------------
+--  insert into table notifications
+-- ----------------------------------------------------------
+INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
+    VALUES
+    ('Agent::EscalationNotifyBefore', 'iso-8859-1', 'de', 'Ticket Eskalations-Warnung! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
+
+das Ticket "<OTRS_TICKET_TicketNumber>" wird bald eskalieren!
+
+Eskalation um: <OTRS_TICKET_EscalationDestinationDate>
+Eskalation in: <OTRS_TICKET_EscalationDestinationIn>
+
 <OTRS_CUSTOMER_FROM>
 
 schrieb:
@@ -1185,3 +1264,4 @@ Der Status des Tickets "<OTRS_TICKET_TicketNumber>" hat sich durch
 Ihr OTRS Benachrichtigungs-Master
 
 *** NUR EINE INFO ***', 1, current_timestamp, 1, current_timestamp);
+SET DEFINE OFF;
